@@ -45,6 +45,10 @@ public:
     AbstractClipItem(const ItemInfo info, const QRectF& rect, double fps);
     virtual ~ AbstractClipItem();
     void updateSelectedKeyFrame();
+
+    /** @brief Move the selected keyframe (does not influence the effect, only the display in timeline).
+    * @param pos new Position
+    * @param value new Value */
     void updateKeyFramePos(const GenTime pos, const double value);
     int addKeyFrame(const GenTime pos, const double value);
     bool hasKeyFrames() const;
@@ -69,7 +73,14 @@ public:
     virtual int track() const ;
     virtual GenTime cropStart() const ;
     virtual GenTime cropDuration() const ;
-    virtual void resizeStart(int posx);
+
+    /** @brief Resizes the clip from the start.
+    * @param posx Absolute position of new in point
+    * @param hasSizeLimit (optional) Whether the clip has a maximum size */
+    virtual void resizeStart(int posx, bool hasSizeLimit = true);
+
+    /** @brief Resizes the clip from the end.
+    * @param posx Absolute position of new out point */
     virtual void resizeEnd(int posx);
     virtual double fps() const;
     virtual void updateFps(double fps);
