@@ -61,9 +61,10 @@ ClipItem::ClipItem(DocClipBase *clip, ItemInfo info, double fps, double speed, i
     setPos(info.startPos.frames(fps), (double)(info.track * KdenliveSettings::trackheight()) + 1);
 
     // set speed independant info
+    if (m_speed <= 0 && m_speed > -1) m_speed = 1.0;
     m_speedIndependantInfo = m_info;
-    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * m_speed), m_fps);
-    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * m_speed), m_fps);
+    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * qAbs(m_speed)), m_fps);
+    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * qAbs(m_speed)), m_fps);
 
     m_videoPix = KIcon("kdenlive-show-video").pixmap(QSize(16, 16));
     m_audioPix = KIcon("kdenlive-show-audio").pixmap(QSize(16, 16));
@@ -138,6 +139,7 @@ ClipItem *ClipItem::clone(ItemInfo info) const
     duplicate->setEffectList(m_effectList);
     duplicate->setVideoOnly(m_videoOnly);
     duplicate->setAudioOnly(m_audioOnly);
+    duplicate->setFades(fadeIn(), fadeOut());
     //duplicate->setSpeed(m_speed);
     return duplicate;
 }
@@ -146,7 +148,61 @@ void ClipItem::setEffectList(const EffectsList effectList)
 {
     m_effectList.clone(effectList);
     m_effectNames = m_effectList.effectNames().join(" / ");
-    if (!m_effectList.isEmpty()) setSelectedEffect(0);
+    if (!m_effectList.isEmpty()) {
+        for (int i = 0; i < m_effectList.count(); i++) {
+            QString effectId = m_effectList.item(i).attribute("id");
+            // check if it is a fade effect
+            QDomNodeList params = m_effectList.item(i).elementsByTagName("parameter");
+            int fade = 0;
+            for (int j = 0; j < params.count(); j++) {
+                QDomElement e = params.item(j).toElement();
+                if (!e.isNull()) {
+                    if (effectId == "fadein") {
+                        if (m_effectList.hasEffect(QString(), "fade_from_black") == -1) {
+                            if (e.attribute("name") == "out") fade += e.attribute("value").toInt();
+                            else if (e.attribute("name") == "in") fade -= e.attribute("value").toInt();
+                        } else {
+                            QDomElement fadein = m_effectList.getEffectByTag(QString(), "fade_from_black");
+                            if (fadein.attribute("name") == "out") fade += fadein.attribute("value").toInt();
+                            else if (fadein.attribute("name") == "in") fade -= fadein.attribute("value").toInt();
+                        }
+                    } else if (effectId == "fade_from_black") {
+                        if (m_effectList.hasEffect(QString(), "fadein") == -1) {
+                            if (e.attribute("name") == "out") fade += e.attribute("value").toInt();
+                            else if (e.attribute("name") == "in") fade -= e.attribute("value").toInt();
+                        } else {
+                            QDomElement fadein = m_effectList.getEffectByTag(QString(), "fadein");
+                            if (fadein.attribute("name") == "out") fade += fadein.attribute("value").toInt();
+                            else if (fadein.attribute("name") == "in") fade -= fadein.attribute("value").toInt();
+                        }
+                    } else if (effectId == "fadeout") {
+                        if (m_effectList.hasEffect(QString(), "fade_to_black") == -1) {
+                            if (e.attribute("name") == "out") fade -= e.attribute("value").toInt();
+                            else if (e.attribute("name") == "in") fade += e.attribute("value").toInt();
+                        } else {
+                            QDomElement fadeout = m_effectList.getEffectByTag(QString(), "fade_to_black");
+                            if (fadeout.attribute("name") == "out") fade -= fadeout.attribute("value").toInt();
+                            else if (fadeout.attribute("name") == "in") fade += fadeout.attribute("value").toInt();
+                        }
+                    } else if (effectId == "fade_to_black") {
+                        if (m_effectList.hasEffect(QString(), "fadeout") == -1) {
+                            if (e.attribute("name") == "out") fade -= e.attribute("value").toInt();
+                            else if (e.attribute("name") == "in") fade += e.attribute("value").toInt();
+                        } else {
+                            QDomElement fadeout = m_effectList.getEffectByTag(QString(), "fadeout");
+                            if (fadeout.attribute("name") == "out") fade -= fadeout.attribute("value").toInt();
+                            else if (fadeout.attribute("name") == "in") fade += fadeout.attribute("value").toInt();
+                        }
+                    }
+                }
+            }
+            if (fade > 0)
+                m_startFade = fade;
+            else if (fade < 0)
+                m_endFade = -fade;
+        }
+        setSelectedEffect(0);
+    }
 }
 
 const EffectsList ClipItem::effectList() const
@@ -197,7 +253,7 @@ void ClipItem::initEffect(QDomElement effect, int diff)
     }
     if (effect.attribute("tag") == "volume" || effect.attribute("tag") == "brightness") {
         if (effect.attribute("id") == "fadeout" || effect.attribute("id") == "fade_to_black") {
-            int end = (cropDuration() + cropStart()).frames(m_fps);
+            int end = (cropDuration() + cropStart()).frames(m_fps) - 1;
             int start = end;
             if (effect.attribute("id") == "fadeout") {
                 if (m_effectList.hasEffect(QString(), "fade_to_black") == -1) {
@@ -255,9 +311,14 @@ void ClipItem::initEffect(QDomElement effect, int diff)
 bool ClipItem::checkKeyFrames()
 {
     bool clipEffectsModified = false;
-    for (int ix = 0; ix < m_effectList.count(); ix ++) {
-        QString kfr = keyframes(ix);
-        if (!kfr.isEmpty()) {
+    // go through all effects this clip has
+    for (int ix = 0; ix < m_effectList.count(); ++ix) {
+        QStringList keyframeParams = keyframes(ix);
+        QStringList newKeyFrameParams;
+        bool effModified = false;
+
+        // go through all params which have keyframes
+        foreach(const QString &kfr, keyframeParams) {
             const QStringList keyframes = kfr.split(';', QString::SkipEmptyParts);
             QStringList newKeyFrames;
             bool cutKeyFrame = false;
@@ -266,6 +327,8 @@ bool ClipItem::checkKeyFrames()
             double lastValue = -1;
             int start = cropStart().frames(m_fps);
             int end = (cropStart() + cropDuration()).frames(m_fps);
+
+            // go through all keyframes for one param
             foreach(const QString &str, keyframes) {
                 int pos = str.section(':', 0, 0).toInt();
                 double val = str.section(':', 1, 1).toDouble();
@@ -301,26 +364,32 @@ bool ClipItem::checkKeyFrames()
                 lastPos = pos;
                 lastValue = val;
             }
-            if (modified) {
-                // update KeyFrames
-                setKeyframes(ix, newKeyFrames.join(";"));
-                clipEffectsModified = true;
-            }
+
+            newKeyFrameParams.append(newKeyFrames.join(";"));
+            if (modified)
+                effModified = true;
+        }
+
+        if (effModified) {
+            // update KeyFrames
+            setKeyframes(ix, newKeyFrameParams);
+            clipEffectsModified = true;
         }
     }
     return clipEffectsModified;
 }
 
-void ClipItem::setKeyframes(const int ix, const QString keyframes)
+void ClipItem::setKeyframes(const int ix, const QStringList keyframes)
 {
     QDomElement effect = getEffectAt(ix);
     if (effect.attribute("disable") == "1") return;
     QDomNodeList params = effect.elementsByTagName("parameter");
+    int keyframeParams = 0;
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
         if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
-            e.setAttribute("keyframes", keyframes);
-            if (ix == m_selectedEffect) {
+            e.setAttribute("keyframes", keyframes.at(keyframeParams));
+            if (ix == m_selectedEffect && keyframeParams == 0) {
                 m_keyframes.clear();
                 double max = e.attribute("max").toDouble();
                 double min = e.attribute("min").toDouble();
@@ -337,9 +406,8 @@ void ClipItem::setKeyframes(const int ix, const QString keyframes)
                 if (m_keyframes.find(m_editedKeyframe) == m_keyframes.end()) m_editedKeyframe = -1;
                 if (m_keyframes.find(m_editedKeyframe) == m_keyframes.end()) m_editedKeyframe = -1;
                 update();
-                return;
             }
-            break;
+            ++keyframeParams;
         }
     }
 }
@@ -381,18 +449,16 @@ void ClipItem::setSelectedEffect(const int ix)
     }
 }
 
-QString ClipItem::keyframes(const int index)
+QStringList ClipItem::keyframes(const int index)
 {
-    QString result;
+    QStringList result;
     QDomElement effect = effectAt(index);
     QDomNodeList params = effect.elementsByTagName("parameter");
 
     for (int i = 0; i < params.count(); i++) {
         QDomElement e = params.item(i).toElement();
-        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
-            result = e.attribute("keyframes");
-            break;
-        }
+        if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe"))
+            result.append(e.attribute("keyframes"));
     }
     return result;
 }
@@ -450,11 +516,10 @@ void ClipItem::refreshClip(bool checkDuration)
                 if (m_info.cropStart > m_maxDuration) {
                     m_info.cropStart = GenTime();
                     m_info.cropDuration = qMin(m_info.cropDuration, m_maxDuration);
-                    updateRectGeometry();
                 } else {
                     m_info.cropDuration = m_maxDuration;
-                    updateRectGeometry();
                 }
+                updateRectGeometry();
             }
         }
     }
@@ -591,6 +656,11 @@ DocClipBase *ClipItem::baseClip() const
 }
 
 QDomElement ClipItem::xml() const
+{
+    return itemXml();
+}
+
+QDomElement ClipItem::itemXml() const
 {
     QDomElement xml = m_clip->toXML();
     if (m_speed != 1.0) xml.setAttribute("speed", m_speed);
@@ -676,6 +746,12 @@ void ClipItem::paint(QPainter *painter,
             QLineF l2(mapped.left() + m_startPix.width(), mapped.top(), mapped.left() + m_startPix.width(), mapped.bottom());
             painter->drawLine(l2);
         }
+        if (painter->matrix().m11() == FRAME_SIZE) {
+            int offset = (m_info.startPos - m_info.cropStart).frames(m_fps);
+            int left = qMax((int) m_info.startPos.frames(m_fps) + 1, (int) mapToScene(exposed.left(), 0).x());
+            int right = qMin((int)(m_info.startPos + m_info.cropDuration).frames(m_fps) - 1, (int) mapToScene(exposed.right(), 0).x());
+            doGetIntraThumbs(painter, mapped.topLeft(), m_info.cropStart.frames(m_fps), left - offset, right - offset);
+        }
         painter->setPen(Qt::black);
     }
 
@@ -708,6 +784,7 @@ void ClipItem::paint(QPainter *painter,
         const int mappedEndPixel =  painter->matrix().map(QPointF(endpixel + cropLeft, 0)).x() - clipStart;
         cropLeft = cropLeft * scale;
 
+
         if (channels >= 1) {
             emit prepareAudioThumb(scale, mappedStartPixel, mappedEndPixel, channels);
         }
@@ -775,7 +852,7 @@ void ClipItem::paint(QPainter *painter,
         pen.setStyle(Qt::DotLine);
 
         for (; it != markers.end(); ++it) {
-            pos = GenTime((int)((*it).time().frames(m_fps) / m_speed + 0.5), m_fps) - cropStart();
+            pos = GenTime((int)((*it).time().frames(m_fps) / qAbs(m_speed) + 0.5), m_fps) - cropStart();
             if (pos > GenTime()) {
                 if (pos > cropDuration()) break;
                 QLineF l(rect().x() + pos.frames(m_fps), rect().y(), rect().x() + pos.frames(m_fps), rect().bottom());
@@ -890,7 +967,12 @@ OPERATIONTYPE ClipItem::operationMode(QPointF pos)
         setToolTip(i18n("Add transition"));
         return TRANSITIONEND;
     }
-    setToolTip(QString());
+    QString tooltip = "<b>" + m_clipName + "</b>";
+    if (!baseClip()->fileURL().isEmpty())
+        tooltip.append("<br />" + baseClip()->fileURL().path());
+    if (!baseClip()->description().isEmpty())
+        tooltip.append("<br />" + baseClip()->description());
+    setToolTip(tooltip);
     return MOVE;
 }
 
@@ -901,8 +983,7 @@ QList <GenTime> ClipItem::snapMarkers() const
     GenTime pos;
 
     for (int i = 0; i < markers.size(); i++) {
-
-        pos = GenTime((int)(markers.at(i).frames(m_fps) / m_speed + 0.5), m_fps) - cropStart();
+        pos = GenTime((int)(markers.at(i).frames(m_fps) / qAbs(m_speed) + 0.5), m_fps) - cropStart();
         if (pos > GenTime()) {
             if (pos > cropDuration()) break;
             else snaps.append(pos + startPos());
@@ -918,7 +999,7 @@ QList <CommentedTime> ClipItem::commentedSnapMarkers() const
     GenTime pos;
 
     for (int i = 0; i < markers.size(); i++) {
-        pos = GenTime((int)(markers.at(i).time().frames(m_fps) / m_speed + 0.5), m_fps) - cropStart();
+        pos = GenTime((int)(markers.at(i).time().frames(m_fps) / qAbs(m_speed) + 0.5), m_fps) - cropStart();
         if (pos > GenTime()) {
             if (pos > cropDuration()) break;
             else snaps.append(CommentedTime(pos + startPos(), markers.at(i).comment()));
@@ -1046,6 +1127,12 @@ void ClipItem::setFadeOut(int pos)
 
 }
 
+void ClipItem::setFades(int in, int out)
+{
+    m_startFade = in;
+    m_endFade = out;
+}
+
 /*
 //virtual
 void ClipItem::hoverEnterEvent(QGraphicsSceneHoverEvent *e)
@@ -1076,18 +1163,23 @@ void ClipItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *)
 }
 */
 
-void ClipItem::resizeStart(int posx)
+void ClipItem::resizeStart(int posx, bool /*size*/)
 {
-    const int min = (startPos() - cropStart()).frames(m_fps);
-    if (posx < min) posx = min;
+    bool sizeLimit = false;
+    if (clipType() != IMAGE && clipType() != COLOR && clipType() != TEXT) {
+        const int min = (startPos() - cropStart()).frames(m_fps);
+        if (posx < min) posx = min;
+        sizeLimit = true;
+    }
+
     if (posx == startPos().frames(m_fps)) return;
     const int previous = cropStart().frames(m_fps);
-    AbstractClipItem::resizeStart(posx);
+    AbstractClipItem::resizeStart(posx, sizeLimit);
 
     // set speed independant info
     m_speedIndependantInfo = m_info;
-    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * m_speed), m_fps);
-    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * m_speed), m_fps);
+    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * qAbs(m_speed)), m_fps);
+    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * qAbs(m_speed)), m_fps);
 
     if ((int) cropStart().frames(m_fps) != previous) {
         if (m_hasThumbs && KdenliveSettings::videothumbnails()) {
@@ -1107,8 +1199,8 @@ void ClipItem::resizeEnd(int posx)
 
     // set speed independant info
     m_speedIndependantInfo = m_info;
-    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * m_speed), m_fps);
-    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * m_speed), m_fps);
+    m_speedIndependantInfo.cropStart = GenTime((int)(m_info.cropStart.frames(m_fps) * qAbs(m_speed)), m_fps);
+    m_speedIndependantInfo.cropDuration = GenTime((int)(m_info.cropDuration.frames(m_fps) * qAbs(m_speed)), m_fps);
 
     if ((int) cropDuration().frames(m_fps) != previous) {
         if (m_hasThumbs && KdenliveSettings::videothumbnails()) {
@@ -1120,13 +1212,16 @@ void ClipItem::resizeEnd(int posx)
 
 bool ClipItem::checkEffectsKeyframesPos(const int previous, const int current, bool fromStart)
 {
-    bool modified = false;
+    bool effModified = false;
     for (int i = 0; i < m_effectList.count(); i++) {
         QDomElement effect = m_effectList.at(i);
         QDomNodeList params = effect.elementsByTagName("parameter");
         for (int j = 0; j < params.count(); j++) {
-            QDomElement e = params.item(i).toElement();
-            if (!e.isNull() && (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe")) {
+            bool modified = false;
+            QDomElement e = params.item(j).toElement();
+            if (e.isNull())
+                continue;
+            if (e.attribute("type") == "keyframe" || e.attribute("type") == "simplekeyframe") {
                 // parse keyframes and adjust values
                 const QStringList keyframes = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
                 QMap <int, double> kfr;
@@ -1136,16 +1231,19 @@ bool ClipItem::checkEffectsKeyframesPos(const int previous, const int current, b
                     pos = str.section(':', 0, 0).toInt();
                     val = str.section(':', 1, 1).toDouble();
                     if (pos == previous) {
+                        // first or last keyframe
                         kfr[current] = val;
                         modified = true;
                     } else {
                         if ((fromStart && pos >= current) || (!fromStart && pos <= current)) {
+                            // only keyframes in range
                             kfr[pos] = val;
                             modified = true;
                         }
                     }
                 }
                 if (modified) {
+                    effModified = true;
                     QString newkfr;
                     QMap<int, double>::const_iterator k = kfr.constBegin();
                     while (k != kfr.constEnd()) {
@@ -1153,13 +1251,12 @@ bool ClipItem::checkEffectsKeyframesPos(const int previous, const int current, b
                         ++k;
                     }
                     e.setAttribute("keyframes", newkfr);
-                    break;
                 }
             }
         }
     }
-    if (modified && m_selectedEffect >= 0) setSelectedEffect(m_selectedEffect);
-    return modified;
+    if (effModified && m_selectedEffect >= 0) setSelectedEffect(m_selectedEffect);
+    return effModified;
 }
 
 //virtual
@@ -1317,11 +1414,22 @@ EffectsParameterList ClipItem::addEffect(const QDomElement effect, bool /*animat
     if (effect.hasAttribute("src")) parameters.addParam("src", effect.attribute("src"));
     if (effect.hasAttribute("disable")) parameters.addParam("disable", effect.attribute("disable"));
 
-
     QString effectId = effect.attribute("id");
     if (effectId.isEmpty()) effectId = effect.attribute("tag");
     parameters.addParam("id", effectId);
 
+    // special case: the affine effect needs in / out points
+    if (effectId == "pan_zoom") {
+        int start = cropStart().frames(m_fps);
+        int end = (cropStart() + cropDuration()).frames(m_fps);
+        if (start < 0) {
+            end -= start;
+            start = 0;
+        }
+        parameters.addParam("in", QString::number(start));
+        parameters.addParam("out", QString::number(end));
+    }
+
     QDomNodeList params = effect.elementsByTagName("parameter");
     int fade = 0;
     for (int i = 0; i < params.count(); i++) {
@@ -1421,70 +1529,6 @@ EffectsParameterList ClipItem::addEffect(const QDomElement effect, bool /*animat
     return parameters;
 }
 
-EffectsParameterList ClipItem::getEffectArgs(const QDomElement effect)
-{
-    EffectsParameterList parameters;
-    parameters.addParam("tag", effect.attribute("tag"));
-    parameters.addParam("kdenlive_ix", effect.attribute("kdenlive_ix"));
-    parameters.addParam("id", effect.attribute("id"));
-    if (effect.hasAttribute("src")) parameters.addParam("src", effect.attribute("src"));
-    if (effect.hasAttribute("disable")) parameters.addParam("disable", effect.attribute("disable"));
-
-    QDomNodeList params = effect.elementsByTagName("parameter");
-    for (int i = 0; i < params.count(); i++) {
-        QDomElement e = params.item(i).toElement();
-        //kDebug() << "/ / / /SENDING EFFECT PARAM: " << e.attribute("type") << ", NAME_ " << e.attribute("tag");
-        if (e.attribute("type") == "simplekeyframe") {
-
-            QStringList values = e.attribute("keyframes").split(";", QString::SkipEmptyParts);
-            double factor = e.attribute("factor", "1").toDouble();
-            for (int j = 0; j < values.count(); j++) {
-                QString pos = values.at(j).section(":", 0, 0);
-                double val = values.at(j).section(":", 1, 1).toDouble() / factor;
-                values[j] = pos + "=" + QString::number(val);
-            }
-            // kDebug() << "/ / / /SENDING KEYFR:" << values;
-            parameters.addParam(e.attribute("name"), values.join(";"));
-            /*parameters.addParam(e.attribute("name"), e.attribute("keyframes").replace(":", "="));
-            parameters.addParam("max", e.attribute("max"));
-            parameters.addParam("min", e.attribute("min"));
-            parameters.addParam("factor", e.attribute("factor", "1"));*/
-        } else if (e.attribute("type") == "keyframe") {
-            kDebug() << "/ / / /SENDING KEYFR EFFECT TYPE";
-            parameters.addParam("keyframes", e.attribute("keyframes"));
-            parameters.addParam("max", e.attribute("max"));
-            parameters.addParam("min", e.attribute("min"));
-            parameters.addParam("factor", e.attribute("factor", "1"));
-            parameters.addParam("starttag", e.attribute("starttag", "start"));
-            parameters.addParam("endtag", e.attribute("endtag", "end"));
-        } else if (e.attribute("namedesc").contains(';')) {
-            QString format = e.attribute("format");
-            QStringList separators = format.split("%d", QString::SkipEmptyParts);
-            QStringList values = e.attribute("value").split(QRegExp("[,:;x]"));
-            QString neu;
-            QTextStream txtNeu(&neu);
-            if (values.size() > 0)
-                txtNeu << (int)values[0].toDouble();
-            for (int i = 0; i < separators.size() && i + 1 < values.size(); i++) {
-                txtNeu << separators[i];
-                txtNeu << (int)(values[i+1].toDouble());
-            }
-            parameters.addParam("start", neu);
-        } else {
-            if (e.attribute("factor", "1") != "1") {
-                double fact;
-                if (e.attribute("factor").startsWith('%')) {
-                    fact = ProfilesDialog::getStringEval(projectScene()->profile(), e.attribute("factor"));
-                } else fact = e.attribute("factor", "1").toDouble();
-                parameters.addParam(e.attribute("name"), QString::number(e.attribute("value").toDouble() / fact));
-            } else {
-                parameters.addParam(e.attribute("name"), e.attribute("value"));
-            }
-        }
-    }
-    return parameters;
-}
-
 void ClipItem::deleteEffect(QString index)
 {
     bool needRepaint = false;
@@ -1539,17 +1583,19 @@ int ClipItem::strobe() const
 void ClipItem::setSpeed(const double speed, const int strobe)
 {
     m_speed = speed;
+    if (m_speed <= 0 && m_speed > -1)
+        m_speed = 1.0;
     m_strobe = strobe;
     if (m_speed == 1.0) m_clipName = baseClip()->name();
     else m_clipName = baseClip()->name() + " - " + QString::number(speed * 100, 'f', 0) + '%';
-    m_info.cropStart = GenTime((int)(m_speedIndependantInfo.cropStart.frames(m_fps) / m_speed + 0.5), m_fps);
-    m_info.cropDuration = GenTime((int)(m_speedIndependantInfo.cropDuration.frames(m_fps) / m_speed + 0.5), m_fps);
+    m_info.cropStart = GenTime((int)(m_speedIndependantInfo.cropStart.frames(m_fps) / qAbs(m_speed) + 0.5), m_fps);
+    m_info.cropDuration = GenTime((int)(m_speedIndependantInfo.cropDuration.frames(m_fps) / qAbs(m_speed) + 0.5), m_fps);
     //update();
 }
 
 GenTime ClipItem::maxDuration() const
 {
-    return GenTime((int)(m_maxDuration.frames(m_fps) / m_speed + 0.5), m_fps);
+    return GenTime((int)(m_maxDuration.frames(m_fps) / qAbs(m_speed) + 0.5), m_fps);
 }
 
 GenTime ClipItem::speedIndependantCropStart() const
@@ -1705,4 +1751,105 @@ void ClipItem::updateKeyframes(QDomElement effect)
     }
     if (!m_keyframes.contains(m_selectedKeyframe)) m_selectedKeyframe = -1;
 }
+
+void ClipItem::doGetIntraThumbs(QPainter *painter, const QPointF startPos, int offset, int start, int end)
+{
+    if (!m_clip->thumbProducer() || clipType() == COLOR) return;
+    if (scene() && scene()->views().isEmpty()) return;
+    CustomTrackView *view = (CustomTrackView *) scene()->views()[0];
+    if (view == NULL) return;
+    const int theight = KdenliveSettings::trackheight();
+    const int twidth = FRAME_SIZE;
+
+    if (clipType() == IMAGE || clipType() == TEXT) {
+        for (int i = start; i <= end; i++)
+            painter->drawPixmap(startPos + QPointF(twidth *(i - offset), 0), m_startPix);
+    }
+    QPixmap p;
+    for (int i = start; i <= end; i++) {
+        if (!view->pixmapCache->find(m_clip->fileURL().path() + "%" + QString::number(i), p)) {
+            p = m_clip->thumbProducer()->extractImage(i, twidth, theight);
+            view->pixmapCache->insert(m_clip->fileURL().path() + "%" + QString::number(i), p);
+        }
+        painter->drawPixmap(startPos + QPointF(twidth *(i - offset), 0), p);
+    }
+}
+
+QList <int> ClipItem::updatePanZoom(int width, int height, int cut)
+{
+    QList <int> effectPositions;
+    for (int i = 0; i < m_effectList.count(); i++) {
+        QDomElement effect = m_effectList.at(i);
+        QDomNodeList params = effect.elementsByTagName("parameter");
+        for (int j = 0; j < params.count(); j++) {
+            QDomElement e = params.item(j).toElement();
+            if (e.isNull())
+                continue;
+            if (e.attribute("type") == "geometry" && !e.hasAttribute("fixed")) {
+                effectPositions << i;
+
+                int in = cropStart().frames(fps());
+                int out = in + cropDuration().frames(fps());
+                if (in < 0) {
+                    out -= in;
+                    in = 0;
+                }
+                int dur = out - in - 1;
+
+                effect.setAttribute("in", in);
+                effect.setAttribute("out", out);
+
+                Mlt::Geometry geometry(e.attribute("value").toUtf8().data(), dur, width, height);
+                Mlt::GeometryItem item;
+                bool endFrameAdded = false;
+                if (cut == 0) {
+                    while (!geometry.next_key(&item, dur)) {
+                        if (!endFrameAdded) {
+                            // add keyframe at the end with interpolated value
+
+                            // but only once ;)
+                            endFrameAdded = true;
+
+                            Mlt::GeometryItem endItem;
+                            Mlt::GeometryItem interp;
+                            geometry.fetch(&interp, dur - 1);
+                            endItem.frame(dur - 1);
+                            endItem.x(interp.x());
+                            endItem.y(interp.y());
+                            endItem.w(interp.w());
+                            endItem.h(interp.h());
+                            endItem.mix(interp.mix());
+                            geometry.insert(&endItem);
+                        }
+                        geometry.remove(item.frame());
+                    }
+                } else {
+                    Mlt::Geometry origGeometry(e.attribute("value").toUtf8().data(), dur, width, height);
+                    // remove keyframes before cut point
+                    while (!geometry.prev_key(&item, cut - 1) && item.frame() < cut)
+                        geometry.remove(item.frame());
+
+                    // add a keyframe at new pos 0
+                    origGeometry.fetch(&item, cut);
+                    item.frame(0);
+                    geometry.insert(&item);
+
+                    // move exisiting keyframes by -cut
+                    while (!origGeometry.next_key(&item, cut)) {
+                        geometry.remove(item.frame());
+                        origGeometry.remove(item.frame());
+                        item.frame(item.frame() - cut);
+                        geometry.insert(&item);
+                    }
+                    
+                }
+
+                e.setAttribute("value", geometry.serialise());
+            }
+        }
+    }
+
+    return effectPositions;
+}
+
 #include "clipitem.moc"
