@@ -29,21 +29,28 @@
 #include <mlt++/Mlt.h>
 
 #include <KDebug>
+#include <KMessageBox>
 #include <KFileDialog>
+#include <KApplication>
 #include <kio/netaccess.h>
 
 #include <QGraphicsItemGroup>
 
+#include <KFileMetaInfo>
+
 ClipManager::ClipManager(KdenliveDoc *doc) :
         QObject(),
         m_audioThumbsQueue(),
         m_doc(doc),
-        m_audioThumbsEnabled(false),
         m_generatingAudioId()
 {
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
+    m_modifiedTimer.setInterval(1500);
     connect(&m_fileWatcher, SIGNAL(dirty(const QString &)), this, SLOT(slotClipModified(const QString &)));
+    connect(&m_fileWatcher, SIGNAL(deleted(const QString &)), this, SLOT(slotClipMissing(const QString &)));
+    connect(&m_fileWatcher, SIGNAL(created(const QString &)), this, SLOT(slotClipAvailable(const QString &)));
+    connect(&m_modifiedTimer, SIGNAL(timeout()), this, SLOT(slotProcessModifiedClips()));
 }
 
 ClipManager::~ClipManager()
@@ -62,22 +69,25 @@ void ClipManager::clear()
     m_folderIdCounter = 1;
     m_folderList.clear();
     m_audioThumbsQueue.clear();
+    m_modifiedClips.clear();
 }
 
 void ClipManager::checkAudioThumbs()
 {
-    if (m_audioThumbsEnabled == KdenliveSettings::audiothumbnails()) return;
-    m_audioThumbsEnabled = KdenliveSettings::audiothumbnails();
-    for (int i = 0; i < m_clipList.count(); i++) {
-        if (m_audioThumbsEnabled) m_audioThumbsQueue.append(m_clipList.at(i)->getId());
-        else m_clipList.at(i)->slotClearAudioCache();
-    }
-    if (m_audioThumbsEnabled) {
-        if (m_generatingAudioId.isEmpty()) startAudioThumbsGeneration();
-    } else {
+    if (!KdenliveSettings::audiothumbnails()) {
+        if (!m_generatingAudioId.isEmpty()) {
+            DocClipBase *clip = getClipById(m_generatingAudioId);
+            if (clip) clip->slotClearAudioCache();
+        }
         m_audioThumbsQueue.clear();
         m_generatingAudioId.clear();
+        return;
     }
+
+    for (int i = 0; i < m_clipList.count(); i++) {
+        m_audioThumbsQueue.append(m_clipList.at(i)->getId());
+    }
+    if (m_generatingAudioId.isEmpty()) startAudioThumbsGeneration();
 }
 
 void ClipManager::askForAudioThumb(const QString &id)
@@ -140,8 +150,9 @@ QMap <QString, QString> ClipManager::documentFolderList() const
 void ClipManager::addClip(DocClipBase *clip)
 {
     m_clipList.append(clip);
-    if (clip->clipType() == IMAGE || clip->clipType() == AUDIO || (clip->clipType() == TEXT && !clip->fileURL().isEmpty())) {
+    if (clip->clipType() != COLOR && clip->clipType() != SLIDESHOW  && !clip->fileURL().isEmpty()) {
         // listen for file change
+        //kDebug() << "// LISTEN FOR: " << clip->fileURL().path();
         m_fileWatcher.addFile(clip->fileURL().path());
     }
     const QString id = clip->getId();
@@ -168,7 +179,8 @@ void ClipManager::deleteClip(const QString &clipId)
 {
     for (int i = 0; i < m_clipList.count(); i++) {
         if (m_clipList.at(i)->getId() == clipId) {
-            if (m_clipList.at(i)->clipType() == IMAGE || m_clipList.at(i)->clipType() == AUDIO || (m_clipList.at(i)->clipType() == TEXT && !m_clipList.at(i)->fileURL().isEmpty())) {
+            if (m_clipList.at(i)->clipType() != COLOR && m_clipList.at(i)->clipType() != SLIDESHOW  && !m_clipList.at(i)->fileURL().isEmpty()) {
+                //if (m_clipList.at(i)->clipType() == IMAGE || m_clipList.at(i)->clipType() == AUDIO || (m_clipList.at(i)->clipType() == TEXT && !m_clipList.at(i)->fileURL().isEmpty())) {
                 // listen for file change
                 m_fileWatcher.removeFile(m_clipList.at(i)->fileURL().path());
             }
@@ -259,25 +271,37 @@ void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods)
 void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, const QString &groupId)
 {
     QUndoCommand *addClips = new QUndoCommand();
-    addClips->setText(i18n("Add clips"));
 
     foreach(const KUrl &file, urls) {
         if (KIO::NetAccess::exists(file, KIO::NetAccess::SourceSide, NULL)) {
+            if (!getClipByResource(file.path()).empty()) {
+                if (KMessageBox::warningContinueCancel(kapp->activeWindow(), i18n("Clip <b>%1</b><br />already exists in project, what do you want to do?", file.path()), i18n("Clip already exists")) == KMessageBox::Cancel)
+                    continue;
+            }
+            kDebug() << "Adding clip: " << file.path();
             QDomDocument doc;
             QDomElement prod = doc.createElement("producer");
             doc.appendChild(prod);
+            prod.setAttribute("resource", file.path());
+            uint id = m_clipIdCounter++;
+            prod.setAttribute("id", QString::number(id));
             if (!group.isEmpty()) {
                 prod.setAttribute("groupname", group);
                 prod.setAttribute("groupid", groupId);
             }
-            prod.setAttribute("resource", file.path());
-            uint id = m_clipIdCounter++;
-            prod.setAttribute("id", QString::number(id));
             KMimeType::Ptr type = KMimeType::findByUrl(file);
             if (type->name().startsWith("image/")) {
                 prod.setAttribute("type", (int) IMAGE);
                 prod.setAttribute("in", 0);
                 prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
+                // Read EXIF metadata for JPEG
+                if (type->is("image/jpeg")) {
+                    KFileMetaInfo metaInfo(file.path(), QString("image/jpeg"), KFileMetaInfo::TechnicalInfo);
+                    const QHash<QString, KFileMetaInfoItem> metaInfoItems = metaInfo.items();
+                    foreach(const KFileMetaInfoItem& metaInfoItem, metaInfoItems) {
+                        prod.setAttribute("meta.attr." + metaInfoItem.name().section("#", 1), metaInfoItem.value().toString());
+                    }
+                }
             } else if (type->is("application/x-kdenlivetitle")) {
                 // opening a title file
                 QDomDocument txtdoc("titledocument");
@@ -285,61 +309,48 @@ void ClipManager::slotAddClipList(const KUrl::List urls, const QString group, co
                 if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
                     txtfile.close();
                     prod.setAttribute("type", (int) TEXT);
-                    prod.setAttribute("resource", file.path());
                     prod.setAttribute("xmldata", txtdoc.toString());
                     prod.setAttribute("transparency", 1);
                     prod.setAttribute("in", 0);
                     int out = txtdoc.documentElement().attribute("out").toInt();
-                    if (out > 0) prod.setAttribute("out", out);
-                    else prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
-                } else txtfile.close();
+                    if (out > 0)
+                        prod.setAttribute("out", out);
+                    else
+                        prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                } else
+                    txtfile.close();
             }
             new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true, addClips);
         }
     }
-    m_doc->commandStack()->push(addClips);
+    if (addClips->childCount() > 0) {
+        addClips->setText(i18np("Add clip", "Add clips", addClips->childCount()));
+        m_doc->commandStack()->push(addClips);
+    }
 }
 
 void ClipManager::slotAddClipFile(const KUrl url, const QString group, const QString &groupId)
 {
-    kDebug() << "/////  CLIP MANAGER, ADDING CLIP: " << url;
+    slotAddClipList(KUrl::List(url), group, groupId);
+}
+
+void ClipManager::slotAddXmlClipFile(const QString name, const QDomElement xml, const QString group, const QString &groupId)
+{
     QDomDocument doc;
-    QDomElement prod = doc.createElement("producer");
-    doc.appendChild(prod);
-    prod.setAttribute("resource", url.path());
+    doc.appendChild(doc.importNode(xml, true));
+    QDomElement prod = doc.documentElement();
+    prod.setAttribute("type", (int) PLAYLIST);
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
+    prod.setAttribute("name", name);
     if (!group.isEmpty()) {
         prod.setAttribute("groupname", group);
         prod.setAttribute("groupid", groupId);
     }
-    KMimeType::Ptr type = KMimeType::findByUrl(url);
-    if (type->name().startsWith("image/")) {
-        prod.setAttribute("type", (int) IMAGE);
-        prod.setAttribute("in", "0");
-        prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
-    } else if (type->name() == "application/x-kdenlivetitle") {
-        // opening a title file
-        QDomDocument txtdoc("titledocument");
-        QFile txtfile(url.path());
-        if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
-            txtfile.close();
-            prod.setAttribute("type", (int) TEXT);
-            prod.setAttribute("resource", QString());
-            prod.setAttribute("xmldata", txtdoc.toString());
-            GenTime outPos(txtdoc.documentElement().attribute("out").toDouble() / 1000.0);
-            prod.setAttribute("transparency", 1);
-            prod.setAttribute("in", 0);
-            int out = (int) outPos.frames(m_doc->fps());
-            if (out > 0) prod.setAttribute("out", out);
-            else prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
-        } else txtfile.close();
-    }
     AddClipCommand *command = new AddClipCommand(m_doc, doc.documentElement(), QString::number(id), true);
     m_doc->commandStack()->push(command);
 }
 
-
 void ClipManager::slotAddColorClipFile(const QString name, const QString color, QString duration, const QString group, const QString &groupId)
 {
     QDomDocument doc;
@@ -361,7 +372,10 @@ void ClipManager::slotAddColorClipFile(const QString name, const QString color,
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration, const bool loop, const bool fade, const QString &luma_duration, const QString &luma_file, const int softness, QString group, const QString &groupId)
+void ClipManager::slotAddSlideshowClipFile(const QString name, const QString path, int count, const QString duration,
+                                           const bool loop, const bool crop, const bool fade,
+                                           const QString &luma_duration, const QString &luma_file, const int softness,
+                                           const QString &animation, QString group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
@@ -376,9 +390,11 @@ void ClipManager::slotAddSlideshowClipFile(const QString name, const QString pat
     prod.setAttribute("luma_duration", m_doc->getFramePos(luma_duration));
     prod.setAttribute("name", name);
     prod.setAttribute("loop", loop);
+    prod.setAttribute("crop", crop);
     prod.setAttribute("fade", fade);
     prod.setAttribute("softness", QString::number(softness));
     prod.setAttribute("luma_file", luma_file);
+    prod.setAttribute("animation", animation);
     if (!group.isEmpty()) {
         prod.setAttribute("groupname", group);
         prod.setAttribute("groupid", groupId);
@@ -518,11 +534,53 @@ QDomElement ClipManager::groupsXml() const
 
 void ClipManager::slotClipModified(const QString &path)
 {
-    //kDebug()<<"// CLIP: "<<path<<" WAS MODIFIED";
+    //kDebug() << "// CLIP: " << path << " WAS MODIFIED";
     const QList <DocClipBase *> list = getClipByResource(path);
     for (int i = 0; i < list.count(); i++) {
         DocClipBase *clip = list.at(i);
-        if (clip != NULL) emit reloadClip(clip->getId());
+        if (clip != NULL) {
+            QString id = clip->getId();
+            if (!m_modifiedClips.contains(id))
+                emit modifiedClip(id);
+            m_modifiedClips[id] = QTime::currentTime();
+        }
+    }
+    if (!m_modifiedTimer.isActive()) m_modifiedTimer.start();
+}
+
+void ClipManager::slotProcessModifiedClips()
+{
+    if (!m_modifiedClips.isEmpty()) {
+        QMapIterator<QString, QTime> i(m_modifiedClips);
+        while (i.hasNext()) {
+            i.next();
+            if (QTime::currentTime().msecsTo(i.value()) <= -1500) {
+                emit reloadClip(i.key());
+                m_modifiedClips.remove(i.key());
+                break;
+            }
+        }
+    }
+    if (m_modifiedClips.isEmpty()) m_modifiedTimer.stop();
+}
+
+void ClipManager::slotClipMissing(const QString &path)
+{
+    // kDebug() << "// CLIP: " << path << " WAS MISSING";
+    const QList <DocClipBase *> list = getClipByResource(path);
+    for (int i = 0; i < list.count(); i++) {
+        DocClipBase *clip = list.at(i);
+        if (clip != NULL) emit missingClip(clip->getId());
+    }
+}
+
+void ClipManager::slotClipAvailable(const QString &path)
+{
+    // kDebug() << "// CLIP: " << path << " WAS ADDED";
+    const QList <DocClipBase *> list = getClipByResource(path);
+    for (int i = 0; i < list.count(); i++) {
+        DocClipBase *clip = list.at(i);
+        if (clip != NULL) emit availableClip(clip->getId());
     }
 }
 
