@@ -21,11 +21,16 @@
 #ifndef CUSTOMTRACKVIEW_H
 #define CUSTOMTRACKVIEW_H
 
+#include <KPixmapCache>
+#include <KColorScheme>
+
 #include <QGraphicsView>
 #include <QGraphicsItemAnimation>
 #include <QTimeLine>
 #include <QMenu>
 #include <QUndoStack>
+#include <QMutex>
+#include <QWaitCondition>
 
 #include "kdenlivedoc.h"
 #include "docclipbase.h"
@@ -38,6 +43,7 @@ class AbstractClipItem;
 class AbstractGroupItem;
 class Transition;
 
+
 class CustomTrackView : public QGraphicsView
 {
     Q_OBJECT
@@ -51,7 +57,8 @@ public:
     virtual void mouseDoubleClickEvent(QMouseEvent *event);
     void addTrack(TrackInfo type, int ix = -1);
     void removeTrack(int ix);
-    void changeTrack(int ix, TrackInfo type);
+    /** @brief Makes the document use new track infos (name, type, ...). */
+    void configTracks(QList <TrackInfo> trackInfos);
     int cursorPos();
     void checkAutoScroll();
     void moveClip(const ItemInfo start, const ItemInfo end, bool refresh);
@@ -79,6 +86,7 @@ public:
     void activateMonitor();
     int duration() const;
     void deleteSelectedClips();
+    /** @brief Cuts all clips that are selected at the timeline cursor position. */
     void cutSelectedClips();
     void setContextMenu(QMenu *timeline, QMenu *clip, QMenu *transition, QActionGroup *clipTypeGroup, QMenu *markermenu);
     void checkTrackHeight();
@@ -90,31 +98,52 @@ public:
     double getSnapPointForPos(double pos);
     void editKeyFrame(const GenTime pos, const int track, const int index, const QString keyframes);
     bool findString(const QString &text);
+    void selectFound(QString track, QString pos);
     bool findNextString(const QString &text);
     void initSearchStrings();
     void clearSearchStrings();
+    QList<ItemInfo> findId(const QString &clipId);
     void clipStart();
     void clipEnd();
     void changeClipSpeed();
     void doChangeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, const double speed, const double oldspeed, int strobe, const QString &id);
+    /** @brief Sets the document as modified. */
     void setDocumentModified();
     void setInPoint();
     void setOutPoint();
+
+    /** @brief Prepares inserting space.
+    *
+    * Shows a dialog to configure length and track. */
     void slotInsertSpace();
+    /** @brief Prepares removing space. */
     void slotRemoveSpace();
     void insertSpace(QList<ItemInfo> clipsToMove, QList<ItemInfo> transToMove, int track, const GenTime duration, const GenTime offset);
     ClipItem *getActiveClipUnderCursor(bool allowOutsideCursor = false) const;
     void deleteTimelineTrack(int ix, TrackInfo trackinfo);
-    void changeTimelineTrack(int ix, TrackInfo trackinfo);
     void saveThumbnails();
     void autoTransition();
     QStringList getLadspaParams(QDomElement effect) const;
     void initCursorPos(int pos);
-    void lockTrack(int ix, bool lock);
+
+    /** @brief Locks or unlocks a track.
+    * @param ix number of track
+    * @param lock whether to lock or unlock
+    * @param requestUpdate (default = true) Whether to request an update of the icon in the track header
+    *
+    * Makes sure no clip on track to lock is selected. */
+    void lockTrack(int ix, bool lock, bool requestUpdate = true);
     void groupClips(bool group = true);
     void doGroupClips(QList <ItemInfo> clipInfos, QList <ItemInfo> transitionInfos, bool group);
     void loadGroups(const QDomNodeList groups);
+
+    /** @brief Creates SplitAudioCommands for selected clips. */
     void splitAudio();
+
+    /** @brief Seperates the audio of a clip to a audio track.
+    * @param pos Position of the clip to split
+    * @param track Track of the clip
+    * @param split Split or unsplit */
     void doSplitAudio(const GenTime &pos, int track, bool split);
     void setVideoOnly();
     void setAudioOnly();
@@ -125,21 +154,47 @@ public:
     void updateProjectFps();
     double fps() const;
     int selectedTrack() const;
-    void selectClip(bool add, bool group = false);
+    QStringList selectedClips() const;
+    QList<ClipItem *> selectedClipItems() const;
+
+    /** @brief Selects a clip.
+    * @param add Whether to select or deselect
+    * @param group (optional) Whether to add the clip to a group
+    * @param track (optional) The track of the clip (has to be combined with @param pos)
+    * @param pos (optional) The position of the clip (has to be combined with @param track) */
+    void selectClip(bool add, bool group = false, int track = -1, int pos = -1);
     void selectTransition(bool add, bool group = false);
     QStringList extractTransitionsLumas();
     void setEditMode(EDITMODE mode);
+
+    /** @brief Inserts @param clip.
+    * @param clip The clip to insert
+    * @param in The inpoint of the clip (crop from start)
+    * @param out The outpoint of the clip (crop from end)
+    *
+    * Inserts at the position of timeline cursor and selected track. */
     void insertClipCut(DocClipBase *clip, int in, int out);
     void clearSelection();
+    void editItemDuration();
+    void buildGuidesMenu(QMenu *goMenu) const;
+    KPixmapCache* pixmapCache;
+    /** update the timeline objects when palette changes */
+    void updatePalette();
+    /** @brief Returns true if a track has audio data on it.
+    * @param track The track number
+    *
+    * Check whether given track has a clip with audio in it. */
+    bool hasAudio(int track) const;
 
 public slots:
     void setCursorPos(int pos, bool seek = true);
     void moveCursorPos(int delta);
     void updateCursorPos();
-    void slotDeleteEffect(ClipItem *clip, QDomElement effect, bool affectGroup = true);
-    void slotChangeEffectState(ClipItem *clip, int effectPos, bool disable);
-    void slotChangeEffectPosition(ClipItem *clip, int currentPos, int newPos);
-    void slotUpdateClipEffect(ClipItem *clip, QDomElement oldeffect, QDomElement effect, int ix);
+    void slotDeleteEffect(ClipItem *clip, int track, QDomElement effect, bool affectGroup = true);
+    void slotChangeEffectState(ClipItem *clip, int track, int effectPos, bool disable);
+    void slotChangeEffectPosition(ClipItem *clip, int track, int currentPos, int newPos);
+    void slotUpdateClipEffect(ClipItem *clip, int track, QDomElement oldeffect, QDomElement effect, int ix);
+    void slotUpdateClipRegion(ClipItem *clip, int ix, QString region);
     void slotRefreshEffects(ClipItem *clip);
     void setDuration(int duration);
     void slotAddTransition(ClipItem* clip, ItemInfo transitionInfo, int endTrack, QDomElement transition = QDomElement());
@@ -163,20 +218,55 @@ public slots:
     void slotUpdateAllThumbs();
     void slotCheckPositionScrolling();
     void slotInsertTrack(int ix);
+
+    /** @brief Shows a dialog for selecting a track to delete.
+    * @param ix Number of the track, which should be pre-selected in the dialog */
     void slotDeleteTrack(int ix);
-    void slotChangeTrack(int ix);
+    /** @brief Shows the configure tracks dialog. */
+    void slotConfigTracks(int ix);
     void clipNameChanged(const QString id, const QString name);
     void slotTrackUp();
     void slotTrackDown();
     void slotSelectTrack(int ix);
     void insertZoneOverwrite(QStringList data, int in);
 
+    /** @brief Rebuilds a group to fit again after children changed.
+    * @param childTrack the track of one of the groups children
+    * @param childPos The position of the same child */
+    void rebuildGroup(int childTrack, GenTime childPos);
+    /** @brief Rebuilds a group to fit again after children changed.
+    * @param group The group to rebuild */
+    void rebuildGroup(AbstractGroupItem *group);
+
+    /** @brief Cuts a group into two parts.
+    * @param clips1 Clips before the cut
+    * @param transitions1 Transitions before the cut
+    * @param clipsCut Clips that need to be cut
+    * @param transitionsCut Transitions that need to be cut
+    * @param clips2 Clips behind the cut
+    * @param transitions2 Transitions behind the cut
+    * @param cutPos Absolute position of the cut
+    * @param cut true = cut, false = "uncut" */
+    void slotRazorGroup(QList <ItemInfo> clips1, QList <ItemInfo> transitions1, QList <ItemInfo> clipsCut, QList <ItemInfo> transitionsCut, QList <ItemInfo> clips2, QList <ItemInfo> transitions2, GenTime cutPos, bool cut);
+
+    /** @brief Add en effect to a track.
+    * @param effect The new effect xml
+    * @param ix The track index */
+    void slotAddTrackEffect(const QDomElement effect, int ix);
+
+    /** @brief Update the list of snap points (sticky timeline hotspots).
+    * @param selected The currently selected clip if any
+    * @param offsetList The list of points that should also snap (for example when movin a clip, start and end points should snap
+    * @param skipSelectedItems if true, the selected item start and end points will not be added to snap list */
+    void updateSnapPoints(AbstractClipItem *selected, QList <GenTime> offsetList = QList <GenTime> (), bool skipSelectedItems = false);
+
 protected:
     virtual void drawBackground(QPainter * painter, const QRectF & rect);
     //virtual void drawForeground ( QPainter * painter, const QRectF & rect );
     virtual void dragEnterEvent(QDragEnterEvent * event);
     virtual void dragMoveEvent(QDragMoveEvent * event);
     virtual void dragLeaveEvent(QDragLeaveEvent * event);
+    /** @brief Something has been dropped onto the timeline */
     virtual void dropEvent(QDropEvent * event);
     virtual void wheelEvent(QWheelEvent * e);
     virtual void keyPressEvent(QKeyEvent * event);
@@ -206,7 +296,7 @@ private:
     QPoint m_clickEvent;
     QList <CommentedTime> m_searchPoints;
     QList <Guide *> m_guides;
-    void updateSnapPoints(AbstractClipItem *selected, QList <GenTime> offsetList = QList <GenTime> (), bool skipSelectedItems = false);
+
     ClipItem *getClipItemAt(int pos, int track);
     ClipItem *getClipItemAt(GenTime pos, int track);
     ClipItem *getClipItemAtEnd(GenTime pos, int track);
@@ -248,6 +338,14 @@ private:
     int m_selectedTrack;
     int m_spacerOffset;
 
+    QMutex m_mutex;
+    QWaitCondition m_producerNotReady;
+    KStatefulBrush m_activeTrackBrush;
+
+    /** stores the state of the control modifier during mouse press.
+     * Will then be used to identify whether we resize a group or only one item of it. */
+    bool m_controlModifier;
+
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
     void updatePositionEffects(ClipItem * item, ItemInfo info);
@@ -275,6 +373,43 @@ private:
     /** Adjust keyframes when pasted to another clip */
     void adjustKeyfames(GenTime oldstart, GenTime newstart, GenTime duration, QDomElement xml);
 
+    /** @brief Removes the tip and stops the animation timer. */
+    void removeTipAnimation();
+    /** @brief Creates a new tip animation.
+    * @param clip clip to display the tip on
+    * @param mode operation mode for which the tip should be displayed
+    * @param size size of the tip */
+    void setTipAnimation(AbstractClipItem *clip, OPERATIONTYPE mode, const double size);
+
+    /** @brief Takes care of updating effects and attached transitions during a resize from start.
+    * @param item Item to resize
+    * @param oldInfo The item's info before resizement (set to item->info() is @param check true)
+    * @param pos New startPos
+    * @param check (optional, default = false) Whether to check for collisions
+    * @param command (optional) Will be used as parent command (for undo history) */
+    void prepareResizeClipStart(AbstractClipItem *item, ItemInfo oldInfo, int pos, bool check = false, QUndoCommand *command = NULL);
+
+    /** @brief Takes care of updating effects and attached transitions during a resize from end.
+    * @param item Item to resize
+    * @param oldInfo The item's info before resizement (set to item->info() is @param check true)
+    * @param pos New endPos
+    * @param check (optional, default = false) Whether to check for collisions
+    * @param command (optional) Will be used as parent command (for undo history) */
+    void prepareResizeClipEnd(AbstractClipItem *item, ItemInfo oldInfo, int pos, bool check = false, QUndoCommand *command = NULL);
+
+    /** @brief Collects information about the group's children to pass it on to RazorGroupCommand.
+    * @param group The group to cut
+    * @param cutPos The absolute position of the cut */
+    void razorGroup(AbstractGroupItem *group, GenTime cutPos);
+
+    /** @brief Gets the effect parameters that will be passed to Mlt. */
+    EffectsParameterList getEffectArgs(const QDomElement effect);
+
+    /** @brief Updates @param item's pan and zoom effect after resize or cut.
+     * @param item clip whose pan and zoom effect should be updated
+     * @param cutPos (optional) if clip was cut, cut position relative to the original's clip position */
+    void updatePanZoom(ClipItem *item, GenTime cutPos = GenTime());
+
 private slots:
     void slotRefreshGuides();
     void slotEnableRefresh();
@@ -284,6 +419,8 @@ private slots:
     void slotFetchNextThumbs();
     void checkTrackSequence(int track);
     void slotGoToMarker(QAction *action);
+    void slotResetMenuPosition();
+    void slotDoResetMenuPosition();
 
 signals:
     void cursorMoved(int, int);
@@ -301,6 +438,12 @@ signals:
     void updateClipMarkers(DocClipBase *);
     void updateTrackHeaders();
     void playMonitor();
+    /** @brief Monitor document changes (for example the presence of audio data in timeline for export widget.*/
+    void documentModified();
+    void forceClipProcessing(const QString &);
+    void showTrackEffects(int, TrackInfo);
+    /** @brief Update the track effect button that shows if a track has effects or not.*/
+    void updateTrackEffectState(int);
 };
 
 #endif
