@@ -150,6 +150,17 @@ bool EffectsList::hasKeyFrames(QDomElement effect)
     return false;
 }
 
+// static
+bool EffectsList::hasSimpleKeyFrames(QDomElement effect)
+{
+    QDomNodeList params = effect.elementsByTagName("parameter");
+    for (int i = 0; i < params.count(); i++) {
+        QDomElement e = params.item(i).toElement();
+        if (e.attribute("type") == "simplekeyframe") return true;
+    }
+    return false;
+}
+
 void EffectsList::clone(const EffectsList original)
 {
     setContent(original.toString());
@@ -188,6 +199,32 @@ QString EffectsList::parameter(QDomElement effect, const QString &name)
     return QString();
 }
 
+// static
+void EffectsList::setProperty(QDomElement effect, const QString &name, const QString &value)
+{
+    QDomNodeList params = effect.elementsByTagName("property");
+    for (int i = 0; i < params.count(); i++) {
+        QDomElement e = params.item(i).toElement();
+        if (e.attribute("name") == name) {
+            e.firstChild().setNodeValue(value);
+            break;
+        }
+    }
+}
+
+// static
+QString EffectsList::property(QDomElement effect, const QString &name)
+{
+    QDomNodeList params = effect.elementsByTagName("property");
+    for (int i = 0; i < params.count(); i++) {
+        QDomElement e = params.item(i).toElement();
+        if (e.attribute("name") == name) {
+            return e.firstChild().nodeValue();
+        }
+    }
+    return QString();
+}
+
 void EffectsList::append(QDomElement e)
 {
     m_baseElement.appendChild(importNode(e, true));
@@ -206,27 +243,28 @@ bool EffectsList::isEmpty() const
 const QDomElement EffectsList::at(int ix) const
 {
     QDomNodeList effects = m_baseElement.childNodes();
-    if (ix >= effects.count()) return QDomElement();
+    if (ix < 0 || ix >= effects.count()) return QDomElement();
     return effects.at(ix).toElement();
 }
 
 void EffectsList::removeAt(int ix)
 {
     QDomNodeList effects = m_baseElement.childNodes();
-    if (ix >= effects.count()) return;
+    if (ix < 0 || ix >= effects.count()) return;
     m_baseElement.removeChild(effects.at(ix));
 }
 
 QDomElement EffectsList::item(int ix)
 {
     QDomNodeList effects = m_baseElement.childNodes();
-    if (ix >= effects.count()) return QDomElement();
+    if (ix < 0 || ix >= effects.count()) return QDomElement();
     return effects.at(ix).toElement();
 }
 
 void EffectsList::insert(int ix, QDomElement effect)
 {
     QDomNodeList effects = m_baseElement.childNodes();
+    if (ix < 0) ix = 0;
     if (ix >= effects.count()) m_baseElement.appendChild(importNode(effect, true));
     else m_baseElement.insertBefore(importNode(effect, true), effects.at(ix));
 }
@@ -234,6 +272,7 @@ void EffectsList::insert(int ix, QDomElement effect)
 void EffectsList::replace(int ix, QDomElement effect)
 {
     QDomNodeList effects = m_baseElement.childNodes();
+    if (ix < 0) ix = 0;
     if (ix < effects.count()) m_baseElement.removeChild(effects.at(ix));
     if (ix == effects.count()) m_baseElement.appendChild(importNode(effect, true));
     else m_baseElement.insertBefore(importNode(effect, true), effects.at(ix));
