@@ -41,43 +41,54 @@ EffectsListView::EffectsListView(QWidget *parent) :
     lyr->addWidget(m_effectsList);
     lyr->setContentsMargins(0, 0, 0, 0);
     search_effect->setTreeWidget(m_effectsList);
+    search_effect->setToolTip(i18n("Search in the effect list"));
     buttonInfo->setIcon(KIcon("help-about"));
+    buttonInfo->setToolTip(i18n("Show/Hide the effect description"));
     setFocusPolicy(Qt::StrongFocus);
+    setFocusProxy(search_effect);
+    m_effectsList->setFocusProxy(search_effect);
 
-    if (KdenliveSettings::showeffectinfo()) {
+    if (KdenliveSettings::showeffectinfo())
         buttonInfo->setDown(true);
-    } else infopanel->hide();
+    else
+        infopanel->hide();
+
     menu->addAction(KIcon("edit-delete"), i18n("Delete effect"), this, SLOT(slotRemoveEffect()));
 
     connect(type_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(filterList(int)));
     connect(buttonInfo, SIGNAL(clicked()), this, SLOT(showInfoPanel()));
     connect(m_effectsList, SIGNAL(itemSelectionChanged()), this, SLOT(slotUpdateInfo()));
     connect(m_effectsList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotEffectSelected()));
-
+    connect(search_effect, SIGNAL(hiddenChanged(QTreeWidgetItem *, bool)), this, SLOT(slotUpdateSearch(QTreeWidgetItem *, bool)));
+    connect(search_effect, SIGNAL(textChanged(QString)), this, SLOT(slotAutoExpand(QString)));
     //m_effectsList->setCurrentRow(0);
 }
 
-
-void EffectsListView::focusInEvent(QFocusEvent * /*event*/)
-{
-    search_effect->setFocus();
-}
-
 void EffectsListView::filterList(int pos)
 {
-    QTreeWidgetItem *item;
-    QTreeWidgetItem *folder;
     for (int i = 0; i < m_effectsList->topLevelItemCount(); i++) {
-        folder = m_effectsList->topLevelItem(i);
+        QTreeWidgetItem *folder = m_effectsList->topLevelItem(i);
+        bool hideFolder = true;
         for (int j = 0; j < folder->childCount(); j++) {
-            item = folder->child(j);
-            if (pos == 0) item->setHidden(false);
-            else if (item->data(0, Qt::UserRole).toInt() == pos) item->setHidden(false);
-            else item->setHidden(true);
+            QTreeWidgetItem *item = folder->child(j);
+            if (pos == 0 || pos == item->data(0, Qt::UserRole).toInt()) {
+                item->setHidden(false);
+                hideFolder = false;
+            } else {
+                item->setHidden(true);
+            }
         }
+        // do not hide the folder if it's empty but "All" is selected
+        if (pos == 0)
+            hideFolder = false;
+        folder->setHidden(hideFolder);
     }
-    item = m_effectsList->currentItem();
-    /*if (item) {
+    // make sure we don't show anything not matching the search expression
+    search_effect->updateSearch();
+
+
+    /*item = m_effectsList->currentItem();
+    if (item) {
         if (item->isHidden()) {
             int i;
             for (i = 0; i < m_effectsList->count() && m_effectsList->item(i)->isHidden(); i++); //do nothing
@@ -88,21 +99,17 @@ void EffectsListView::filterList(int pos)
 
 void EffectsListView::showInfoPanel()
 {
-    if (infopanel->isVisible()) {
-        infopanel->setVisible(false);
-        buttonInfo->setDown(false);
-        KdenliveSettings::setShoweffectinfo(false);
-    } else {
-        infopanel->setVisible(true);
-        buttonInfo->setDown(true);
-        KdenliveSettings::setShoweffectinfo(true);
-    }
+    bool show = !infopanel->isVisible();
+    infopanel->setVisible(show);
+    buttonInfo->setDown(show);
+    KdenliveSettings::setShoweffectinfo(show);
 }
 
 void EffectsListView::slotEffectSelected()
 {
     QDomElement effect = m_effectsList->currentEffect();
-    if (!effect.isNull()) emit addEffect(effect);
+    if (!effect.isNull())
+        emit addEffect(effect);
 }
 
 void EffectsListView::slotUpdateInfo()
@@ -146,4 +153,37 @@ void EffectsListView::slotRemoveEffect()
     emit reloadEffects();
 }
 
+void EffectsListView::slotUpdateSearch(QTreeWidgetItem *item, bool hidden)
+{
+    if (!hidden) {
+        if (item->data(0, Qt::UserRole).toInt() == type_combo->currentIndex()) {
+            if (item->parent())
+                item->parent()->setHidden(false);
+        } else {
+            if (type_combo->currentIndex() != 0)
+                item->setHidden(true);
+        }
+    }
+}
+
+void EffectsListView::slotAutoExpand(QString text)
+{
+    search_effect->updateSearch();
+
+    for (int i = 0; i < m_effectsList->topLevelItemCount(); ++i) {
+        QTreeWidgetItem *folder = m_effectsList->topLevelItem(i);
+        bool expandFolder = false;
+        /*if (folder->isHidden())
+            continue;*/
+        if (!text.isEmpty()) {
+            for (int j = 0; j < folder->childCount(); j++) {
+                QTreeWidgetItem *item = folder->child(j);
+                if (!item->isHidden())
+                    expandFolder = true;
+            }
+        }
+        folder->setExpanded(expandFolder);
+    }
+}
+
 #include "effectslistview.moc"
