@@ -22,10 +22,11 @@
 #include "effectslist.h"
 #include "mainwindow.h"
 
-#include "KDebug"
+#include <KDebug>
+#include <KStandardDirs>
 
-#include "QApplication"
-#include "QMouseEvent"
+#include <QApplication>
+#include <QMouseEvent>
 #include <QMenu>
 
 
@@ -37,30 +38,50 @@ static const int EFFECT_FOLDER = 4;
 const int TypeRole = Qt::UserRole;
 const int IdRole = TypeRole + 1;
 
+
 EffectsListWidget::EffectsListWidget(QMenu *menu, QWidget *parent) :
         QTreeWidget(parent),
         m_menu(menu)
 {
-    //setSelectionMode(QAbstractItemView::ExtendedSelection);
-    //setDragDropMode(QAbstractItemView::DragDrop);
     setColumnCount(1);
-    setDropIndicatorShown(true);
-    setAlternatingRowColors(true);
     setDragEnabled(true);
-    setAcceptDrops(true);
+    setAcceptDrops(false);
     setHeaderHidden(true);
+    setFrameShape(QFrame::NoFrame);
+    setAutoFillBackground(false);
+    setRootIsDecorated(false);
+    //setSelectionMode(QAbstractItemView::ExtendedSelection);
+    setDragDropMode(QAbstractItemView::DragOnly);
+    QPalette p = palette();
+    p.setBrush(QPalette::Base, Qt::NoBrush);
+    setPalette(p);
     initList();
+    connect(this, SIGNAL(activated(const QModelIndex &)), this, SLOT(slotExpandItem(const QModelIndex &)));
 }
 
 EffectsListWidget::~EffectsListWidget()
 {
 }
 
+void EffectsListWidget::slotExpandItem(const QModelIndex & index)
+{
+    setExpanded(index, !isExpanded(index));
+}
+
 void EffectsListWidget::initList()
 {
-    clear();
-    QTreeWidgetItem *item;
+    QString current;
+    QString currentFolder;
+    QTreeWidgetItem *item = NULL;
     QTreeWidgetItem *parentItem;
+    bool found = false;
+
+    if (currentItem()) {
+        current = currentItem()->text(0);
+        if (currentItem()->parent()) currentFolder = currentItem()->parent()->text(0);
+        else if (currentItem()->data(0, TypeRole) ==  EFFECT_FOLDER)  currentFolder = currentItem()->text(0);
+    }
+
     QString effectName;
     QStringList effectInfo;
     KIcon videoIcon("kdenlive-show-video");
@@ -68,36 +89,69 @@ void EffectsListWidget::initList()
     KIcon customIcon("kdenlive-custom-effect");
     KIcon folderIcon("folder");
 
-    KSharedConfigPtr config = KSharedConfig::openConfig("kdenliveeffectscategoryrc");
-    KConfigGroup transConfig(config, "Category");
-    // read the entries
-    QMap< QString, QString > profiles = transConfig.entryMap();
-    QMapIterator<QString, QString> i(profiles);
+    QString effectCategory = KStandardDirs::locate("config", "kdenliveeffectscategory.rc");
+    QDomDocument doc;
+    QFile file(effectCategory);
+    doc.setContent(&file, false);
+    file.close();
     QList <QTreeWidgetItem *> folders;
-    while (i.hasNext()) {
-        i.next();
-        item = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n(i.key().toUtf8().data())));
-        item->setIcon(0, folderIcon);
-        item->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
-        item->setData(0, IdRole, i.value());
+    QStringList folderNames;
+    QDomNodeList groups = doc.documentElement().elementsByTagName("group");
+    for (int i = 0; i < groups.count(); i++) {
+        folderNames << groups.at(i).firstChild().firstChild().nodeValue();
+    }
+    for (int i = 0; i < topLevelItemCount(); i++) {
+        topLevelItem(i)->takeChildren();
+        QString currentName = topLevelItem(i)->text(0);
+        if (currentName != i18n("Misc") && currentName != i18n("Audio") && currentName != i18n("Custom") && !folderNames.contains(currentName)) {
+            takeTopLevelItem(i);
+            i--;
+        }
+    }
+
+    for (int i = 0; i < groups.count(); i++) {
+        item = findFolder(folderNames.at(i));
+        if (item) {
+            item->setData(0, IdRole, groups.at(i).toElement().attribute("list"));
+        } else {
+            item = new QTreeWidgetItem((QTreeWidget*)0, QStringList(folderNames.at(i)));
+            item->setIcon(0, folderIcon);
+            item->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+            item->setData(0, IdRole, groups.at(i).toElement().attribute("list"));
+            item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+            insertTopLevelItem(0, item);
+        }
         folders.append(item);
     }
-    QTreeWidgetItem *misc = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Misc")));
-    misc->setIcon(0, folderIcon);
-    misc->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
 
-    QTreeWidgetItem *audio = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Audio")));
-    audio->setIcon(0, folderIcon);
-    audio->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+    QTreeWidgetItem *misc = findFolder(i18n("Misc"));
+    if (misc == NULL) {
+        misc = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Misc")));
+        misc->setIcon(0, folderIcon);
+        misc->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+        misc->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+        insertTopLevelItem(0, misc);
+    }
 
-    QTreeWidgetItem *custom = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Custom")));
-    custom->setIcon(0, folderIcon);
-    custom->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+    QTreeWidgetItem *audio = findFolder(i18n("Audio"));
+    if (audio == NULL) {
+        audio = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Audio")));
+        audio->setIcon(0, folderIcon);
+        audio->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+        audio->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+        insertTopLevelItem(0, audio);
+    }
 
-    insertTopLevelItem(0, custom);
-    insertTopLevelItem(0, misc);
-    insertTopLevelItem(0, audio);
-    insertTopLevelItems(0, folders);
+    QTreeWidgetItem *custom = findFolder(i18n("Custom"));
+    if (custom == NULL) {
+        custom = new QTreeWidgetItem((QTreeWidget*)0, QStringList(i18n("Custom")));
+        custom->setIcon(0, folderIcon);
+        custom->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
+        custom->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+        insertTopLevelItem(0, custom);
+    }
+
+    //insertTopLevelItems(0, folders);
 
 
     int ct = MainWindow::videoEffects.count();
@@ -117,6 +171,10 @@ void EffectsListWidget::initList()
             item->setIcon(0, videoIcon);
             item->setData(0, TypeRole, QString::number((int) EFFECT_VIDEO));
             item->setData(0, IdRole, effectInfo);
+            if (item->text(0) == current) {
+                setCurrentItem(item);
+                found = true;
+            }
         }
     }
 
@@ -137,10 +195,15 @@ void EffectsListWidget::initList()
             item->setIcon(0, audioIcon);
             item->setData(0, TypeRole, QString::number((int) EFFECT_AUDIO));
             item->setData(0, IdRole, effectInfo);
+            if (item->text(0) == current) {
+                setCurrentItem(item);
+                found = true;
+            }
         }
     }
 
     ct = MainWindow::customEffects.count();
+    kDebug() << "--- REBUILDING;: " << ct;
     for (int ix = 0; ix < ct; ix ++) {
         effectInfo = MainWindow::customEffects.effectIdInfo(ix);
         if (!effectInfo.isEmpty()) {
@@ -148,12 +211,41 @@ void EffectsListWidget::initList()
             item->setIcon(0, customIcon);
             item->setData(0, TypeRole, QString::number((int) EFFECT_CUSTOM));
             item->setData(0, IdRole, effectInfo);
+            if (item->text(0) == current) {
+                setCurrentItem(item);
+                found = true;
+            }
         }
     }
+    if (!found && !currentFolder.isEmpty()) {
+        // previously selected effect was removed, focus on its parent folder
+        for (int i = 0; i < topLevelItemCount(); i++) {
+            if (topLevelItem(i)->text(0) == currentFolder) {
+                setCurrentItem(topLevelItem(i));
+                break;
+            }
+        }
+
+    }
     setSortingEnabled(true);
     sortByColumn(0, Qt::AscendingOrder);
 }
 
+QTreeWidgetItem *EffectsListWidget::findFolder(const QString name)
+{
+    QTreeWidgetItem *item = NULL;
+    QList<QTreeWidgetItem *> result = findItems(name, Qt::MatchExactly);
+    if (!result.isEmpty()) {
+        for (int j = 0; j < result.count(); j++) {
+            if (result.at(j)->data(0, TypeRole) ==  EFFECT_FOLDER) {
+                item = result.at(j);
+                break;
+            }
+        }
+    }
+    return item;
+}
+
 const QDomElement EffectsListWidget::currentEffect() const
 {
     return itemEffect(currentItem());
@@ -200,56 +292,33 @@ QString EffectsListWidget::currentInfo()
     return info;
 }
 
-// virtual
-void EffectsListWidget::mousePressEvent(QMouseEvent *event)
+//virtual
+QMimeData * EffectsListWidget::mimeData(const QList<QTreeWidgetItem *> list) const
 {
-    if (event->button() == Qt::LeftButton) {
-        m_DragStartPosition = event->pos();
-        m_dragStarted = true;
-    }
-    QTreeWidget::mousePressEvent(event);
-}
-
-// virtual
-void EffectsListWidget::mouseMoveEvent(QMouseEvent *event)
-{
-    if (!m_dragStarted) return;
-    if ((event->pos() - m_DragStartPosition).manhattanLength()
-            < QApplication::startDragDistance())
-        return;
-
-    {
-        QTreeWidgetItem *clickItem = itemAt(event->pos());
-        if (clickItem && clickItem->data(0, TypeRole).toInt() != (int)EFFECT_FOLDER) {
-            QDrag *drag = new QDrag(this);
-            QMimeData *mimeData = new QMimeData;
-            const QList <QTreeWidgetItem *>list = selectedItems();
-            QDomDocument doc;
-            foreach(QTreeWidgetItem *item, list) {
-                const QDomElement e = itemEffect(item);
-                if (!e.isNull()) doc.appendChild(doc.importNode(e, true));
-            }
-            QByteArray data;
-            data.append(doc.toString().toUtf8());
-            mimeData->setData("kdenlive/effectslist", data);
-            drag->setMimeData(mimeData);
-            //QPixmap pix = qVariantValue<QPixmap>(clickItem->data(Qt::DecorationRole));
-            //drag->setPixmap(pix);
-            //drag->setHotSpot(QPoint(0, 50));
-            drag->start(Qt::CopyAction);
+    QDomDocument doc;
+    foreach(QTreeWidgetItem *item, list) {
+        if (item->flags() & Qt::ItemIsDragEnabled) {
+            const QDomElement e = itemEffect(item);
+            if (!e.isNull()) doc.appendChild(doc.importNode(e, true));
         }
-        event->accept();
+    }
+    QMimeData *mime = new QMimeData;
+    QByteArray data;
+    data.append(doc.toString().toUtf8());
+    mime->setData("kdenlive/effectslist", data);
+    return mime;
+}
+
+//virtual
+void EffectsListWidget::dragMoveEvent(QDragMoveEvent *event)
+{
+    if (event->mimeData()->hasFormat("kdenlive/effectslist")) {
+        event->acceptProposedAction();
+    } else {
+        event->ignore();
     }
 }
 
-void EffectsListWidget::dragMoveEvent(QDragMoveEvent * event)
-{
-    event->setDropAction(Qt::CopyAction);
-    if (event->mimeData()->hasText()) {
-        event->acceptProposedAction();
-    }
-    //}
-}
 
 //virtual
 void EffectsListWidget::contextMenuEvent(QContextMenuEvent * event)
