@@ -19,36 +19,38 @@
 
 double GenTime::s_delta = 0.00001;
 
-/** Creates a time object, with a time of 0 seconds. */
 GenTime::GenTime()
 {
     m_time = 0.0;
 }
 
-/** Creates a time object, with time given in seconds. */
 GenTime::GenTime(double seconds)
 {
     m_time = seconds;
 }
 
-/** Creates a time object, by passing number of frames and how many frames per second */
 GenTime::GenTime(int frames, double framesPerSecond)
 {
     m_time = (double) frames / framesPerSecond;
 }
 
-/** Returns the time, in milliseconds */
+double GenTime::seconds() const
+{
+    return m_time;
+}
+
 double GenTime::ms() const
 {
     return m_time * 1000;
 }
 
-/** Returns the time in frames, after being given the number of frames per second */
 double GenTime::frames(double framesPerSecond) const
 {
     return floor(m_time * framesPerSecond + 0.5);
 }
 
-GenTime::~GenTime()
+GenTime& GenTime::roundNearestFrame(double framesPerSecond)
 {
-}
+    m_time = floor((m_time * framesPerSecond) + 0.5) / framesPerSecond;
+    return *this;
+}
\ No newline at end of file
