@@ -26,9 +26,10 @@
 #include <QGraphicsRectItem>
 #include <QMenu>
 #include <QInputDialog>
+#include <QTimer>
 
 
-Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, int startPoint, QWidget* parent) :
+Geometryval::Geometryval(const MltVideoProfile profile, Timecode t, QPoint frame_size, int startPoint, QWidget* parent) :
         QWidget(parent),
         m_profile(profile),
         m_paramRect(NULL),
@@ -36,9 +37,13 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, int s
         m_path(NULL),
         m_fixedMode(false),
         m_frameSize(frame_size),
-        m_startPoint(startPoint)
+        m_startPoint(startPoint),
+        m_timePos(t)
 {
     setupUi(this);
+    toolbarlayout->addWidget(&m_timePos);
+    toolbarlayout->insertStretch(-1);
+
     QVBoxLayout* vbox = new QVBoxLayout(widget);
     m_sceneview = new QGraphicsView(this);
     m_sceneview->setBackgroundBrush(QBrush(Qt::black));
@@ -77,31 +82,16 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, int s
     buttonDelete->setToolTip(i18n("Delete keyframe"));
 
     m_configMenu = new QMenu(i18n("Misc..."), this);
-    buttonMenu->setIcon(KIcon("system-run"));
     buttonMenu->setMenu(m_configMenu);
-    buttonMenu->setPopupMode(QToolButton::QToolButton::InstantPopup);
+    buttonMenu->setPopupMode(QToolButton::MenuButtonPopup);
 
+    m_editOptions = m_configMenu->addAction(KIcon("system-run"), i18n("Show/Hide options"));
+    m_editOptions->setCheckable(true);
+    buttonMenu->setDefaultAction(m_editOptions);
+    connect(m_editOptions, SIGNAL(triggered()), this, SLOT(slotSwitchOptions()));
+    slotSwitchOptions();
 
-    m_editGeom = m_configMenu->addAction(i18n("Edit keyframe"), this, SLOT(slotGeometry()));
-
-    m_scaleMenu = new QMenu(i18n("Resize..."), this);
-    m_configMenu->addMenu(m_scaleMenu);
-    m_scaleMenu->addAction(i18n("50%"), this, SLOT(slotResize50()));
-    m_scaleMenu->addAction(i18n("100%"), this, SLOT(slotResize100()));
-    m_scaleMenu->addAction(i18n("200%"), this, SLOT(slotResize200()));
-    m_scaleMenu->addAction(i18n("Original size"), this, SLOT(slotResizeOriginal()));
-    m_scaleMenu->addAction(i18n("Custom"), this, SLOT(slotResizeCustom()));
-
-    m_alignMenu = new QMenu(i18n("Align..."), this);
-    m_configMenu->addMenu(m_alignMenu);
-    m_alignMenu->addAction(i18n("Center"), this, SLOT(slotAlignCenter()));
-    m_alignMenu->addAction(i18n("Hor. Center"), this, SLOT(slotAlignHCenter()));
-    m_alignMenu->addAction(i18n("Vert. Center"), this, SLOT(slotAlignVCenter()));
-    m_alignMenu->addAction(i18n("Right"), this, SLOT(slotAlignRight()));
-    m_alignMenu->addAction(i18n("Left"), this, SLOT(slotAlignLeft()));
-    m_alignMenu->addAction(i18n("Top"), this, SLOT(slotAlignTop()));
-    m_alignMenu->addAction(i18n("Bottom"), this, SLOT(slotAlignBottom()));
-
+    m_reset = m_configMenu->addAction(KIcon("view-refresh"), i18n("Reset"), this, SLOT(slotResetPosition()));
 
     m_syncAction = m_configMenu->addAction(i18n("Sync timeline cursor"), this, SLOT(slotSyncCursor()));
     m_syncAction->setCheckable(true);
@@ -120,17 +110,40 @@ Geometryval::Geometryval(const MltVideoProfile profile, QPoint frame_size, int s
     connect(buttonDelete , SIGNAL(clicked()) , this , SLOT(slotDeleteFrame()));
     connect(buttonAdd , SIGNAL(clicked()) , this , SLOT(slotAddFrame()));
     connect(m_scene, SIGNAL(actionFinished()), this, SLOT(slotUpdateTransitionProperties()));
-    connect(m_scene, SIGNAL(doubleClickEvent()), this, SLOT(slotGeometry()));
 
+    buttonhcenter->setIcon(KIcon("kdenlive-align-hor"));
+    buttonhcenter->setToolTip(i18n("Align item horizontally"));
+    buttonvcenter->setIcon(KIcon("kdenlive-align-vert"));
+    buttonvcenter->setToolTip(i18n("Align item vertically"));
+    buttontop->setIcon(KIcon("kdenlive-align-top"));
+    buttontop->setToolTip(i18n("Align item to top"));
+    buttonbottom->setIcon(KIcon("kdenlive-align-bottom"));
+    buttonbottom->setToolTip(i18n("Align item to bottom"));
+    buttonright->setIcon(KIcon("kdenlive-align-right"));
+    buttonright->setToolTip(i18n("Align item to right"));
+    buttonleft->setIcon(KIcon("kdenlive-align-left"));
+    buttonleft->setToolTip(i18n("Align item to left"));
+
+    connect(buttonhcenter, SIGNAL(clicked()), this, SLOT(slotAlignHCenter()));
+    connect(buttonvcenter, SIGNAL(clicked()), this, SLOT(slotAlignVCenter()));
+    connect(buttontop, SIGNAL(clicked()), this, SLOT(slotAlignTop()));
+    connect(buttonbottom, SIGNAL(clicked()), this, SLOT(slotAlignBottom()));
+    connect(buttonright, SIGNAL(clicked()), this, SLOT(slotAlignRight()));
+    connect(buttonleft, SIGNAL(clicked()), this, SLOT(slotAlignLeft()));
+    connect(spinX, SIGNAL(valueChanged(int)), this, SLOT(slotGeometryX(int)));
+    connect(spinY, SIGNAL(valueChanged(int)), this, SLOT(slotGeometryY(int)));
+    connect(spinWidth, SIGNAL(valueChanged(int)), this, SLOT(slotGeometryWidth(int)));
+    connect(spinHeight, SIGNAL(valueChanged(int)), this, SLOT(slotGeometryHeight(int)));
+    connect(spinResize, SIGNAL(editingFinished()), this, SLOT(slotResizeCustom()));
+    connect(buttonResize, SIGNAL(clicked()), this, SLOT(slotResizeOriginal()));
+
+    connect(this, SIGNAL(parameterChanged()), this, SLOT(slotUpdateGeometry()));
 }
 
 
 Geometryval::~Geometryval()
 {
     m_scene->disconnect();
-    delete m_scaleMenu;
-    delete m_alignMenu;
-    delete m_editGeom;
     delete m_syncAction;
     delete m_configMenu;
     delete m_paramRect;
@@ -142,170 +155,77 @@ Geometryval::~Geometryval()
 }
 
 
-void Geometryval::slotAlignCenter()
-{
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
-        return;
-    }
-    m_paramRect->setPos((m_realWidth - m_paramRect->rect().width()) / 2, (m_profile.height - m_paramRect->rect().height()) / 2);
-    slotUpdateTransitionProperties();
-}
-
 void Geometryval::slotAlignHCenter()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos((m_realWidth - m_paramRect->rect().width()) / 2, m_paramRect->pos().y());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignVCenter()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos(m_paramRect->pos().x(), (m_profile.height - m_paramRect->rect().height()) / 2);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignTop()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos(m_paramRect->pos().x(), 0);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignBottom()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos(m_paramRect->pos().x(), m_profile.height - m_paramRect->rect().height());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignLeft()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos(0, m_paramRect->pos().y());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotAlignRight()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
     m_paramRect->setPos(m_realWidth - m_paramRect->rect().width(), m_paramRect->pos().y());
     slotUpdateTransitionProperties();
 }
 
-void Geometryval::slotResize50()
-{
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
-        return;
-    }
-    m_paramRect->setRect(0, 0, m_realWidth / 2, m_profile.height / 2);
-    slotUpdateTransitionProperties();
-}
-
-void Geometryval::slotResize100()
-{
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
-        return;
-    }
-    m_paramRect->setRect(0, 0, m_realWidth, m_profile.height);
-    slotUpdateTransitionProperties();
-}
-
-void Geometryval::slotResize200()
-{
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
-        return;
-    }
-    m_paramRect->setRect(0, 0, m_realWidth * 2, m_profile.height * 2);
-    slotUpdateTransitionProperties();
-}
-
 void Geometryval::slotResizeOriginal()
 {
-    if (m_frameSize.isNull()) slotResize100();
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
-    m_paramRect->setRect(0, 0, m_frameSize.x(), m_frameSize.y());
+    if (m_frameSize.isNull())
+        m_paramRect->setRect(0, 0, m_realWidth, m_profile.height);
+    else
+        m_paramRect->setRect(0, 0, m_frameSize.x(), m_frameSize.y());
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotResizeCustom()
 {
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
+    if (!keyframeSelected())
         return;
-    }
-    int scale = m_paramRect->rect().width() * 100 / m_realWidth;
-    bool ok;
-    scale =  QInputDialog::getInteger(this, i18n("Resize..."), i18n("Scale"), scale, 1, 2147483647, 10, &ok);
-    if (!ok) return;
-    m_paramRect->setRect(0, 0, m_realWidth * scale / 100, m_profile.height * scale / 100);
+    int value = spinResize->value();
+    m_paramRect->setRect(0, 0, m_realWidth * value / 100, m_profile.height * value / 100);
     slotUpdateTransitionProperties();
 }
 
 void Geometryval::slotTransparencyChanged(int transp)
 {
-    int pos = spinPos->value();
+    int pos = m_timePos.getValue();
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -323,11 +243,22 @@ void Geometryval::slotSyncCursor()
     KdenliveSettings::setTransitionfollowcursor(m_syncAction->isChecked());
 }
 
+void Geometryval::updateTimecodeFormat()
+{
+    m_timePos.slotUpdateTimeCodeFormat();
+}
+
 void Geometryval::slotPositionChanged(int pos, bool seek)
 {
+    if (pos == -1) {
+        pos = m_timePos.getValue();
+    }
     if (seek && KdenliveSettings::transitionfollowcursor()) emit seekToPos(pos + m_startPoint);
-    spinPos->setValue(pos);
+    m_timePos.setValue(pos);
+    //spinPos->setValue(pos);
+    m_helper->blockSignals(true);
     m_helper->setValue(pos);
+    m_helper->blockSignals(false);
     Mlt::GeometryItem item;
     int error = m_geom->fetch(&item, pos);
     if (error || item.key() == false) {
@@ -336,44 +267,44 @@ void Geometryval::slotPositionChanged(int pos, bool seek)
         buttonDelete->setEnabled(false);
         widget->setEnabled(false);
         spinTransp->setEnabled(false);
-        m_scaleMenu->setEnabled(false);
-        m_alignMenu->setEnabled(false);
-        m_editGeom->setEnabled(false);
+        frameOptions->setEnabled(false);
+        m_reset->setEnabled(false);
     } else {
         buttonAdd->setEnabled(false);
         buttonDelete->setEnabled(true);
         widget->setEnabled(true);
         spinTransp->setEnabled(true);
-        m_scaleMenu->setEnabled(true);
-        m_alignMenu->setEnabled(true);
-        m_editGeom->setEnabled(true);
+        frameOptions->setEnabled(true);
+        m_reset->setEnabled(true);
     }
 
     m_paramRect->setPos(item.x() * m_dar, item.y());
     m_paramRect->setRect(0, 0, item.w() * m_dar, item.h());
     spinTransp->setValue(item.mix());
     m_paramRect->setBrush(QColor(255, 0, 0, item.mix()));
+    slotUpdateGeometry();
 }
 
 void Geometryval::slotDeleteFrame(int pos)
 {
     // check there is more than one keyframe
     Mlt::GeometryItem item;
-    if (pos == -1) pos = spinPos->value();
+    int frame = m_timePos.getValue();
+
+    if (pos == -1) pos = frame;
     int error = m_geom->next_key(&item, pos + 1);
     if (error) {
         error = m_geom->prev_key(&item, pos - 1);
         if (error || item.frame() == pos) return;
     }
 
-    m_geom->remove(spinPos->value());
+    m_geom->remove(frame);
     buttonAdd->setEnabled(true);
     buttonDelete->setEnabled(false);
     widget->setEnabled(false);
     spinTransp->setEnabled(false);
-    m_scaleMenu->setEnabled(false);
-    m_alignMenu->setEnabled(false);
-    m_editGeom->setEnabled(false);
+    frameOptions->setEnabled(false);
+    m_reset->setEnabled(false);
     m_helper->update();
     slotPositionChanged(pos, false);
     updateTransitionPath();
@@ -382,7 +313,8 @@ void Geometryval::slotDeleteFrame(int pos)
 
 void Geometryval::slotAddFrame(int pos)
 {
-    if (pos == -1) pos = spinPos->value();
+    int frame = m_timePos.getValue();
+    if (pos == -1) pos = frame;
     Mlt::GeometryItem item;
     item.frame(pos);
     QRectF r = m_paramRect->rect().normalized();
@@ -397,9 +329,8 @@ void Geometryval::slotAddFrame(int pos)
     buttonDelete->setEnabled(true);
     widget->setEnabled(true);
     spinTransp->setEnabled(true);
-    m_scaleMenu->setEnabled(true);
-    m_alignMenu->setEnabled(true);
-    m_editGeom->setEnabled(true);
+    frameOptions->setEnabled(true);
+    m_reset->setEnabled(true);
     m_helper->update();
     emit parameterChanged();
 }
@@ -408,14 +339,14 @@ void Geometryval::slotNextFrame()
 {
     Mlt::GeometryItem item;
     int error = m_geom->next_key(&item, m_helper->value() + 1);
+    int pos;
     kDebug() << "// SEEK TO NEXT KFR: " << error;
     if (error) {
         // Go to end
-        spinPos->setValue(spinPos->maximum());
-        return;
-    }
-    int pos = item.frame();
-    spinPos->setValue(pos);
+        pos = m_helper->frameLength;
+    } else pos = item.frame();
+    m_timePos.setValue(pos);
+    slotPositionChanged();
 }
 
 void Geometryval::slotPreviousFrame()
@@ -425,7 +356,8 @@ void Geometryval::slotPreviousFrame()
     kDebug() << "// SEEK TO NEXT KFR: " << error;
     if (error) return;
     int pos = item.frame();
-    spinPos->setValue(pos);
+    m_timePos.setValue(pos);
+    slotPositionChanged();
 }
 
 
@@ -446,8 +378,11 @@ void Geometryval::setupParam(const QDomElement par, int minFrame, int maxFrame)
         spinTransp->setMaximum(500);
         label_pos->setHidden(true);
         m_helper->setHidden(true);
-        spinPos->setHidden(true);
-
+        m_timePos.setHidden(true);
+    }
+    if (par.attribute("opacity") == "false") {
+        label_opacity->setHidden(true);
+        spinTransp->setHidden(true);
     }
     char *tmp = (char *) qstrdup(val.toUtf8().data());
     if (m_geom) m_geom->parse(tmp, maxFrame - minFrame, m_profile.width, m_profile.height);
@@ -462,7 +397,6 @@ void Geometryval::setupParam(const QDomElement par, int minFrame, int maxFrame)
         /*QDomDocument doc;
         doc.appendChild(doc.importNode(par, true));
         kDebug() << "IMPORTED TRANS: " << doc.toString();*/
-        spinPos->setMaximum(maxFrame - minFrame - 1);
         if (m_path == NULL) {
             m_path = new QGraphicsPathItem();
             m_path->setPen(QPen(Qt::red));
@@ -482,12 +416,24 @@ void Geometryval::setupParam(const QDomElement par, int minFrame, int maxFrame)
     m_paramRect->setPen(QPen(QBrush(QColor(255, 0, 0, 255)), 1.0));
     m_scene->addItem(m_paramRect);
     slotPositionChanged(0, false);
+    slotUpdateGeometry();
     if (!m_fixedMode) {
-        connect(spinPos, SIGNAL(valueChanged(int)), this , SLOT(slotPositionChanged(int)));
+        m_timePos.setRange(0, maxFrame - minFrame - 1);
+        connect(&m_timePos, SIGNAL(editingFinished()), this , SLOT(slotPositionChanged()));
     }
     connect(spinTransp, SIGNAL(valueChanged(int)), this , SLOT(slotTransparencyChanged(int)));
 }
 
+void Geometryval::slotSyncPosition(int relTimelinePos)
+{
+    if (m_timePos.maximum() > 0 && KdenliveSettings::transitionfollowcursor()) {
+        relTimelinePos = qMax(0, relTimelinePos);
+        relTimelinePos = qMin(relTimelinePos, m_timePos.maximum());
+        if (relTimelinePos != m_timePos.getValue())
+            slotPositionChanged(relTimelinePos, false);
+    }
+}
+
 void Geometryval::updateTransitionPath()
 {
     if (m_fixedMode) return;
@@ -511,7 +457,7 @@ void Geometryval::updateTransitionPath()
 
 void Geometryval::slotUpdateTransitionProperties()
 {
-    int pos = spinPos->value();
+    int pos = m_timePos.getValue();
     Mlt::GeometryItem item;
     int error = m_geom->next_key(&item, pos);
     if (error || item.frame() != pos) {
@@ -529,53 +475,17 @@ void Geometryval::slotUpdateTransitionProperties()
     emit parameterChanged();
 }
 
-void Geometryval::slotGeometry()
-{
-    int pos = spinPos->value();
-    Mlt::GeometryItem item;
-    int error = m_geom->fetch(&item, pos);
-    if (error || item.key() == false) {
-        // no keyframe under cursor
-        return;
-    }
-    QRectF r = m_paramRect->rect().normalized();
-
-    QDialog d(this);
-    m_view.setupUi(&d);
-    d.setWindowTitle(i18n("Frame Geometry"));
-    m_view.value_x->setMaximum(10000);
-    m_view.value_x->setMinimum(-10000);
-    m_view.value_y->setMaximum(10000);
-    m_view.value_y->setMinimum(-10000);
-    m_view.value_width->setMaximum(500000);
-    m_view.value_width->setMinimum(1);
-    m_view.value_height->setMaximum(500000);
-    m_view.value_height->setMinimum(1);
-
-    m_view.value_x->setValue(m_paramRect->pos().x());
-    m_view.value_y->setValue(m_paramRect->pos().y());
-    m_view.value_width->setValue(r.width());
-    m_view.value_height->setValue(r.height());
-    connect(m_view.button_reset , SIGNAL(clicked()) , this , SLOT(slotResetPosition()));
-
-    if (d.exec() == QDialog::Accepted) {
-        m_paramRect->setPos(m_view.value_x->value(), m_view.value_y->value());
-        m_paramRect->setRect(0, 0, m_view.value_width->value(), m_view.value_height->value());
-        slotUpdateTransitionProperties();
-    }
-}
-
 void Geometryval::slotResetPosition()
 {
-    m_view.value_x->setValue(0);
-    m_view.value_y->setValue(0);
+    spinX->setValue(0);
+    spinY->setValue(0);
 
     if (m_frameSize.isNull()) {
-        m_view.value_width->setValue(m_realWidth);
-        m_view.value_height->setValue(m_profile.height);
+        spinWidth->setValue(m_realWidth);
+        spinHeight->setValue(m_profile.height);
     } else {
-        m_view.value_width->setValue(m_frameSize.x());
-        m_view.value_height->setValue(m_frameSize.y());
+        spinWidth->setValue(m_frameSize.x());
+        spinHeight->setValue(m_frameSize.y());
     }
 }
 
@@ -589,5 +499,83 @@ void Geometryval::slotKeyframeMoved(int pos)
 {
     slotPositionChanged(pos);
     slotUpdateTransitionProperties();
+    QTimer::singleShot(100, this, SIGNAL(parameterChanged()));
 }
 
+void Geometryval::slotSwitchOptions()
+{
+    if (frameOptions->isHidden()) {
+        frameOptions->setHidden(false);
+        m_editOptions->setChecked(true);
+    } else {
+        frameOptions->setHidden(true);
+        m_editOptions->setChecked(false);
+    }
+    //adjustSize();
+}
+
+void Geometryval::slotGeometryX(int value)
+{
+    if (!keyframeSelected())
+        return;
+    m_paramRect->setPos(value, spinY->value());
+    slotUpdateTransitionProperties();
+}
+
+void Geometryval::slotGeometryY(int value)
+{
+    if (!keyframeSelected())
+        return;
+    m_paramRect->setPos(spinX->value(), value);
+    slotUpdateTransitionProperties();
+}
+
+void Geometryval::slotGeometryWidth(int value)
+{
+    if (!keyframeSelected())
+        return;
+    m_paramRect->setRect(0, 0, value, spinHeight->value());
+    slotUpdateTransitionProperties();
+}
+
+void Geometryval::slotGeometryHeight(int value)
+{
+    if (!keyframeSelected())
+        return;
+    m_paramRect->setRect(0, 0, spinWidth->value(), value);
+    slotUpdateTransitionProperties();
+}
+
+void Geometryval::slotUpdateGeometry()
+{
+    QRectF r = m_paramRect->rect().normalized();
+
+    spinX->blockSignals(true);
+    spinY->blockSignals(true);
+    spinWidth->blockSignals(true);
+    spinHeight->blockSignals(true);
+    spinResize->blockSignals(true);
+
+    spinX->setValue(m_paramRect->pos().x());
+    spinY->setValue(m_paramRect->pos().y());
+    spinWidth->setValue(r.width());
+    spinHeight->setValue(r.height());
+    spinResize->setValue(m_paramRect->rect().width() * 100 / m_realWidth);
+
+    spinX->blockSignals(false);
+    spinY->blockSignals(false);
+    spinWidth->blockSignals(false);
+    spinHeight->blockSignals(false);
+    spinResize->blockSignals(false);
+}
+
+bool Geometryval::keyframeSelected()
+{
+    Mlt::GeometryItem item;
+    int pos = m_timePos.getValue();
+    if (m_geom->fetch(&item, pos) || item.key() == false) return false;
+    return true;
+}
+
+
+
