@@ -54,9 +54,13 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
     // Hide multi tab option until Kdenlive really supports it
     m_configMisc.kcfg_activatetabs->setVisible(false);
 
+    QWidget *p8 = new QWidget;
+    m_configProject.setupUi(p8);
+    m_page8 = addPage(p8, i18n("Project Defaults"), "document-new");
+
     QWidget *p3 = new QWidget;
-    m_configDisplay.setupUi(p3);
-    m_page3 = addPage(p3, i18n("Display"), "video-display");
+    m_configTimeline.setupUi(p3);
+    m_page3 = addPage(p3, i18n("Timeline"), "video-display");
 
     QWidget *p2 = new QWidget;
     m_configEnv.setupUi(p2);
@@ -121,6 +125,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
 
     connect(m_configCapture.kcfg_video4vdevice, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
     connect(m_configCapture.kcfg_video4adevice, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
+    connect(m_configCapture.kcfg_video4vcodec, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
+    connect(m_configCapture.kcfg_video4acodec, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
     connect(m_configCapture.kcfg_video4vformat, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
     connect(m_configCapture.kcfg_video4aformat, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
     connect(m_configCapture.kcfg_video4size, SIGNAL(editingFinished()), this, SLOT(rebuildVideo4Commands()));
@@ -140,7 +146,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
 
     connect(m_configSdl.kcfg_audio_driver, SIGNAL(currentIndexChanged(int)), this, SLOT(slotCheckAlsaDriver()));
     initDevices();
-    connect(m_configMisc.kcfg_profiles_list, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDisplay()));
+    connect(m_configProject.kcfg_profiles_list, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateDisplay()));
     connect(m_configCapture.kcfg_rmd_capture_type, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateRmdRegionStatus()));
 
     slotUpdateRmdRegionStatus();
@@ -180,8 +186,10 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
         QString rmdpath = KStandardDirs::findExe("recordmydesktop");
         KdenliveSettings::setRmd_path(rmdpath);
     }
-    if (KdenliveSettings::rmd_path().isEmpty()) m_configCapture.rmd_info->setText(i18n("<strong><em>Recordmydesktop</em> utility not found, please install it for screen grabs</strong>"));
-    else m_configCapture.rmd_info->setText(i18n("Recordmydesktop found at: %1", KdenliveSettings::rmd_path()));
+    if (KdenliveSettings::rmd_path().isEmpty())
+        m_configCapture.rmd_info->setText(i18n("<strong><em>Recordmydesktop</em> utility not found, please install it for screen grabs</strong>"));
+    else
+        m_configCapture.rmd_info->setText(i18n("Recordmydesktop found at: %1", KdenliveSettings::rmd_path()));
 }
 
 KdenliveSettingsDialog::~KdenliveSettingsDialog() {}
@@ -193,18 +201,18 @@ void KdenliveSettingsDialog::slotUpdateRmdRegionStatus()
 
 void KdenliveSettingsDialog::checkProfile()
 {
-    m_configMisc.kcfg_profiles_list->clear();
+    m_configProject.kcfg_profiles_list->clear();
     QMap <QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
     QMapIterator<QString, QString> i(profilesInfo);
     while (i.hasNext()) {
         i.next();
-        m_configMisc.kcfg_profiles_list->addItem(i.key(), i.value());
+        m_configProject.kcfg_profiles_list->addItem(i.key(), i.value());
     }
 
     if (!KdenliveSettings::default_profile().isEmpty()) {
-        for (int i = 0; i < m_configMisc.kcfg_profiles_list->count(); i++) {
-            if (m_configMisc.kcfg_profiles_list->itemData(i).toString() == KdenliveSettings::default_profile()) {
-                m_configMisc.kcfg_profiles_list->setCurrentIndex(i);
+        for (int i = 0; i < m_configProject.kcfg_profiles_list->count(); i++) {
+            if (m_configProject.kcfg_profiles_list->itemData(i).toString() == KdenliveSettings::default_profile()) {
+                m_configProject.kcfg_profiles_list->setCurrentIndex(i);
                 KdenliveSettings::setProfiles_list(i);
                 break;
             }
@@ -405,9 +413,9 @@ void KdenliveSettingsDialog::slotUpdateShuttleDevice(int ix)
 void KdenliveSettingsDialog::rebuildVideo4Commands()
 {
     QString captureCommand;
-    if (!m_configCapture.kcfg_video4adevice->text().isEmpty()) captureCommand = "-f " + m_configCapture.kcfg_video4aformat->text() + " -i " + m_configCapture.kcfg_video4adevice->text();
+    if (!m_configCapture.kcfg_video4adevice->text().isEmpty()) captureCommand = "-f " + m_configCapture.kcfg_video4aformat->text() + " -i " + m_configCapture.kcfg_video4adevice->text() + " -acodec " + m_configCapture.kcfg_video4acodec->text();
 
-    captureCommand +=  " -f " + m_configCapture.kcfg_video4vformat->text() + " -s " + m_configCapture.kcfg_video4size->text() + " -r " + QString::number(m_configCapture.kcfg_video4rate->value()) + " -i " + m_configCapture.kcfg_video4vdevice->text();
+    captureCommand +=  " -f " + m_configCapture.kcfg_video4vformat->text() + " -s " + m_configCapture.kcfg_video4size->text() + " -r " + QString::number(m_configCapture.kcfg_video4rate->value()) + " -i " + m_configCapture.kcfg_video4vdevice->text() + " -vcodec " + m_configCapture.kcfg_video4vcodec->text();
     m_configCapture.kcfg_video4capture->setText(captureCommand);
 }
 
@@ -416,7 +424,7 @@ void KdenliveSettingsDialog::updateSettings()
 {
     //kDebug() << "// // // KCONFIG UPDATE called";
 
-    m_defaultProfile = m_configMisc.kcfg_profiles_list->currentText();
+    m_defaultProfile = m_configProject.kcfg_profiles_list->currentText();
     KdenliveSettings::setDefault_profile(m_defaultPath);
 
     bool resetProfile = false;
@@ -475,6 +483,16 @@ void KdenliveSettingsDialog::updateSettings()
         resetProfile = true;
     }
 
+    if (m_configSdl.kcfg_window_background->color() != KdenliveSettings::window_background()) {
+        KdenliveSettings::setWindow_background(m_configSdl.kcfg_window_background->color());
+        resetProfile = true;
+    }
+
+    if (m_configSdl.kcfg_volume->value() != KdenliveSettings::volume()) {
+        KdenliveSettings::setVolume(m_configSdl.kcfg_volume->value());
+        resetProfile = true;
+    }
+
     bool updatePreview = false;
     if (m_configSdl.kcfg_dropbframes->isChecked() != KdenliveSettings::dropbframes()) {
         KdenliveSettings::setDropbframes(m_configSdl.kcfg_dropbframes->isChecked());
@@ -498,15 +516,17 @@ void KdenliveSettingsDialog::updateSettings()
 
 void KdenliveSettingsDialog::slotUpdateDisplay()
 {
-    QString currentProfile = m_configMisc.kcfg_profiles_list->itemData(m_configMisc.kcfg_profiles_list->currentIndex()).toString();
+    QString currentProfile = m_configProject.kcfg_profiles_list->itemData(m_configProject.kcfg_profiles_list->currentIndex()).toString();
     QMap< QString, QString > values = ProfilesDialog::getSettingsFromFile(currentProfile);
-    m_configMisc.p_size->setText(values.value("width") + 'x' + values.value("height"));
-    m_configMisc.p_fps->setText(values.value("frame_rate_num") + '/' + values.value("frame_rate_den"));
-    m_configMisc.p_aspect->setText(values.value("sample_aspect_num") + '/' + values.value("sample_aspect_den"));
-    m_configMisc.p_display->setText(values.value("display_aspect_num") + '/' + values.value("display_aspect_den"));
-    if (values.value("progressive").toInt() == 0) m_configMisc.p_progressive->setText(i18n("Interlaced"));
-    else m_configMisc.p_progressive->setText(i18n("Progressive"));
-    m_defaultProfile = m_configMisc.kcfg_profiles_list->itemText(m_configMisc.kcfg_profiles_list->currentIndex());
+    m_configProject.p_size->setText(values.value("width") + 'x' + values.value("height"));
+    m_configProject.p_fps->setText(values.value("frame_rate_num") + '/' + values.value("frame_rate_den"));
+    m_configProject.p_aspect->setText(values.value("sample_aspect_num") + '/' + values.value("sample_aspect_den"));
+    m_configProject.p_display->setText(values.value("display_aspect_num") + '/' + values.value("display_aspect_den"));
+    if (values.value("progressive").toInt() == 0)
+        m_configProject.p_progressive->setText(i18n("Interlaced"));
+    else
+        m_configProject.p_progressive->setText(i18n("Progressive"));
+    m_defaultProfile = m_configProject.kcfg_profiles_list->itemText(m_configProject.kcfg_profiles_list->currentIndex());
     m_defaultPath = currentProfile;
 }
 
