@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "keyframeedit.h"
+#include "doubleparameterwidget.h"
 #include "kdenlivesettings.h"
 
 #include <KDebug>
@@ -23,7 +24,6 @@
 
 #include <QHeaderView>
 
-
 KeyframeEdit::KeyframeEdit(QDomElement e, int minFrame, int maxFrame, int minVal, int maxVal, Timecode tc, int active_keyframe, QWidget* parent) :
         QWidget(parent),
         m_min(minFrame),
@@ -36,6 +36,14 @@ KeyframeEdit::KeyframeEdit(QDomElement e, int minFrame, int maxFrame, int minVal
 {
     kDebug() << " / / / /MODIFIED KFR: " << m_active_keyframe;
     setupUi(this);
+    if (m_max == -1) {
+        // special case: keyframe for tracks, do not allow keyframes
+        button_add->setEnabled(false);
+        button_delete->setEnabled(false);
+        keyframe_seek->setEnabled(false);
+        label->setHidden(true);
+        keyframe_pos->setHidden(true);
+    }
     m_params.append(e.cloneNode().toElement());
     keyframe_list->setFont(KGlobalSettings::generalFont());
     keyframe_seek->setChecked(KdenliveSettings::keyframeseek());
@@ -62,6 +70,8 @@ KeyframeEdit::KeyframeEdit(QDomElement e, int minFrame, int maxFrame, int minVal
         keyframe_list->setCurrentCell(0, 0);
         keyframe_list->selectRow(0);
     }
+    // ensure the keyframe list shows at least 3 lines
+    keyframe_list->setMinimumHeight(QFontInfo(keyframe_list->font()).pixelSize() * 9);
     /*m_delegate = new KeyItemDelegate(minVal, maxVal);
     keyframe_list->setItemDelegate(m_delegate);*/
 }
@@ -74,7 +84,8 @@ KeyframeEdit::~KeyframeEdit()
     while ((child = m_slidersLayout->takeAt(0)) != 0) {
         QWidget *wid = child->widget();
         delete child;
-        if (wid) delete wid;
+        if (wid)
+            delete wid;
     }
     //delete m_delegate;
 }
@@ -88,11 +99,12 @@ void KeyframeEdit::addParameter(QDomElement e)
     int columnId = keyframe_list->columnCount();
     keyframe_list->insertColumn(columnId);
     keyframe_list->setHorizontalHeaderItem(columnId, new QTableWidgetItem(paramName));
-    m_slidersLayout->addWidget(new QLabel(paramName), columnId, 0);
-    QSlider *sl = new QSlider(Qt::Horizontal, this);
-    sl->setRange(m_params.at(columnId).attribute("min").toInt(), m_params.at(columnId).attribute("max").toInt());
-    connect(sl, SIGNAL(valueChanged(int)), this, SLOT(slotAdjustKeyframeValue(int)));
-    m_slidersLayout->addWidget(sl, columnId, 1);
+
+    DoubleParameterWidget *doubleparam = new DoubleParameterWidget(paramName, 0,
+            m_params.at(columnId).attribute("min").toInt(), m_params.at(columnId).attribute("max").toInt(),
+            m_params.at(columnId).attribute("default").toInt(), m_params.at(columnId).attribute("suffix"), this);
+    connect(doubleparam, SIGNAL(valueChanged(int)), this, SLOT(slotAdjustKeyframeValue(int)));
+    m_slidersLayout->addWidget(doubleparam, columnId, 0);
 
     QStringList frames = e.attribute("keyframes").split(";", QString::SkipEmptyParts);
     for (int i = 0; i < frames.count(); i++) {
@@ -100,9 +112,7 @@ void KeyframeEdit::addParameter(QDomElement e)
         bool found = false;
         int j;
         for (j = 0; j < keyframe_list->rowCount(); j++) {
-            int currentPos;
-            if (KdenliveSettings::frametimecode()) currentPos = keyframe_list->verticalHeaderItem(j)->text().toInt();
-            else currentPos = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(j)->text());
+            int currentPos = getPos(j);
             if (frame == currentPos) {
                 keyframe_list->setItem(j, columnId, new QTableWidgetItem(frames.at(i).section(':', 1, 1)));
                 found = true;
@@ -113,10 +123,7 @@ void KeyframeEdit::addParameter(QDomElement e)
         }
         if (!found) {
             keyframe_list->insertRow(j);
-            QString currentPos;
-            if (KdenliveSettings::frametimecode()) currentPos = QString::number(frame);
-            else currentPos = m_timecode.getTimecodeFromFrames(frame);
-            keyframe_list->setVerticalHeaderItem(j, new QTableWidgetItem(currentPos));
+            keyframe_list->setVerticalHeaderItem(j, new QTableWidgetItem(getPosString(frame)));
             keyframe_list->setItem(j, columnId, new QTableWidgetItem(frames.at(i).section(':', 1, 1)));
             keyframe_list->resizeRowToContents(j);
         }
@@ -136,24 +143,23 @@ void KeyframeEdit::setupParam()
     kDebug() << " INSERT COL: " << col << ", " << paramName;
     keyframe_list->insertColumn(col);
     keyframe_list->setHorizontalHeaderItem(col, new QTableWidgetItem(paramName));
-    m_slidersLayout = new QGridLayout;
-    m_slidersLayout->addWidget(new QLabel(paramName), 0, 0);
-    QSlider *sl = new QSlider(Qt::Horizontal, this);
-    sl->setRange(m_params.at(0).attribute("min").toInt(), m_params.at(0).attribute("max").toInt());
-    connect(sl, SIGNAL(valueChanged(int)), this, SLOT(slotAdjustKeyframeValue(int)));
-    m_slidersLayout->addWidget(sl, 0, 1);
-    param_sliders->setLayout(m_slidersLayout);
+    m_slidersLayout = new QGridLayout(param_sliders);
+
+    DoubleParameterWidget *doubleparam = new DoubleParameterWidget(paramName, 0,
+            m_params.at(0).attribute("min").toInt(), m_params.at(0).attribute("max").toInt(),
+            m_params.at(0).attribute("default").toInt(), m_params.at(0).attribute("suffix"), this);
+    connect(doubleparam, SIGNAL(valueChanged(int)), this, SLOT(slotAdjustKeyframeValue(int)));
+    m_slidersLayout->addWidget(doubleparam, 0, 0);
+
     keyframe_list->setSelectionBehavior(QAbstractItemView::SelectRows);
     keyframe_list->setSelectionMode(QAbstractItemView::SingleSelection);
 
     QStringList frames = m_params.at(0).attribute("keyframes").split(";", QString::SkipEmptyParts);
+    setEnabled(frames.count() > 0);
     for (int i = 0; i < frames.count(); i++) {
         keyframe_list->insertRow(i);
         int currentpos = frames.at(i).section(':', 0, 0).toInt();
-        QString framePos;
-        if (KdenliveSettings::frametimecode()) framePos  = QString::number(currentpos);
-        else framePos = m_timecode.getTimecodeFromFrames(currentpos);
-        keyframe_list->setVerticalHeaderItem(i, new QTableWidgetItem(framePos));
+        keyframe_list->setVerticalHeaderItem(i, new QTableWidgetItem(getPosString(currentpos)));
         keyframe_list->setItem(i, col, new QTableWidgetItem(frames.at(i).section(':', 1, 1)));
         if ((m_active_keyframe > -1) && (m_active_keyframe == currentpos)) {
             keyframe_list->setCurrentCell(i, 0);
@@ -171,7 +177,8 @@ void KeyframeEdit::setupParam()
 
 void KeyframeEdit::slotDeleteKeyframe()
 {
-    if (keyframe_list->rowCount() < 2) return;
+    if (keyframe_list->rowCount() < 2)
+        return;
     int col = keyframe_list->currentColumn();
     int row = keyframe_list->currentRow();
     keyframe_list->removeRow(keyframe_list->currentRow());
@@ -189,17 +196,12 @@ void KeyframeEdit::slotAddKeyframe()
     int row = keyframe_list->currentRow();
     int col = keyframe_list->currentColumn();
     int newrow = row;
-    int pos1;
-    if (KdenliveSettings::frametimecode()) pos1 = keyframe_list->verticalHeaderItem(row)->text().toInt();
-    else pos1 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(row)->text());
+    int pos1 = getPos(row);
 
     int result;
     kDebug() << "// ADD KF: " << row << ", MAX: " << keyframe_list->rowCount() << ", POS: " << pos1;
     if (row < (keyframe_list->rowCount() - 1)) {
-        int pos2;
-        if (KdenliveSettings::frametimecode()) pos2 = keyframe_list->verticalHeaderItem(row + 1)->text().toInt();
-        else pos2 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(row + 1)->text());
-        result = pos1 + (pos2 - pos1) / 2;
+        result = pos1 + (getPos(row + 1) - pos1) / 2;
         newrow++;
     } else if (row == 0) {
         if (pos1 == m_min) {
@@ -209,20 +211,15 @@ void KeyframeEdit::slotAddKeyframe()
             result = m_min;
         }
     } else {
-        int pos2;
-        if (KdenliveSettings::frametimecode()) pos2 = keyframe_list->verticalHeaderItem(row - 1)->text().toInt();
-        else pos2 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(row - 1)->text());
+        int pos2 = getPos(row - 1);
         result = pos2 + (pos1 - pos2) / 2;
     }
 
     keyframe_list->insertRow(newrow);
-    QString currentPos;
-    if (KdenliveSettings::frametimecode()) currentPos = QString::number(result);
-    else currentPos = m_timecode.getTimecodeFromFrames(result);
-    keyframe_list->setVerticalHeaderItem(newrow, new QTableWidgetItem(currentPos));
-    for (int i = 0; i < keyframe_list->columnCount(); i++) {
+    keyframe_list->setVerticalHeaderItem(newrow, new QTableWidgetItem(getPosString(result)));
+    for (int i = 0; i < keyframe_list->columnCount(); i++)
         keyframe_list->setItem(newrow, i, new QTableWidgetItem(keyframe_list->item(item->row(), i)->text()));
-    }
+
     keyframe_list->resizeRowsToContents();
     //keyframe_list->resizeRowToContents(newrow);
     slotAdjustKeyframeInfo();
@@ -239,37 +236,29 @@ void KeyframeEdit::slotGenerateParams(int row, int column)
     if (column == -1) {
         // position of keyframe changed
         QTableWidgetItem *item = keyframe_list->item(row, 0);
-        if (item == NULL) return;
-        QString val = keyframe_list->verticalHeaderItem(row)->text();
-        int pos;
-        if (KdenliveSettings::frametimecode()) pos = val.toInt();
-        else pos = m_timecode.getFrameCount(val);
+        if (item == NULL)
+            return;
 
-        if (pos <= m_min) {
+        int pos = getPos(row);
+        if (pos <= m_min)
             pos = m_min;
-            if (KdenliveSettings::frametimecode()) val = QString::number(pos);
-            else val = m_timecode.getTimecodeFromFrames(pos);
-        }
-        if (pos > m_max) {
+        if (m_max != -1 && pos > m_max)
             pos = m_max;
-            if (KdenliveSettings::frametimecode()) val = QString::number(pos);
-            else val = m_timecode.getTimecodeFromFrames(pos);
-        }
-        if (val != keyframe_list->verticalHeaderItem(row)->text()) keyframe_list->verticalHeaderItem(row)->setText(val);
+        QString val = getPosString(pos);
+        if (val != keyframe_list->verticalHeaderItem(row)->text())
+            keyframe_list->verticalHeaderItem(row)->setText(val);
 
         for (int col = 0; col < keyframe_list->horizontalHeader()->count(); col++) {
             item = keyframe_list->item(row, col);
             int v = item->text().toInt();
-            if (v >= m_params.at(col).attribute("max").toInt()) item->setText(m_params.at(col).attribute("max"));
-            if (v <= m_params.at(col).attribute("min").toInt()) item->setText(m_params.at(col).attribute("min"));
+            if (v >= m_params.at(col).attribute("max").toInt())
+                item->setText(m_params.at(col).attribute("max"));
+            if (v <= m_params.at(col).attribute("min").toInt())
+                item->setText(m_params.at(col).attribute("min"));
             QString keyframes;
             for (int i = 0; i < keyframe_list->rowCount(); i++) {
-                if (keyframe_list->item(i, col)) {
-                    int pos3;
-                    if (KdenliveSettings::frametimecode()) pos3 = keyframe_list->verticalHeaderItem(i)->text().toInt();
-                    else pos3 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(i)->text());
-                    keyframes.append(QString::number(pos3) + ':' + keyframe_list->item(i, col)->text() + ';');
-                }
+                if (keyframe_list->item(i, col))
+                    keyframes.append(QString::number(getPos(i)) + ':' + keyframe_list->item(i, col)->text() + ';');
             }
             m_params[col].setAttribute("keyframes", keyframes);
         }
@@ -279,44 +268,35 @@ void KeyframeEdit::slotGenerateParams(int row, int column)
 
     }
     QTableWidgetItem *item = keyframe_list->item(row, column);
-    if (item == NULL) return;
-    QString val = keyframe_list->verticalHeaderItem(row)->text();
-    ;
-    int pos;
-    if (KdenliveSettings::frametimecode()) pos = val.toInt();
-    else pos = m_timecode.getFrameCount(val);
+    if (item == NULL)
+        return;
 
-    if (pos <= m_min) {
+    int pos = getPos(row);
+    if (pos <= m_min)
         pos = m_min;
-        if (KdenliveSettings::frametimecode()) val = QString::number(pos);
-        else val = m_timecode.getTimecodeFromFrames(pos);
-    }
-    if (pos > m_max) {
+    if (m_max != -1 && pos > m_max)
         pos = m_max;
-        if (KdenliveSettings::frametimecode()) val = QString::number(pos);
-        else val = m_timecode.getTimecodeFromFrames(pos);
-    }
     /*QList<QTreeWidgetItem *> duplicates = keyframe_list->findItems(val, Qt::MatchExactly, 0);
     duplicates.removeAll(item);
     if (!duplicates.isEmpty()) {
         // Trying to insert a keyframe at existing value, revert it
         val = m_timecode.getTimecodeFromFrames(m_previousPos);
     }*/
-    if (val != keyframe_list->verticalHeaderItem(row)->text()) keyframe_list->verticalHeaderItem(row)->setText(val);
+    QString val = getPosString(pos);
+    if (val != keyframe_list->verticalHeaderItem(row)->text())
+        keyframe_list->verticalHeaderItem(row)->setText(val);
 
     int v = item->text().toInt();
-    if (v >= m_params.at(column).attribute("max").toInt()) item->setText(m_params.at(column).attribute("max"));
-    if (v <= m_params.at(column).attribute("min").toInt()) item->setText(m_params.at(column).attribute("min"));
+    if (v >= m_params.at(column).attribute("max").toInt())
+        item->setText(m_params.at(column).attribute("max"));
+    if (v <= m_params.at(column).attribute("min").toInt())
+        item->setText(m_params.at(column).attribute("min"));
     slotAdjustKeyframeInfo(false);
 
     QString keyframes;
     for (int i = 0; i < keyframe_list->rowCount(); i++) {
-        if (keyframe_list->item(i, column)) {
-            int pos3;
-            if (KdenliveSettings::frametimecode()) pos3 = keyframe_list->verticalHeaderItem(i)->text().toInt();
-            else pos3 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(i)->text());
-            keyframes.append(QString::number(pos3) + ':' + keyframe_list->item(i, column)->text() + ';');
-        }
+        if (keyframe_list->item(i, column))
+            keyframes.append(QString::number(getPos(i)) + ':' + keyframe_list->item(i, column)->text() + ';');
     }
     m_params[column].setAttribute("keyframes", keyframes);
     emit parameterChanged();
@@ -327,12 +307,8 @@ void KeyframeEdit::generateAllParams()
     for (int col = 0; col < keyframe_list->columnCount(); col++) {
         QString keyframes;
         for (int i = 0; i < keyframe_list->rowCount(); i++) {
-            if (keyframe_list->item(i, col)) {
-                int pos3;
-                if (KdenliveSettings::frametimecode()) pos3 = keyframe_list->verticalHeaderItem(i)->text().toInt();
-                else pos3 = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(i)->text());
-                keyframes.append(QString::number(pos3) + ':' + keyframe_list->item(i, col)->text() + ';');
-            }
+            if (keyframe_list->item(i, col))
+                keyframes.append(QString::number(getPos(i)) + ':' + keyframe_list->item(i, col)->text() + ';');
         }
         m_params[col].setAttribute("keyframes", keyframes);
     }
@@ -344,8 +320,9 @@ const QString KeyframeEdit::getValue(const QString &name)
     for (int col = 0; col < keyframe_list->columnCount(); col++) {
         QDomNode na = m_params.at(col).firstChildElement("name");
         QString paramName = i18n(na.toElement().text().toUtf8().data());
-        kDebug() << paramName << " == " << name;
-        if (paramName == name) return m_params.at(col).attribute("keyframes");
+        //kDebug() << paramName << " == " << name;
+        if (paramName == name)
+            return m_params.at(col).attribute("keyframes");
     }
     return QString();
 }
@@ -353,71 +330,93 @@ const QString KeyframeEdit::getValue(const QString &name)
 void KeyframeEdit::slotAdjustKeyframeInfo(bool seek)
 {
     QTableWidgetItem *item = keyframe_list->currentItem();
-    if (!item) return;
+    if (!item)
+        return;
     int min = m_min;
     int max = m_max;
     QTableWidgetItem *above = keyframe_list->item(item->row() - 1, item->column());
     QTableWidgetItem *below = keyframe_list->item(item->row() + 1, item->column());
-    if (above) {
-        if (KdenliveSettings::frametimecode()) min = keyframe_list->verticalHeaderItem(above->row())->text().toInt();
-        else min = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(above->row())->text());
-        min++;
-    }
-    if (below) {
-        if (KdenliveSettings::frametimecode()) max = keyframe_list->verticalHeaderItem(below->row())->text().toInt();
-        else max = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(below->row())->text());
-        max--;
-    }
+    if (above)
+        min = getPos(above->row()) + 1;
+    if (below)
+        max = getPos(below->row()) - 1;
+
     keyframe_pos->blockSignals(true);
     keyframe_pos->setRange(min, max);
-    int pos;
-    if (KdenliveSettings::frametimecode()) pos = keyframe_list->verticalHeaderItem(item->row())->text().toInt();
-    else pos = m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(item->row())->text());
-
-    keyframe_pos->setValue(pos);
+    keyframe_pos->setValue(getPos(item->row()));
     keyframe_pos->blockSignals(false);
     for (int col = 0; col < keyframe_list->columnCount(); col++) {
-        QSlider *sl = static_cast <QSlider*>(m_slidersLayout->itemAtPosition(col, 1)->widget());
-        if (!sl) continue;
-        sl->blockSignals(true);
-        sl->setValue(keyframe_list->item(item->row(), col)->text().toInt());
-        sl->blockSignals(false);
+        DoubleParameterWidget *doubleparam = static_cast <DoubleParameterWidget*>(m_slidersLayout->itemAtPosition(col, 0)->widget());
+        if (!doubleparam)
+            continue;
+        doubleparam->blockSignals(true);
+        if (keyframe_list->item(item->row(), col)) {
+            doubleparam->setValue(keyframe_list->item(item->row(), col)->text().toInt());
+        } else {
+            kDebug() << "Null pointer exception caught: http://www.kdenlive.org/mantis/view.php?id=1771";
+        }
+        doubleparam->blockSignals(false);
     }
-    if (KdenliveSettings::keyframeseek() && seek) emit seekToPos(keyframe_pos->value() - m_min);
+    if (KdenliveSettings::keyframeseek() && seek)
+        emit seekToPos(keyframe_pos->value() - m_min);
 }
 
 void KeyframeEdit::slotAdjustKeyframePos(int value)
 {
     QTableWidgetItem *item = keyframe_list->currentItem();
-    QString val;
-    if (KdenliveSettings::frametimecode()) val = QString::number(value);
-    else val = m_timecode.getTimecodeFromFrames(value);
-    keyframe_list->verticalHeaderItem(item->row())->setText(val);
+    keyframe_list->verticalHeaderItem(item->row())->setText(getPosString(value));
     slotGenerateParams(item->row(), -1);
-    if (KdenliveSettings::keyframeseek()) emit seekToPos(value - m_min);
+    if (KdenliveSettings::keyframeseek())
+        emit seekToPos(value - m_min);
 }
 
 void KeyframeEdit::slotAdjustKeyframeValue(int /*value*/)
 {
     QTableWidgetItem *item = keyframe_list->currentItem();
     for (int col = 0; col < keyframe_list->columnCount(); col++) {
-        QSlider *sl = static_cast <QSlider*>(m_slidersLayout->itemAtPosition(col, 1)->widget());
-        if (!sl) continue;
-        int val = sl->value();
+        DoubleParameterWidget *doubleparam = static_cast <DoubleParameterWidget*>(m_slidersLayout->itemAtPosition(col, 0)->widget());
+        if (!doubleparam)
+            continue;
+        int val = doubleparam->getValue();
         QTableWidgetItem *nitem = keyframe_list->item(item->row(), col);
-        if (nitem->text().toInt() != val) {
+        if (nitem->text().toInt() != val)
             nitem->setText(QString::number(val));
-        }
     }
     //keyframe_list->item(item->row() - 1, item->column());
 
 }
 
+int KeyframeEdit::getPos(int row)
+{
+    if (KdenliveSettings::frametimecode())
+        return keyframe_list->verticalHeaderItem(row)->text().toInt();
+    else
+        return m_timecode.getFrameCount(keyframe_list->verticalHeaderItem(row)->text());
+}
+
+QString KeyframeEdit::getPosString(int pos)
+{
+    if (KdenliveSettings::frametimecode())
+        return QString::number(pos);
+    else
+        return m_timecode.getTimecodeFromFrames(pos);
+}
+
 void KeyframeEdit::slotSetSeeking(int state)
 {
     KdenliveSettings::setKeyframeseek(state == Qt::Checked);
 }
 
+void KeyframeEdit::updateTimecodeFormat()
+{
+    for (int row = 0; row < keyframe_list->rowCount(); ++row) {
+        QString pos = keyframe_list->verticalHeaderItem(row)->text();
+        if (KdenliveSettings::frametimecode())
+            keyframe_list->verticalHeaderItem(row)->setText(QString::number(m_timecode.getFrameCount(pos)));
+        else
+            keyframe_list->verticalHeaderItem(row)->setText(m_timecode.getTimecodeFromFrames(pos.toInt()));
+    }
+}
 
 /*void KeyframeEdit::slotSaveCurrentParam(QTreeWidgetItem *item, int column)
 {
