@@ -33,6 +33,7 @@ class KeyframeHelper : public QWidget
 public:
     KeyframeHelper(QWidget *parent = 0);
     int value() const;
+    int frameLength;
 
 protected:
     virtual void paintEvent(QPaintEvent * /*e*/);
@@ -44,12 +45,12 @@ protected:
 
 private:
     Mlt::Geometry *m_geom;
-    int m_length;
     int m_position;
     double m_scale;
     bool m_movingKeyframe;
     Mlt::GeometryItem m_movingItem;
     QPoint m_dragStart;
+    int m_lineHeight;
 
 public slots:
     void setKeyGeometry(Mlt::Geometry *geom, const int length);
