@@ -34,13 +34,15 @@ int main(int argc, char *argv[])
                          ki18n("Kdenlive"), VERSION,
                          ki18n("An open source video editor."),
                          KAboutData::License_GPL,
-                         ki18n("Copyright (c) 2009 Development team"));
-    aboutData.addAuthor(ki18n("Jean-Baptiste Mardelle"), ki18n("MLT porting, KDE 4 porting, Main developer"), "jb@kdenlive.org");
-    aboutData.addAuthor(ki18n("Marco Gittler"), ki18n("MLT Connection, Transition, Effect, Timeline Developer"), "g.marco@freenet.de");
+                         ki18n("Copyright © 2007–2010 Kdenlive authors"));
+    aboutData.addAuthor(ki18n("Jean-Baptiste Mardelle"), ki18n("MLT and KDE SC 4 porting, main developer and maintainer"), "jb@kdenlive.org");
+    aboutData.addAuthor(ki18n("Marco Gittler"), ki18n("MLT transitions and effects, timeline, audio thumbs"), "g.marco@freenet.de");
+    aboutData.addAuthor(ki18n("Dan Dennedy"), ki18n("Bug fixing, etc."), "dan@dennedy.org");
+    aboutData.addAuthor(ki18n("Simon A. Eugster"), ki18n("Color scopes, bug fixing, etc."), "simon.eu@gmail.com");
+    aboutData.addAuthor(ki18n("Till Theato"), ki18n("Bug fixing, etc."), "root@ttill.de");
+    aboutData.addAuthor(ki18n("Alberto Villa"), ki18n("Bug fixing, logo, etc."), "avilla@FreeBSD.org");
     aboutData.addAuthor(ki18n("Jean-Michel Poure"), ki18n("Rendering profiles customization"), "jm@poure.com");
     aboutData.addAuthor(ki18n("Ray Lehtiniemi"), ki18n("Bug fixing, etc."), "rayl@mail.com");
-    aboutData.addAuthor(ki18n("Dan Dennedy"), ki18n("Bug fixing, etc."), "dan@dennedy.org");
-    aboutData.addAuthor(ki18n("Simon A. Eugster"), ki18n("Bug fixing, etc."), "simon.eu@gmail.com");
     aboutData.addAuthor(ki18n("Jason Wood"), ki18n("Original KDE 3 version author (not active anymore)"), "jasonwood@blueyonder.co.uk");
     aboutData.setHomepage("http://kdenlive.org");
     aboutData.setCustomAuthorText(ki18n("Please report bugs to http://kdenlive.org/mantis"), ki18n("Please report bugs to <a href=\"http://kdenlive.org/mantis\">http://kdenlive.org/mantis</a>"));
@@ -55,6 +57,7 @@ int main(int argc, char *argv[])
     KCmdLineArgs::addCmdLineOptions(options); //new
 
     KApplication app;
+    MainWindow* window = 0;
 
     // see if we are starting with session management
     if (app.isSessionRestored()) {
@@ -62,8 +65,8 @@ int main(int argc, char *argv[])
         while (KMainWindow::canBeRestored(n)) {
             const QString className = KXmlGuiWindow::classNameOfToplevel(n);
             if (className == QLatin1String("MainWindow")) {
-                MainWindow* win = new MainWindow();
-                win->restore(n);
+                window = new MainWindow();
+                window->restore(n);
             } else {
                 kWarning() << "Unknown class " << className << " in session saved data!";
             }
@@ -77,11 +80,15 @@ int main(int argc, char *argv[])
         if (args->count()) {
             url = args->url(0);
         }
-        MainWindow* window = new MainWindow(mltPath, url);
+        window = new MainWindow(mltPath, url);
         window->show();
 
         args->clear();
     }
 
-    return app.exec();
+    int result = app.exec();
+#ifdef Q_WS_MAC
+    delete window;
+#endif
+    return result;
 }
