@@ -23,6 +23,7 @@
 #include "monitormanager.h"
 #include "smallruler.h"
 #include "docclipbase.h"
+#include "monitorscene.h"
 #include "kdenlivesettings.h"
 
 #include <KDebug>
@@ -39,6 +40,8 @@
 #include <QDesktopWidget>
 #include <QLabel>
 #include <QIntValidator>
+#include <QVBoxLayout>
+#include <QGraphicsView>
 
 
 Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget *parent) :
@@ -52,7 +55,9 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
         m_isActive(false),
         m_scale(1),
         m_length(0),
-        m_dragStarted(false)
+        m_dragStarted(false),
+        m_effectScene(NULL),
+        m_effectView(NULL)
 {
     m_ui.setupUi(this);
     QVBoxLayout *layout = new QVBoxLayout;
@@ -71,10 +76,12 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
     if (name != "chapter") {
         toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
         toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
-    } else m_ruler->setZone(-3, -2);
+    } else {
+        m_ruler->setZone(-3, -2);
+    }
 
     toolbar->addAction(KIcon("media-seek-backward"), i18n("Rewind"), this, SLOT(slotRewind()));
-    toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
+    //toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
 
     QToolButton *playButton = new QToolButton(toolbar);
     m_playMenu = new QMenu(i18n("Play..."), this);
@@ -86,7 +93,7 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
     playButton->setPopupMode(QToolButton::MenuButtonPopup);
     toolbar->addWidget(playButton);
 
-    toolbar->addAction(KIcon("media-skip-forward"), i18n("Forward 1 frame"), this, SLOT(slotForwardOneFrame()));
+    //toolbar->addAction(KIcon("media-skip-forward"), i18n("Forward 1 frame"), this, SLOT(slotForwardOneFrame()));
     toolbar->addAction(KIcon("media-seek-forward"), i18n("Forward"), this, SLOT(slotForward()));
 
     playButton->setDefaultAction(m_playAction);
@@ -112,15 +119,8 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
     QWidget *spacer = new QWidget(this);
     spacer->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     toolbar->addWidget(spacer);
-    m_timePos = new KRestrictedLine(this);
-    m_timePos->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
-    m_frametimecode = KdenliveSettings::frametimecode();
-    if (m_frametimecode) {
-        m_timePos->setInputMask(QString());
-        m_timePos->setValidator(new QIntValidator(this));
-    } else m_timePos->setInputMask("99:99:99:99");
+    m_timePos = new TimecodeDisplay(m_monitorManager->timecode(), this);
     toolbar->addWidget(m_timePos);
-
     connect(m_timePos, SIGNAL(editingFinished()), this, SLOT(slotSeek()));
 
     layout2->addWidget(toolbar);
@@ -166,6 +166,18 @@ Monitor::Monitor(QString name, MonitorManager *manager, QString profile, QWidget
 #ifndef Q_WS_MAC
     m_monitorRefresh->show();
 #endif
+
+    if (name == "project") {
+        m_effectScene = new MonitorScene(render);
+        m_effectView = new QGraphicsView(m_effectScene, m_ui.video_frame);
+        m_effectView->setRenderHints(QFlags<QPainter::RenderHint>());
+        m_effectView->scale(((double) render->renderWidth()) / render->frameRenderWidth(), 1.0);
+        rendererBox->addWidget(m_effectView);
+        m_effectView->setMouseTracking(true);
+        m_effectScene->setUp();
+        m_effectView->hide();
+    }
+
     kDebug() << "/////// BUILDING MONITOR, ID: " << m_ui.video_frame->winId();
 }
 
@@ -174,6 +186,10 @@ Monitor::~Monitor()
     delete m_ruler;
     delete m_timePos;
     delete m_overlay;
+    if (m_name == "project") {
+        delete m_effectView;
+        delete m_effectScene;
+    }
     delete m_monitorRefresh;
     delete render;
 }
@@ -345,8 +361,6 @@ GenTime Monitor::getSnapForPos(bool previous)
     return GenTime();
 }
 
-
-
 void Monitor::slotZoneMoved(int start, int end)
 {
     m_ruler->setZone(start, end);
@@ -385,7 +399,7 @@ void Monitor::mousePressEvent(QMouseEvent * event)
 void Monitor::mouseReleaseEvent(QMouseEvent * event)
 {
     if (m_dragStarted) {
-        if (m_ui.video_frame->underMouse()) {
+        if (m_ui.video_frame->underMouse() && (!m_effectView || !m_effectView->isVisible())) {
             if (isActive()) slotPlay();
             else activateMonitor();
         } else QWidget::mouseReleaseEvent(event);
@@ -393,7 +407,6 @@ void Monitor::mouseReleaseEvent(QMouseEvent * event)
     }
 }
 
-
 // virtual
 void Monitor::mouseMoveEvent(QMouseEvent *event)
 {
@@ -452,16 +465,7 @@ QStringList Monitor::mimeTypes() const
     return qstrList;
 }
 
-
 // virtual
-/** Move to other position on mousewheel
- *
- * Moves towards end of clip/timeline on mousewheel down/back,
- * opposite for mousewheel up/forward.
- *
- * Ctrl+wheel moves single frame, without Ctrl moves a second.
- *
- * See also http://www.kdenlive.org/mantis/view.php?id=265 */
 void Monitor::wheelEvent(QWheelEvent * event)
 {
     if (event->modifiers() == Qt::ControlModifier) {
@@ -515,20 +519,13 @@ void Monitor::activateMonitor()
 
 void Monitor::setTimePos(const QString &pos)
 {
-    if (m_frametimecode) {
-        int frames = m_monitorManager->timecode().getFrameCount(pos);
-        m_timePos->setText(QString::number(frames));
-    } else m_timePos->setText(pos);
+    m_timePos->setValue(pos);
     slotSeek();
 }
 
 void Monitor::slotSeek()
 {
-    int frames;
-    if (m_frametimecode) frames = m_timePos->text().toInt();
-    else frames = m_monitorManager->timecode().getFrameCount(m_timePos->text());
-    //kDebug() << "// / / SEEK TO: " << frames;
-    slotSeek(frames);
+    slotSeek(m_timePos->getValue());
 }
 
 void Monitor::slotSeek(int pos)
@@ -536,7 +533,6 @@ void Monitor::slotSeek(int pos)
     activateMonitor();
     if (render == NULL) return;
     render->seekToFrame(pos);
-    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::checkOverlay()
@@ -544,13 +540,17 @@ void Monitor::checkOverlay()
     if (m_overlay == NULL) return;
     int pos = render->seekFramePosition();
     QPoint zone = m_ruler->zone();
-    if (pos == zone.x()) m_overlay->setOverlayText(i18n("In Point"));
-    else if (pos == zone.y()) m_overlay->setOverlayText(i18n("Out Point"));
+    if (pos == zone.x())
+        m_overlay->setOverlayText(i18n("In Point"));
+    else if (pos == zone.y())
+        m_overlay->setOverlayText(i18n("Out Point"));
     else {
         if (m_currentClip) {
             QString markerComment = m_currentClip->markerComment(GenTime(pos, m_monitorManager->timecode().fps()));
-            if (markerComment.isEmpty()) m_overlay->setHidden(true);
-            else m_overlay->setOverlayText(markerComment, false);
+            if (markerComment.isEmpty())
+                m_overlay->setHidden(true);
+            else
+                m_overlay->setOverlayText(markerComment, false);
         } else m_overlay->setHidden(true);
     }
 }
@@ -560,7 +560,6 @@ void Monitor::slotStart()
     activateMonitor();
     render->play(0);
     render->seekToFrame(0);
-    //emit renderPosition(0);
 }
 
 void Monitor::slotEnd()
@@ -568,7 +567,6 @@ void Monitor::slotEnd()
     activateMonitor();
     render->play(0);
     render->seekToFrame(render->getLength());
-    //emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotZoneStart()
@@ -576,7 +574,6 @@ void Monitor::slotZoneStart()
     activateMonitor();
     render->play(0);
     render->seekToFrame(m_ruler->zone().x());
-    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotZoneEnd()
@@ -584,7 +581,6 @@ void Monitor::slotZoneEnd()
     activateMonitor();
     render->play(0);
     render->seekToFrame(m_ruler->zone().y());
-    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotRewind(double speed)
@@ -616,7 +612,6 @@ void Monitor::slotRewindOneFrame(int diff)
     activateMonitor();
     render->play(0);
     render->seekToFrameDiff(-diff);
-    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::slotForwardOneFrame(int diff)
@@ -624,7 +619,6 @@ void Monitor::slotForwardOneFrame(int diff)
     activateMonitor();
     render->play(0);
     render->seekToFrameDiff(diff);
-    emit renderPosition(render->seekFramePosition());
 }
 
 void Monitor::seekCursor(int pos)
@@ -632,8 +626,7 @@ void Monitor::seekCursor(int pos)
     activateMonitor();
     if (m_ruler->slotNewValue(pos)) {
         checkOverlay();
-        if (m_frametimecode) m_timePos->setText(QString::number(pos));
-        else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+        m_timePos->setValue(pos);
     }
 }
 
@@ -641,8 +634,7 @@ void Monitor::rendererStopped(int pos)
 {
     if (m_ruler->slotNewValue(pos)) {
         checkOverlay();
-        if (m_frametimecode) m_timePos->setText(QString::number(pos));
-        else m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
+        m_timePos->setValue(pos);
     }
     disconnect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
     m_playAction->setChecked(false);
@@ -784,11 +776,15 @@ void Monitor::slotSaveZone()
     //render->setSceneList(doc, 0);
 }
 
-
 void Monitor::resetProfile(const QString profile)
 {
+    m_timePos->updateTimeCode(m_monitorManager->timecode());
     if (render == NULL) return;
     render->resetProfile(profile);
+    if (m_effectScene) {
+        m_effectView->scale(((double) render->renderWidth()) / render->frameRenderWidth(), 1.0);
+        m_effectScene->resetProfile();
+    }
 }
 
 void Monitor::saveSceneList(QString path, QDomElement info)
@@ -803,7 +799,6 @@ const QString Monitor::sceneList()
     return render->sceneList();
 }
 
-
 void Monitor::setClipZone(QPoint pos)
 {
     if (m_currentClip == NULL) return;
@@ -835,18 +830,7 @@ void Monitor::slotSwitchMonitorInfo(bool show)
 
 void Monitor::updateTimecodeFormat()
 {
-    m_frametimecode = KdenliveSettings::frametimecode();
-    if (m_frametimecode) {
-        int frames = m_monitorManager->timecode().getFrameCount(m_timePos->text());
-        m_timePos->setValidator(new QIntValidator(this));
-        m_timePos->setInputMask(QString());
-        m_timePos->setText(QString::number(frames));
-    } else {
-        int pos = m_timePos->text().toInt();
-        m_timePos->setValidator(0);
-        m_timePos->setInputMask("99:99:99:99");
-        m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
-    }
+    m_timePos->slotUpdateTimeCodeFormat();
 }
 
 QStringList Monitor::getZoneInfo() const
@@ -859,8 +843,34 @@ QStringList Monitor::getZoneInfo() const
     return result;
 }
 
+void Monitor::slotEffectScene(bool show)
+{
+    if (m_name == "project") {
+#ifdef Q_WS_MAC
+        m_glWidget->setVisible(!show);
+#else
+        m_monitorRefresh->setVisible(!show);
+#endif
+        m_effectView->setVisible(show);
+        emit requestFrameForAnalysis(show);
+        if (show) {
+            render->doRefresh();
+            m_effectScene->slotZoomFit();
+        }
+    }
+}
 
-MonitorRefresh::MonitorRefresh(QWidget* parent) : \
+MonitorScene * Monitor::getEffectScene()
+{
+    return m_effectScene;
+}
+
+bool Monitor::effectSceneDisplayed()
+{
+    return m_effectView->isVisible();
+}
+
+MonitorRefresh::MonitorRefresh(QWidget* parent) :
         QWidget(parent),
         m_renderer(NULL)
 {
@@ -874,38 +884,31 @@ void MonitorRefresh::setRenderer(Render* render)
     m_renderer = render;
 }
 
-void MonitorRefresh::paintEvent(QPaintEvent * /*event*/)
+void MonitorRefresh::paintEvent(QPaintEvent *event)
 {
+    Q_UNUSED(event);
     if (m_renderer) m_renderer->doRefresh();
 }
 
-
 Overlay::Overlay(QWidget* parent) :
         QLabel(parent)
 {
     setAttribute(Qt::WA_TransparentForMouseEvents);
-    setAttribute(Qt::WA_OpaquePaintEvent);
+    //setAttribute(Qt::WA_OpaquePaintEvent);
     //setAttribute(Qt::WA_NoSystemBackground);
-    setAutoFillBackground(false);
+    setAutoFillBackground(true);
+    setBackgroundRole(QPalette::Base);
 }
 
-void Overlay::paintEvent(QPaintEvent * /*event*/)
-{
-    QPainter painter(this);
-    QColor col;
-    painter.setPen(Qt::white);
-    if (m_isZone) col = QColor(200, 0, 0);
-    else col = QColor(0, 0, 200);
-    painter.fillRect(rect(), col);
-    painter.drawText(rect(), Qt::AlignCenter, text());
-}
-
-
-
 void Overlay::setOverlayText(const QString &text, bool isZone)
 {
     setHidden(true);
     m_isZone = isZone;
+    QPalette p;
+    p.setColor(QPalette::Text, Qt::white);
+    if (m_isZone) p.setColor(QPalette::Base, QColor(200, 0, 0));
+    else p.setColor(QPalette::Base, QColor(0, 0, 200));
+    setPalette(p);
     setText(' ' + text + ' ');
     setHidden(false);
     update();
