@@ -48,8 +48,10 @@ void MonitorManager::initMonitors(Monitor *clipMonitor, Monitor *projectMonitor)
 
 void MonitorManager::activateMonitor(QString name)
 {
-    if (m_blocked || m_clipMonitor == NULL) return;
-    if (m_activeMonitor == name) return;
+    if (m_blocked || m_clipMonitor == NULL || m_projectMonitor == NULL)
+        return;
+    if (m_activeMonitor == name)
+        return;
     if (name == "clip") {
         m_projectMonitor->stop();
         m_clipMonitor->start();
@@ -60,22 +62,15 @@ void MonitorManager::activateMonitor(QString name)
         emit raiseClipMonitor(false);
     }
     m_activeMonitor = name;
+    emit checkColorScopes();
 }
 
 void MonitorManager::slotSwitchMonitors(bool activateClip)
 {
-    if (m_blocked || m_clipMonitor == NULL) return;
-    if (!activateClip && m_clipMonitor->isActive()) {
-        m_clipMonitor->stop();
-        m_projectMonitor->start();
-        m_activeMonitor = m_projectMonitor->name();
-        emit raiseClipMonitor(false);
-    } else if (activateClip && m_projectMonitor->isActive()) {
-        m_projectMonitor->stop();
-        m_clipMonitor->start();
-        m_activeMonitor = m_clipMonitor->name();
-        emit raiseClipMonitor(true);
-    }
+    if (activateClip)
+        activateMonitor("clip");
+    else
+        activateMonitor("project");
 }
 
 void MonitorManager::stopActiveMonitor()
@@ -163,11 +158,15 @@ void MonitorManager::slotResetProfiles()
 {
     if (m_blocked) return;
     if (m_projectMonitor == NULL || m_clipMonitor == NULL) return;
+    QString active = m_activeMonitor;
     activateMonitor("clip");
     m_clipMonitor->resetProfile(KdenliveSettings::current_profile());
+    m_clipMonitor->updateTimecodeFormat();
     activateMonitor("project");
     m_projectMonitor->resetProfile(KdenliveSettings::current_profile());
+    m_projectMonitor->updateTimecodeFormat();
     //m_projectMonitor->refreshMonitor(true);
+    activateMonitor(active);
 }
 
 
