@@ -21,12 +21,9 @@
 #ifndef MOVECLIPCOMMAND_H
 #define MOVECLIPCOMMAND_H
 
-#include <QUndoCommand>
-#include <QGraphicsView>
-#include <QPointF>
 
-#include <KDebug>
 #include "definitions.h"
+#include <QUndoCommand>
 
 class CustomTrackView;
 
@@ -42,6 +39,7 @@ private:
     const ItemInfo m_startPos;
     const ItemInfo m_endPos;
     bool m_doIt;
+    bool m_refresh;
 };
 
 #endif
