@@ -26,7 +26,7 @@
 #include <QToolButton>
 #include <QTreeWidget>
 #include <QPainter>
-#include <QItemDelegate>
+#include <QStyledItemDelegate>
 #include <QUndoStack>
 #include <QTimer>
 #include <QApplication>
@@ -61,10 +61,10 @@ const int NameRole = Qt::UserRole;
 const int DurationRole = NameRole + 1;
 const int UsageRole = NameRole + 2;
 
-class ItemDelegate: public QItemDelegate
+class ItemDelegate: public QStyledItemDelegate
 {
 public:
-    ItemDelegate(QAbstractItemView* parent = 0): QItemDelegate(parent) {
+    ItemDelegate(QAbstractItemView* parent = 0): QStyledItemDelegate(parent) {
     }
 
     /*void drawFocus(QPainter *, const QStyleOptionViewItem &, const QRect &) const {
@@ -74,22 +74,23 @@ public:
         if (index.column() == 0 && !index.data(DurationRole).isNull()) {
             QRect r1 = option.rect;
             painter->save();
-            if (option.state & (QStyle::State_Selected)) {
-                painter->setPen(option.palette.color(QPalette::HighlightedText));
-                painter->fillRect(r1, option.palette.highlight());
+            QStyleOptionViewItemV4 opt(option);
+            QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
+            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
+
+            if (option.state & QStyle::State_Selected) {
+                painter->setPen(option.palette.highlightedText().color());
             }
-            QStyleOptionViewItemV2 opt = setOptions(index, option);
-            QPixmap pixmap = decoration(opt, index.data(Qt::DecorationRole));
+            const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
+            QPixmap pixmap = qVariantValue<QPixmap>(index.data(Qt::DecorationRole));
             if ((index.flags() & (Qt::ItemIsDragEnabled)) == false) {
                 KIcon icon("dialog-close");
                 QPainter p(&pixmap);
                 p.drawPixmap(1, 1, icon.pixmap(16, 16));
                 p.end();
             }
-            QRect decorationRect = pixmap.rect(); //QRect(QPoint(0, 0), option.decorationSize).intersected(pixmap.rect());
-            const int textMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
-            decorationRect.moveTo(r1.topLeft() + QPoint(0, 1));
-            drawDecoration(painter, opt, decorationRect, pixmap);
+
+            painter->drawPixmap(r1.left() + textMargin, r1.top() + (r1.height() - pixmap.height()) / 2, pixmap);
             int decoWidth = pixmap.width() + 2 * textMargin;
 
             QFont font = painter->font();
@@ -100,7 +101,6 @@ public:
             QRect r2 = option.rect;
             r2.adjust(decoWidth, mid, 0, 0);
             painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data().toString());
-            //painter->setPen(Qt::green);
             font.setBold(false);
             painter->setFont(font);
             QString subText = index.data(DurationRole).toString();
@@ -111,7 +111,7 @@ public:
             painter->restore();
         } else if (index.column() == 2 && KdenliveSettings::activate_nepomuk()) {
             if (index.data().toString().isEmpty()) {
-                QItemDelegate::paint(painter, option, index);
+                QStyledItemDelegate::paint(painter, option, index);
                 return;
             }
             QRect r1 = option.rect;
@@ -122,7 +122,7 @@ public:
             KRatingPainter::paintRating(painter, r1, Qt::AlignCenter, index.data().toInt());
 #endif
         } else {
-            QItemDelegate::paint(painter, option, index);
+            QStyledItemDelegate::paint(painter, option, index);
         }
     }
 };
@@ -140,8 +140,9 @@ public:
     void slotUpdateClipProperties(const QString &id, QMap <QString, QString> properties);
     QByteArray headerInfo() const;
     void setHeaderInfo(const QByteArray &state);
+    void updateProjectFormat(Timecode t);
     void setupMenu(QMenu *addMenu, QAction *defaultAction);
-    void setupGeneratorMenu(QMenu *addMenu, QMenu *transcodeMenu);
+    void setupGeneratorMenu(QMenu *addMenu, QMenu *transcodeMenu, QMenu *inTimelineMenu);
     QString currentClipUrl() const;
     KUrl::List getConditionalUrls(const QString &condition) const;
     void reloadClipThumbnails();
@@ -154,7 +155,12 @@ public:
     void focusTree() const;
     SubProjectItem *getSubItem(ProjectItem *clip, QPoint zone);
     void doUpdateClipCut(const QString &id, const QPoint oldzone, const QPoint zone, const QString &comment);
+    bool hasMissingClips();
     void deleteProjectFolder(QMap <QString, QString> map);
+    void selectItemById(const QString &clipId);
+
+    /** @brief Returns a string list of all supported mime extensions. */
+    static QString getExtensions();
 
 public slots:
     void setDocument(KdenliveDoc *doc);
@@ -168,17 +174,26 @@ public slots:
     void slotRefreshClipThumbnail(QTreeWidgetItem *item, bool update = true);
     void slotRemoveInvalidClip(const QString &id, bool replace);
     void slotSelectClip(const QString &ix);
+
+    /** @brief Prepares removing the selected items. */
     void slotRemoveClip();
     void slotAddClip(const QList <QUrl> givenList = QList <QUrl> (), const QString &groupName = QString(), const QString &groupId = QString());
+
+    /** @brief Adds, edits or deletes a folder item.
+    *
+    * This is triggered by AddFolderCommand and EditFolderCommand. */
     void slotAddFolder(const QString foldername, const QString &clipId, bool remove, bool edit = false);
     void slotResetProjectList();
     void slotOpenClip();
     void slotEditClip();
     void slotReloadClip(const QString &id = QString());
+
+    /** @brief Shows dialog for setting up a color clip. */
     void slotAddColorClip();
     void regenerateTemplate(const QString &id);
     void slotUpdateClipCut(QPoint p);
     void slotAddClipCut(const QString &id, int in, int out);
+    void slotForceProcessing(const QString &id);
 
 private:
     ProjectListView *m_listView;
@@ -189,7 +204,6 @@ private:
     QTimer m_queueTimer;
     QMenu *m_menu;
     QUndoStack *m_commandStack;
-    void selectItemById(const QString &clipId);
     ProjectItem *getItemById(const QString &id);
     QTreeWidgetItem *getAnyItemById(const QString &id);
     FolderProjectItem *getFolderItemById(const QString &id);
@@ -207,11 +221,19 @@ private:
     void requestClipInfo(const QDomElement xml, const QString id);
     QList <QString> m_thumbnailQueue;
     void requestClipThumbnail(const QString id);
+
+    /** @brief Creates an EditFolderCommand to change the name of an folder item. */
     void editFolder(const QString folderName, const QString oldfolderName, const QString &clipId);
+
+    /** @brief Gets the selected folder (or the folder of the selected item). */
     QStringList getGroup() const;
     void regenerateTemplate(ProjectItem *clip);
     void editClipSelection(QList<QTreeWidgetItem *> list);
+
+    /** @brief Enables and disables transcode actions based on the selected clip's type. */
     void adjustTranscodeActions(ProjectItem *clip) const;
+
+    /** @brief Sets the buttons enabled/disabled according to selected item. */
     void updateButtons() const;
 
 private slots:
@@ -219,15 +241,26 @@ private slots:
     void slotAddSlideshowClip();
     void slotAddTitleClip();
     void slotAddTitleTemplateClip();
-    void slotContextMenu(const QPoint &pos, QTreeWidgetItem *);
+
+    /** @brief Shows the context menu after enabling and disabling actions based on the item's type.
+    * @param pos The position where the menu should pop up
+    * @param item The item for which the checks should be done */
+    void slotContextMenu(const QPoint &pos, QTreeWidgetItem *item);
+
+    /** @brief Creates an AddFolderCommand. */
     void slotAddFolder();
-    /** This is triggered when a clip description has been modified */
+
+    /** @brief This is triggered when a clip description has been modified. */
     void slotItemEdited(QTreeWidgetItem *item, int column);
     void slotUpdateClipProperties(ProjectItem *item, QMap <QString, QString> properties);
     void slotProcessNextClipInQueue();
     void slotProcessNextThumbnail();
     void slotCheckForEmptyQueue();
     void slotPauseMonitor();
+    /** A clip was modified externally, change icon so that user knows it */
+    void slotModifiedClip(const QString &id);
+    void slotMissingClip(const QString &id);
+    void slotAvailableClip(const QString &id);
     //void slotShowMenu(const QPoint &pos);
 
 signals:
@@ -242,7 +275,9 @@ signals:
     void clipNameChanged(const QString, const QString);
     void clipNeedsReload(const QString&, bool);
     void refreshClip();
+    void updateRenderStatus();
     void deleteProjectClips(QStringList ids, QMap <QString, QString> folderids);
+    void findInTimeline(const QString &clipId);
 };
 
 #endif
