@@ -42,7 +42,8 @@ ProjectListView::ProjectListView(QWidget *parent) :
     setAlternatingRowColors(true);
     setDragEnabled(true);
     setAcceptDrops(true);
-
+    setFrameShape(QFrame::NoFrame);
+    setRootIsDecorated(false);
 
     setColumnCount(3);
     QStringList headers;
@@ -53,12 +54,14 @@ ProjectListView::ProjectListView(QWidget *parent) :
     headerView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(headerView, SIGNAL(customContextMenuRequested(const QPoint&)),
             this, SLOT(configureColumns(const QPoint&)));
+    connect(this, SIGNAL(itemCollapsed(QTreeWidgetItem *)), this, SLOT(slotCollapsed(QTreeWidgetItem *)));
+    connect(this, SIGNAL(itemExpanded(QTreeWidgetItem *)), this, SLOT(slotExpanded(QTreeWidgetItem *)));
     headerView->setClickable(true);
     headerView->setSortIndicatorShown(true);
     headerView->setMovable(false);
     sortByColumn(0, Qt::AscendingOrder);
     setSortingEnabled(true);
-
+    installEventFilter(this);
     if (!KdenliveSettings::showdescriptioncolumn()) hideColumn(1);
     if (!KdenliveSettings::showratingcolumn()) hideColumn(2);
 }
@@ -113,6 +116,45 @@ void ProjectListView::contextMenuEvent(QContextMenuEvent * event)
     emit requestMenu(event->globalPos(), itemAt(event->pos()));
 }
 
+void ProjectListView::slotCollapsed(QTreeWidgetItem *item)
+{
+    if (item->type() == PROJECTFOLDERTYPE) {
+        blockSignals(true);
+        static_cast <FolderProjectItem *>(item)->switchIcon();
+        blockSignals(false);
+    }
+}
+
+void ProjectListView::slotExpanded(QTreeWidgetItem *item)
+{
+    if (item->type() == PROJECTFOLDERTYPE) {
+        blockSignals(true);
+        static_cast <FolderProjectItem *>(item)->switchIcon();
+        blockSignals(false);
+    }
+}
+
+bool ProjectListView::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::KeyPress || event->type() == QEvent::ShortcutOverride) {
+        QKeyEvent* ke = (QKeyEvent*) event;
+        if (ke->key() == Qt::Key_Plus) {
+            if (currentItem()) currentItem()->setExpanded(true);
+            event->accept();
+            return true;
+        } else if (ke->key() == Qt::Key_Minus) {
+            if (currentItem()) currentItem()->setExpanded(false);
+            event->accept();
+            return true;
+        } else {
+            return false;
+        }
+    } else {
+        // pass the event on to the parent class
+        return QTreeWidget::eventFilter(obj, event);
+    }
+}
+
 // virtual
 void ProjectListView::mouseDoubleClickEvent(QMouseEvent * event)
 {
@@ -123,7 +165,14 @@ void ProjectListView::mouseDoubleClickEvent(QMouseEvent * event)
     }
     ProjectItem *item;
     if (it->type() == PROJECTFOLDERTYPE) {
-        if ((columnAt(event->pos().x()) == 0)) QTreeWidget::mouseDoubleClickEvent(event);
+        if ((columnAt(event->pos().x()) == 0)) {
+            QPixmap pix = qVariantValue<QPixmap>(it->data(0, Qt::DecorationRole));
+            int offset = pix.width() + indentation();
+            if (event->pos().x() < offset) {
+                it->setExpanded(!it->isExpanded());
+                event->accept();
+            } else QTreeWidget::mouseDoubleClickEvent(event);
+        }
         return;
     }
     if (it->type() == PROJECTSUBCLIPTYPE) {
@@ -138,11 +187,17 @@ void ProjectListView::mouseDoubleClickEvent(QMouseEvent * event)
     if (!(item->flags() & Qt::ItemIsDragEnabled)) return;
 
     int column = columnAt(event->pos().x());
-    if (column == 0 && (item->clipType() == SLIDESHOW || item->clipType() == TEXT || item->clipType() == COLOR)) {
+    if (column == 0 && (item->clipType() == SLIDESHOW || item->clipType() == TEXT || item->clipType() == COLOR || it->childCount() > 0)) {
         QPixmap pix = qVariantValue<QPixmap>(it->data(0, Qt::DecorationRole));
         int offset = pix.width() + indentation();
         if (item->parent()) offset += indentation();
-        if ((pix.isNull() || offset < event->pos().x())) {
+        if (it->childCount() > 0) {
+            if (offset > event->pos().x()) {
+                it->setExpanded(!it->isExpanded());
+                event->accept();
+                return;
+            }
+        } else if (pix.isNull() || offset < event->pos().x()) {
             QTreeWidget::mouseDoubleClickEvent(event);
             return;
         }
@@ -154,14 +209,6 @@ void ProjectListView::mouseDoubleClickEvent(QMouseEvent * event)
     emit showProperties(item->referencedClip());
 }
 
-// virtual
-void ProjectListView::dragEnterEvent(QDragEnterEvent *event)
-{
-    if (event->mimeData()->hasUrls() || event->mimeData()->hasText()) {
-        kDebug() << "////////////////  DRAG ENTR OK";
-    }
-    event->acceptProposedAction();
-}
 
 // virtual
 void ProjectListView::dropEvent(QDropEvent *event)
@@ -182,6 +229,7 @@ void ProjectListView::dropEvent(QDropEvent *event)
         emit addClip(event->mimeData()->urls(), groupName, groupId);
         event->setDropAction(Qt::CopyAction);
         event->accept();
+        QTreeWidget::dropEvent(event);
         return;
     } else if (event->mimeData()->hasFormat("kdenlive/producerslist")) {
         if (item) {
@@ -226,6 +274,7 @@ void ProjectListView::dropEvent(QDropEvent *event)
         emit addClipCut(list.at(0), list.at(1).toInt(), list.at(2).toInt());
     }
     event->acceptProposedAction();
+    QTreeWidget::dropEvent(event);
 }
 
 // virtual
@@ -314,14 +363,11 @@ void ProjectListView::mouseMoveEvent(QMouseEvent *event)
 }
 
 // virtual
-void ProjectListView::dragMoveEvent(QDragMoveEvent * event)
+void ProjectListView::dragLeaveEvent(QDragLeaveEvent *event)
 {
-    //event->setDropAction(Qt::MoveAction);
-    if (event->mimeData()->hasText()) {
-        event->acceptProposedAction();
-    }
     // stop playing because we get a crash otherwise when fetching the thumbnails
     emit pauseMonitor();
+    QTreeWidget::dragLeaveEvent(event);
 }
 
 QStringList ProjectListView::mimeTypes() const
@@ -340,7 +386,7 @@ QStringList ProjectListView::mimeTypes() const
 Qt::DropActions ProjectListView::supportedDropActions() const
 {
     // returns what actions are supported when dropping
-    return Qt::MoveAction;
+    return Qt::MoveAction | Qt::CopyAction;
 }
 
 #include "projectlistview.moc"
