@@ -43,11 +43,13 @@ protected:
     virtual void mousePressEvent(QMouseEvent *event);
     virtual void mouseReleaseEvent(QMouseEvent *event);
     virtual void mouseMoveEvent(QMouseEvent *event);
-    virtual void dragEnterEvent(QDragEnterEvent *event);
     virtual void dropEvent(QDropEvent *event);
     virtual QStringList mimeTypes() const;
     virtual Qt::DropActions supportedDropActions() const;
-    virtual void dragMoveEvent(QDragMoveEvent * event);
+    virtual void dragLeaveEvent(QDragLeaveEvent *);
+
+    /** @brief Filters key events to make sure user can expand items with + / -. */
+    virtual bool eventFilter(QObject *obj, QEvent *ev);
 
 public slots:
 
@@ -58,6 +60,8 @@ private:
 
 private slots:
     void configureColumns(const QPoint& pos);
+    void slotCollapsed(QTreeWidgetItem *item);
+    void slotExpanded(QTreeWidgetItem *item);
 
 signals:
     void requestMenu(const QPoint &, QTreeWidgetItem *);
