@@ -23,7 +23,7 @@
 
 #include <QPushButton>
 #include <QPainter>
-#include <QItemDelegate>
+#include <QStyledItemDelegate>
 
 #include "definitions.h"
 #include "ui_renderwidget_ui.h"
@@ -32,46 +32,56 @@ class QDomElement;
 
 
 // RenderViewDelegate is used to draw the progress bars.
-class RenderViewDelegate : public QItemDelegate
+class RenderViewDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    RenderViewDelegate(QWidget *parent) : QItemDelegate(parent) {}
+    RenderViewDelegate(QWidget *parent) : QStyledItemDelegate(parent) {}
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
                const QModelIndex &index) const {
         if (index.column() == 1) {
-            QRect r1 = option.rect;
             painter->save();
-            if (option.state & (QStyle::State_Selected)) {
-                painter->setPen(option.palette.color(QPalette::HighlightedText));
-                painter->fillRect(r1, option.palette.highlight());
-            } else painter->setPen(option.palette.color(QPalette::Text));
+            int factor = 2;
+            QStyleOptionViewItemV4 opt(option);
+            QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
+            const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
+            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
+
+            if (option.state & QStyle::State_Selected) {
+                painter->setPen(option.palette.highlightedText().color());
+                factor = 3;
+            }// else painter->setPen(option.palette.color(QPalette::Text));
             QFont font = painter->font();
             font.setBold(true);
             painter->setFont(font);
-            int mid = (int)((r1.height() / 2));
+            QRect r1 = option.rect;
+            r1.adjust(0, textMargin, 0, - textMargin);
+            int mid = (int)((r1.height() / factor));
             r1.setBottom(r1.y() + mid);
-            QRect r2 = option.rect;
-            r2.setTop(r2.y() + mid);
             painter->drawText(r1, Qt::AlignLeft | Qt::AlignBottom , index.data().toString());
+            r1.setBottom(r1.bottom() + mid);
+            r1.setTop(r1.bottom() - mid);
             font.setBold(false);
             painter->setFont(font);
-            painter->setPen(option.palette.color(QPalette::Mid));
-            painter->drawText(r2, Qt::AlignLeft | Qt::AlignVCenter , index.data(Qt::UserRole).toString());
+            painter->drawText(r1, Qt::AlignLeft | Qt::AlignVCenter , index.data(Qt::UserRole).toString());
+            if (factor > 2) {
+                r1.setBottom(r1.bottom() + mid);
+                r1.setTop(r1.bottom() - mid);
+                painter->drawText(r1, Qt::AlignLeft | Qt::AlignVCenter , index.data(Qt::UserRole + 5).toString());
+            }
             painter->restore();
         } else if (index.column() == 2) {
             // Set up a QStyleOptionProgressBar to precisely mimic the
             // environment of a progress bar.
+            QStyleOptionViewItemV4 opt(option);
+            QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
+            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
+
             QStyleOptionProgressBar progressBarOption;
             progressBarOption.state = option.state;
             progressBarOption.direction = QApplication::layoutDirection();
             QRect rect = option.rect;
-            if (option.state & (QStyle::State_Selected)) {
-                painter->setPen(option.palette.color(QPalette::HighlightedText));
-                painter->fillRect(rect, option.palette.highlight());
-            }
-
             int mid = rect.height() / 2;
             rect.setTop(rect.top() + mid / 2);
             rect.setHeight(mid);
@@ -89,7 +99,7 @@ public:
 
             // Draw the progress bar onto the view.
             QApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
-        } else QItemDelegate::paint(painter, option, index);
+        } else QStyledItemDelegate::paint(painter, option, index);
     }
 };
 
@@ -108,19 +118,26 @@ public:
     void setRenderStatus(const QString &dest, int status, const QString &error);
     void setDocumentPath(const QString path);
     void reloadProfiles();
-    void setRenderProfile(const QString &dest, const QString &group, const QString &name, const QString &url);
+    void setRenderProfile(QMap <QString, QString> props);
     int waitingJobsCount() const;
     QString getFreeScriptName(const QString &prefix = QString());
     bool startWaitingRenderJobs();
+    void missingClips(bool hasMissing);
+    /** @brief Returns true if the export audio checkbox is set to automatic. */
+    bool automaticAudioExport() const;
+    /** @brief Returns true if user wants audio export. */
+    bool selectedAudioExport() const;
 
 public slots:
-    void slotExport(bool scriptExport, int zoneIn, int zoneOut, const QString &playlistPath, const QString &scriptPath);
+    void slotExport(bool scriptExport, int zoneIn, int zoneOut, const QString &playlistPath, const QString &scriptPath, bool exportAudio);
 
 private slots:
     void slotUpdateButtons(KUrl url);
     void slotUpdateButtons();
     void refreshView();
     void refreshCategory();
+
+    /** @brief Updates available options when a new format has been selected. */
     void refreshParams();
     void slotSaveProfile();
     void slotEditProfile();
@@ -143,6 +160,11 @@ private slots:
     void slotPlayRendering(QTreeWidgetItem *item, int);
     void slotStartCurrentJob();
     void slotCopyToFavorites();
+    void slotUpdateRescaleHeight(int);
+    void slotUpdateRescaleWidth(int);
+    void slotSwitchAspectRatio();
+    /** @brief Update export audio label depending on current settings. */
+    void slotUpdateAudioLabel(int ix);
 
 private:
     Ui::RenderWidget_UI m_view;
@@ -167,7 +189,7 @@ signals:
     void openDvdWizard(const QString &url, const QString &profile);
     /** Send the infos about rendering that will be saved in the document:
     (profile destination, profile name and url of rendered file */
-    void selectedRenderProfile(const QString &, const QString &, const QString &, const QString &);
+    void selectedRenderProfile(QMap <QString, QString> renderProps);
     void prepareRenderingData(bool scriptExport, bool zoneOnly, const QString &chapterFile);
     void shutdown();
 };
