@@ -19,7 +19,6 @@
 
 
 #include "trackview.h"
-#include "definitions.h"
 #include "headertrack.h"
 #include "clipitem.h"
 #include "transition.h"
@@ -31,6 +30,7 @@
 #include "customtrackview.h"
 #include "initeffects.h"
 #include "profilesdialog.h"
+#include "configtrackscommand.h"
 
 #include <KDebug>
 #include <KMessageBox>
@@ -54,7 +54,6 @@ TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
     m_trackview = new CustomTrackView(doc, m_scene, parent);
     m_trackview->scale(1, 1);
     m_trackview->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-    //m_scene->addRect(QRectF(0, 0, 100, 100), QPen(), QBrush(Qt::red));
 
     m_ruler = new CustomRuler(doc->timecode(), m_trackview);
     connect(m_ruler, SIGNAL(zoneMoved(int, int)), this, SIGNAL(zoneMoved(int, int)));
@@ -104,17 +103,21 @@ TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
     connect(m_trackview, SIGNAL(trackHeightChanged()), this, SLOT(slotRebuildTrackHeaders()));
     connect(m_trackview, SIGNAL(tracksChanged()), this, SLOT(slotReloadTracks()));
     connect(m_trackview, SIGNAL(updateTrackHeaders()), this, SLOT(slotRepaintTracks()));
+    connect(m_trackview, SIGNAL(showTrackEffects(int, TrackInfo)), this, SIGNAL(showTrackEffects(int, TrackInfo)));
+    connect(m_trackview, SIGNAL(updateTrackEffectState(int)), this, SLOT(slotUpdateTrackEffectState(int)));
+
 
     parseDocument(m_doc->toXml());
     if (m_doc->setSceneList() == -1) *ok = false;
     else *ok = true;
     connect(m_trackview, SIGNAL(cursorMoved(int, int)), m_ruler, SLOT(slotCursorMoved(int, int)));
     connect(m_trackview->horizontalScrollBar(), SIGNAL(valueChanged(int)), m_ruler, SLOT(slotMoveRuler(int)));
+    connect(m_trackview->horizontalScrollBar(), SIGNAL(rangeChanged(int, int)), this, SLOT(slotUpdateVerticalScroll(int, int)));
     connect(m_trackview, SIGNAL(mousePosition(int)), this, SIGNAL(mousePosition(int)));
     connect(m_trackview, SIGNAL(doTrackLock(int, bool)), this, SLOT(slotChangeTrackLock(int, bool)));
 
     slotChangeZoom(m_doc->zoom().x(), m_doc->zoom().y());
-    slotSetZone(m_doc->zone());
+    slotSetZone(m_doc->zone(), false);
 }
 
 TrackView::~TrackView()
@@ -145,6 +148,21 @@ int TrackView::tracksNumber() const
     return m_projectTracks - 1;
 }
 
+bool TrackView::checkProjectAudio() const
+{
+    bool hasAudio = false;
+    const QList <TrackInfo> list = m_doc->tracksList();
+    int max = list.count();
+    for (int i = 0; i < max; i++) {
+        TrackInfo info = list.at(max - i - 1);
+        if (!info.isMute && m_trackview->hasAudio(i)) {
+            hasAudio = true;
+            break;
+        }
+    }
+    return hasAudio;
+}
+
 int TrackView::inPoint() const
 {
     return m_ruler->inPoint();
@@ -155,9 +173,10 @@ int TrackView::outPoint() const
     return m_ruler->outPoint();
 }
 
-void TrackView::slotSetZone(QPoint p)
+void TrackView::slotSetZone(QPoint p, bool updateDocumentProperties)
 {
     m_ruler->setZone(p);
+    if (updateDocumentProperties) m_doc->setZone(p.x(), p.y());
 }
 
 void TrackView::setDuration(int dur)
@@ -223,6 +242,7 @@ void TrackView::parseDocument(QDomDocument doc)
         }
     }
 
+    int trackIndex = 0;
     for (int i = 0; i < m_projectTracks; i++) {
         e = tracks.item(i).toElement();
         QString playlist_name = e.attribute("producer");
@@ -231,7 +251,12 @@ void TrackView::parseDocument(QDomDocument doc)
             p = QDomElement();
             for (int j = 0; j < m_projectTracks; j++) {
                 p = playlists.item(j).toElement();
-                if (p.attribute("id") == playlist_name) break;
+                if (p.attribute("id") == playlist_name) {
+                    // playlist found, check track effects
+                    QDomNodeList trackEffects = p.childNodes();
+                    slotAddProjectEffects(trackEffects, p, NULL, trackIndex++);
+                    break;
+                }
             }
             if (p.attribute("id") != playlist_name) { // then it didn't work.
                 kDebug() << "NO PLAYLIST FOUND FOR TRACK " + pos;
@@ -341,9 +366,10 @@ void TrackView::parseDocument(QDomDocument doc)
                     if (isWipeTransition) transitionId = "slide";
                 }
             }
+
             QDomElement base = MainWindow::transitions.getEffectByTag(mlt_service, transitionId).cloneNode().toElement();
 
-            for (int k = 0; k < transitionparams.count(); k++) {
+            if (!base.isNull()) for (int k = 0; k < transitionparams.count(); k++) {
                     p = transitionparams.item(k).toElement();
                     if (!p.isNull()) {
                         QString paramName = p.attribute("name");
@@ -380,9 +406,9 @@ void TrackView::parseDocument(QDomDocument doc)
             transitionInfo.track = m_projectTracks - 1 - b_track;
 
             //kDebug() << "///////////////   +++++++++++  ADDING TRANSITION ON TRACK: " << b_track << ", TOTAL TRKA: " << m_projectTracks;
-            if (transitionInfo.startPos >= transitionInfo.endPos) {
+            if (transitionInfo.startPos >= transitionInfo.endPos || base.isNull()) {
                 // invalid transition, remove it.
-                m_documentErrors.append(i18n("Removed invalid transition: %1", e.attribute("id")) + '\n');
+                m_documentErrors.append(i18n("Removed invalid transition: (%1, %2, %3)", e.attribute("id"), mlt_service, transitionId) + '\n');
                 kDebug() << "///// REMOVED INVALID TRANSITION: " << e.attribute("id");
                 tractor.removeChild(transitions.item(i));
                 i--;
@@ -428,8 +454,10 @@ void TrackView::parseDocument(QDomDocument doc)
             ct++;
             backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
         }
-        if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this)) KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\n To make sure you don't lose data, a backup copy called %1 was created.", backupFile));
-        else KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version, it was not possible to create a backup copy.", backupFile));
+        if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this))
+            KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\nTo make sure you don't lose data, a backup copy called %1 was created.", backupFile));
+        else
+            KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version, but it was not possible to create a backup copy.", backupFile));
     }
     //m_trackview->setCursorPos(cursorPos);
     //m_scrollBox->setGeometry(0, 0, 300 * zoomFactor(), m_scrollArea->height());
@@ -461,8 +489,10 @@ void TrackView::slotChangeZoom(int horizontal, int vertical)
         m_trackview->setScale(m_scale, m_scene->scale().y());
     } else {
         m_verticalZoom = vertical;
-        if (m_verticalZoom == 0) m_trackview->setScale(m_scale, 0.5);
-        else m_trackview->setScale(m_scale, m_verticalZoom);
+        if (m_verticalZoom == 0)
+            m_trackview->setScale(m_scale, 0.5);
+        else
+            m_trackview->setScale(m_scale, m_verticalZoom);
         adjustTrackHeaders();
     }
 }
@@ -488,13 +518,9 @@ void TrackView::refresh()
 
 void TrackView::slotRepaintTracks()
 {
-    QLayoutItem *child;
-    for (int i = 0; i < headers_container->layout()->count(); i++) {
-        child = headers_container->layout()->itemAt(i);
-        if (child->widget() && child->widget()->height() > 5) {
-            HeaderTrack *head = static_cast <HeaderTrack *>(child->widget());
-            if (head) head->setSelectedIndex(m_trackview->selectedTrack());
-        }
+    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
+    for (int i = 0; i < widgets.count(); i++) {
+        if (widgets.at(i)) widgets.at(i)->setSelectedIndex(m_trackview->selectedTrack());
     }
 }
 
@@ -519,10 +545,8 @@ void TrackView::slotRebuildTrackHeaders()
     QFrame *frame = NULL;
     for (int i = 0; i < max; i++) {
         frame = new QFrame(headers_container);
+        frame->setFrameStyle(QFrame::HLine);
         frame->setFixedHeight(1);
-        frame->setFrameStyle(QFrame::Plain);
-        frame->setFrameShape(QFrame::Box);
-        frame->setLineWidth(1);
         headers_container->layout()->addWidget(frame);
         TrackInfo info = list.at(max - i - 1);
         header = new HeaderTrack(i, info, height, headers_container);
@@ -533,15 +557,15 @@ void TrackView::slotRebuildTrackHeaders()
         connect(header, SIGNAL(selectTrack(int)), m_trackview, SLOT(slotSelectTrack(int)));
         connect(header, SIGNAL(deleteTrack(int)), this, SIGNAL(deleteTrack(int)));
         connect(header, SIGNAL(insertTrack(int)), this, SIGNAL(insertTrack(int)));
-        connect(header, SIGNAL(changeTrack(int)), this, SIGNAL(changeTrack(int)));
-        connect(header, SIGNAL(renameTrack(int)), this, SLOT(slotRenameTrack(int)));
+        connect(header, SIGNAL(renameTrack(int, QString)), this, SLOT(slotRenameTrack(int, QString)));
+        connect(header, SIGNAL(configTrack(int)), this, SIGNAL(configTrack(int)));
+        connect(header, SIGNAL(addTrackInfo(const QDomElement, int)), m_trackview, SLOT(slotAddTrackEffect(const QDomElement, int)));
+        connect(header, SIGNAL(showTrackEffects(int)), this, SLOT(slotShowTrackEffects(int)));
         headers_container->layout()->addWidget(header);
     }
     frame = new QFrame(this);
+    frame->setFrameStyle(QFrame::HLine);
     frame->setFixedHeight(1);
-    frame->setFrameStyle(QFrame::Plain);
-    frame->setFrameShape(QFrame::Box);
-    frame->setLineWidth(1);
     headers_container->layout()->addWidget(frame);
 }
 
@@ -549,10 +573,9 @@ void TrackView::slotRebuildTrackHeaders()
 void TrackView::adjustTrackHeaders()
 {
     int height = KdenliveSettings::trackheight() * m_scene->scale().y() - 1;
-    QLayoutItem *child;
-    for (int i = 0; i < headers_container->layout()->count(); i++) {
-        child = headers_container->layout()->itemAt(i);
-        if (child->widget() && child->widget()->height() > 5)(static_cast <HeaderTrack *>(child->widget()))->adjustSize(height);
+    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
+    for (int i = 0; i < widgets.count(); i++) {
+        if (widgets.at(i)) widgets.at(i)->adjustSize(height);
     }
 }
 
@@ -643,199 +666,205 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 }
 
                 // parse clip effects
-                QDomNodeList effects = elem.childNodes();
-                for (int ix = 0; ix < effects.count(); ix++) {
-                    bool disableeffect = false;
-                    QDomElement effect = effects.at(ix).toElement();
-                    if (effect.tagName() == "filter") {
-                        // add effect to clip
-                        QString effecttag;
-                        QString effectid;
-                        QString effectindex = QString::number(ix + 1);
-                        QString ladspaEffectFile;
-                        // Get effect tag & index
-                        for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
-                            // parse effect parameters
-                            QDomElement effectparam = n3.toElement();
-                            if (effectparam.attribute("name") == "tag") {
-                                effecttag = effectparam.text();
-                            } else if (effectparam.attribute("name") == "kdenlive_id") {
-                                effectid = effectparam.text();
-                            } else if (effectparam.attribute("name") == "disable" && effectparam.text().toInt() == 1) {
-                                // Fix effects index
-                                disableeffect = true;
-                            } else if (effectparam.attribute("name") == "kdenlive_ix") {
-                                // Fix effects index
-                                effectparam.firstChild().setNodeValue(effectindex);
-                            } else if (effectparam.attribute("name") == "src") {
-                                ladspaEffectFile = effectparam.text();
-                                if (!QFile::exists(ladspaEffectFile)) {
-                                    // If the ladspa effect file is missing, recreate it
-                                    kDebug() << "// MISSING LADSPA FILE: " << ladspaEffectFile;
-                                    ladspaEffectFile = m_doc->getLadspaFile();
-                                    effectparam.firstChild().setNodeValue(ladspaEffectFile);
-                                    kDebug() << "// ... REPLACED WITH: " << ladspaEffectFile;
-                                }
-                            }
-                        }
-                        //kDebug() << "+ + CLIP EFF FND: " << effecttag << ", " << effectid << ", " << effectindex;
-                        // get effect standard tags
-                        QDomElement clipeffect = MainWindow::customEffects.getEffectByTag(QString(), effectid);
-                        if (clipeffect.isNull()) clipeffect = MainWindow::videoEffects.getEffectByTag(effecttag, effectid);
-                        if (clipeffect.isNull()) clipeffect = MainWindow::audioEffects.getEffectByTag(effecttag, effectid);
-                        if (clipeffect.isNull()) {
-                            kDebug() << "///  WARNING, EFFECT: " << effecttag << ": " << effectid << " not found, removing it from project";
-                            m_documentErrors.append(i18n("Effect %1:%2 not found in MLT, it was removed from this project\n", effecttag, effectid));
-                            elem.removeChild(effects.at(ix));
+                QDomNodeList effects = elem.elementsByTagName("filter");
+                slotAddProjectEffects(effects, elem, item, -1);
+            }
+        }
+    }
+    kDebug() << "*************  ADD DOC TRACK " << ix << ", DURATION: " << position;
+    return position;
+}
+
+void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNode, ClipItem *clip, int trackIndex)
+{
+    for (int ix = 0; ix < effects.count(); ix++) {
+        bool disableeffect = false;
+        QDomElement effect = effects.at(ix).toElement();
+        if (effect.tagName() != "filter") continue;
+
+        // add effect to clip
+        QString effecttag;
+        QString effectid;
+        QString effectindex = QString::number(ix + 1);
+        QString ladspaEffectFile;
+        // Get effect tag & index
+        for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
+            // parse effect parameters
+            QDomElement effectparam = n3.toElement();
+            if (effectparam.attribute("name") == "tag") {
+                effecttag = effectparam.text();
+            } else if (effectparam.attribute("name") == "kdenlive_id") {
+                effectid = effectparam.text();
+            } else if (effectparam.attribute("name") == "disable" && effectparam.text().toInt() == 1) {
+                // Fix effects index
+                disableeffect = true;
+            } else if (effectparam.attribute("name") == "kdenlive_ix") {
+                // Fix effects index
+                effectparam.firstChild().setNodeValue(effectindex);
+            } else if (effectparam.attribute("name") == "src") {
+                ladspaEffectFile = effectparam.text();
+                if (!QFile::exists(ladspaEffectFile)) {
+                    // If the ladspa effect file is missing, recreate it
+                    kDebug() << "// MISSING LADSPA FILE: " << ladspaEffectFile;
+                    ladspaEffectFile = m_doc->getLadspaFile();
+                    effectparam.firstChild().setNodeValue(ladspaEffectFile);
+                    kDebug() << "// ... REPLACED WITH: " << ladspaEffectFile;
+                }
+            }
+        }
+        //kDebug() << "+ + CLIP EFF FND: " << effecttag << ", " << effectid << ", " << effectindex;
+        // get effect standard tags
+        QDomElement clipeffect = MainWindow::customEffects.getEffectByTag(QString(), effectid);
+        if (clipeffect.isNull()) clipeffect = MainWindow::videoEffects.getEffectByTag(effecttag, effectid);
+        if (clipeffect.isNull()) clipeffect = MainWindow::audioEffects.getEffectByTag(effecttag, effectid);
+        if (clipeffect.isNull()) {
+            kDebug() << "///  WARNING, EFFECT: " << effecttag << ": " << effectid << " not found, removing it from project";
+            m_documentErrors.append(i18n("Effect %1:%2 not found in MLT, it was removed from this project\n", effecttag, effectid));
+            if (parentNode.removeChild(effects.at(ix)).isNull()) kDebug() << "///  PROBLEM REMOVING EFFECT: " << effecttag;
+            ix--;
+        } else {
+            QDomElement currenteffect = clipeffect.cloneNode().toElement();
+            currenteffect.setAttribute("kdenlive_ix", effectindex);
+            QDomNodeList clipeffectparams = currenteffect.childNodes();
+
+            if (MainWindow::videoEffects.hasKeyFrames(currenteffect)) {
+                //kDebug() << " * * * * * * * * * * ** CLIP EFF WITH KFR FND  * * * * * * * * * * *";
+                // effect is key-framable, read all effects to retrieve keyframes
+                QString factor;
+                QString starttag;
+                QString endtag;
+                QDomNodeList params = currenteffect.elementsByTagName("parameter");
+                for (int i = 0; i < params.count(); i++) {
+                    QDomElement e = params.item(i).toElement();
+                    if (e.attribute("type") == "keyframe") {
+                        starttag = e.attribute("starttag", "start");
+                        endtag = e.attribute("endtag", "end");
+                        factor = e.attribute("factor", "1");
+                        break;
+                    }
+                }
+                QString keyframes;
+                int effectin = effect.attribute("in").toInt();
+                int effectout = effect.attribute("out").toInt();
+                double startvalue = 0;
+                double endvalue = 0;
+                double fact;
+                if (factor.isEmpty()) fact = 1;
+                else if (factor.startsWith('%')) {
+                    fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                } else fact = factor.toDouble();
+                for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
+                    // parse effect parameters
+                    QDomElement effectparam = n3.toElement();
+                    if (effectparam.attribute("name") == starttag)
+                        startvalue = effectparam.text().toDouble() * fact;
+                    if (effectparam.attribute("name") == endtag)
+                        endvalue = effectparam.text().toDouble() * fact;
+                }
+                // add first keyframe
+                if (effectout <= effectin) {
+                    // there is only one keyframe
+                    keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';');
+                } else keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
+                QDomNode lastParsedEffect;
+                ix++;
+                QDomNode n2 = effects.at(ix);
+                bool continueParsing = true;
+                for (; !n2.isNull() && continueParsing; n2 = n2.nextSibling()) {
+                    // parse all effects
+                    QDomElement kfreffect = n2.toElement();
+                    int effectout = kfreffect.attribute("out").toInt();
+
+                    for (QDomNode n4 = kfreffect.firstChild(); !n4.isNull(); n4 = n4.nextSibling()) {
+                        // parse effect parameters
+                        QDomElement subeffectparam = n4.toElement();
+                        if (subeffectparam.attribute("name") == "kdenlive_ix" && subeffectparam.text() != effectindex) {
+                            //We are not in the same effect, stop parsing
+                            lastParsedEffect = n2.previousSibling();
                             ix--;
-                        } else {
-                            QDomElement currenteffect = clipeffect.cloneNode().toElement();
-                            currenteffect.setAttribute("kdenlive_ix", effectindex);
-                            QDomNodeList clipeffectparams = currenteffect.childNodes();
-
-                            if (MainWindow::videoEffects.hasKeyFrames(currenteffect)) {
-                                //kDebug() << " * * * * * * * * * * ** CLIP EFF WITH KFR FND  * * * * * * * * * * *";
-                                // effect is key-framable, read all effects to retrieve keyframes
-                                QString factor;
-                                QString starttag;
-                                QString endtag;
-                                QDomNodeList params = currenteffect.elementsByTagName("parameter");
-                                for (int i = 0; i < params.count(); i++) {
-                                    QDomElement e = params.item(i).toElement();
-                                    if (e.attribute("type") == "keyframe") {
-                                        starttag = e.attribute("starttag", "start");
-                                        endtag = e.attribute("endtag", "end");
-                                        factor = e.attribute("factor", "1");
-                                        break;
-                                    }
-                                }
-                                QString keyframes;
-                                int effectin = effect.attribute("in").toInt();
-                                int effectout = effect.attribute("out").toInt();
-                                double startvalue = 0;
-                                double endvalue = 0;
-                                double fact;
-                                if (factor.isEmpty()) fact = 1;
-                                else if (factor.startsWith('%')) {
-                                    fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
-                                } else fact = factor.toDouble();
-                                for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
-                                    // parse effect parameters
-                                    QDomElement effectparam = n3.toElement();
-                                    if (effectparam.attribute("name") == starttag)
-                                        startvalue = effectparam.text().toDouble() * fact;
-                                    if (effectparam.attribute("name") == endtag)
-                                        endvalue = effectparam.text().toDouble() * fact;
-                                }
-                                // add first keyframe
-                                keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
-                                QDomNode lastParsedEffect;
-                                ix++;
-                                QDomNode n2 = effects.at(ix);
-                                bool continueParsing = true;
-                                for (; !n2.isNull() && continueParsing; n2 = n2.nextSibling()) {
-                                    // parse all effects
-                                    QDomElement kfreffect = n2.toElement();
-                                    int effectout = kfreffect.attribute("out").toInt();
-
-                                    for (QDomNode n4 = kfreffect.firstChild(); !n4.isNull(); n4 = n4.nextSibling()) {
-                                        // parse effect parameters
-                                        QDomElement subeffectparam = n4.toElement();
-                                        if (subeffectparam.attribute("name") == "kdenlive_ix" && subeffectparam.text() != effectindex) {
-                                            //We are not in the same effect, stop parsing
-                                            lastParsedEffect = n2.previousSibling();
-                                            ix--;
-                                            continueParsing = false;
-                                            break;
-                                        } else if (subeffectparam.attribute("name") == endtag) {
-                                            endvalue = subeffectparam.text().toDouble() * fact;
-                                            break;
-                                        }
-                                    }
-                                    if (continueParsing) {
-                                        keyframes.append(QString::number(effectout) + ':' + QString::number(endvalue) + ';');
-                                        ix++;
-                                    }
-                                }
-
-                                params = currenteffect.elementsByTagName("parameter");
-                                for (int i = 0; i < params.count(); i++) {
-                                    QDomElement e = params.item(i).toElement();
-                                    if (e.attribute("type") == "keyframe") e.setAttribute("keyframes", keyframes);
-                                }
-                                if (!continueParsing) {
-                                    n2 = lastParsedEffect;
-                                }
-                            } else {
-                                // Check if effect has in/out points
-                                if (effect.hasAttribute("in")) {
-                                    EffectsList::setParameter(currenteffect, "in",  effect.attribute("in"));
-                                }
-                                if (effect.hasAttribute("out")) {
-                                    EffectsList::setParameter(currenteffect, "out",  effect.attribute("out"));
-                                }
-                            }
-
-                            // adjust effect parameters
-                            for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
-                                // parse effect parameters
-                                QDomElement effectparam = n3.toElement();
-                                QString paramname = effectparam.attribute("name");
-                                QString paramvalue = effectparam.text();
-
-
-                                // try to find this parameter in the effect xml
-                                QDomElement e;
-                                for (int k = 0; k < clipeffectparams.count(); k++) {
-                                    e = clipeffectparams.item(k).toElement();
-                                    if (!e.isNull() && e.tagName() == "parameter" && e.attribute("name") == paramname) {
-                                        if (e.attribute("factor", "1") != "1") {
-                                            QString factor = e.attribute("factor", "1");
-                                            double fact;
-                                            if (factor.startsWith('%')) {
-                                                fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
-                                            } else fact = factor.toDouble();
-                                            if (e.attribute("type") == "simplekeyframe") {
-                                                QStringList kfrs = paramvalue.split(";");
-                                                for (int l = 0; l < kfrs.count(); l++) {
-                                                    QString fr = kfrs.at(l).section("=", 0, 0);
-                                                    double val = kfrs.at(l).section("=", 1, 1).toDouble();
-                                                    kfrs[l] = fr + ":" + QString::number((int)(val * fact));
-                                                }
-                                                e.setAttribute("keyframes", kfrs.join(";"));
-                                            } else e.setAttribute("value", paramvalue.toDouble() * fact);
-                                        } else e.setAttribute("value", paramvalue);
-                                        break;
-                                    }
-                                }
-                            }
-                            if (effecttag == "ladspa") {
-                                //QString ladspaEffectFile = EffectsList::parameter(effect, "src", "property");
-
-                                if (!QFile::exists(ladspaEffectFile)) {
-                                    // If the ladspa effect file is missing, recreate it
-                                    initEffects::ladspaEffectFile(ladspaEffectFile, currenteffect.attribute("ladspaid").toInt(), m_trackview->getLadspaParams(currenteffect));
-                                }
-                                currenteffect.setAttribute("src", ladspaEffectFile);
-                            }
-                            if (disableeffect) currenteffect.setAttribute("disable", "1");
-                            item->addEffect(currenteffect, false);
+                            continueParsing = false;
+                            break;
+                        } else if (subeffectparam.attribute("name") == endtag) {
+                            endvalue = subeffectparam.text().toDouble() * fact;
+                            break;
                         }
                     }
+                    if (continueParsing) {
+                        keyframes.append(QString::number(effectout) + ':' + QString::number(endvalue) + ';');
+                        ix++;
+                    }
+                }
+
+                params = currenteffect.elementsByTagName("parameter");
+                for (int i = 0; i < params.count(); i++) {
+                    QDomElement e = params.item(i).toElement();
+                    if (e.attribute("type") == "keyframe") e.setAttribute("keyframes", keyframes);
+                }
+                if (!continueParsing) {
+                    n2 = lastParsedEffect;
+                }
+            } else {
+                // Check if effect has in/out points
+                if (effect.hasAttribute("in")) {
+                    EffectsList::setParameter(currenteffect, "in",  effect.attribute("in"));
+                }
+                if (effect.hasAttribute("out")) {
+                    EffectsList::setParameter(currenteffect, "out",  effect.attribute("out"));
+                }
+            }
+
+            // adjust effect parameters
+            for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
+                // parse effect parameters
+                QDomElement effectparam = n3.toElement();
+                QString paramname = effectparam.attribute("name");
+                QString paramvalue = effectparam.text();
+
+                // try to find this parameter in the effect xml
+                QDomElement e;
+                for (int k = 0; k < clipeffectparams.count(); k++) {
+                    e = clipeffectparams.item(k).toElement();
+                    if (!e.isNull() && e.tagName() == "parameter" && e.attribute("name") == paramname) {
+                        if (e.attribute("factor", "1") != "1") {
+                            QString factor = e.attribute("factor", "1");
+                            double fact;
+                            if (factor.startsWith('%')) {
+                                fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
+                            } else fact = factor.toDouble();
+                            if (e.attribute("type") == "simplekeyframe") {
+                                QStringList kfrs = paramvalue.split(";");
+                                for (int l = 0; l < kfrs.count(); l++) {
+                                    QString fr = kfrs.at(l).section("=", 0, 0);
+                                    double val = kfrs.at(l).section("=", 1, 1).toDouble();
+                                    kfrs[l] = fr + ":" + QString::number((int)(val * fact));
+                                }
+                                e.setAttribute("keyframes", kfrs.join(";"));
+                            } else e.setAttribute("value", paramvalue.toDouble() * fact);
+                        } else e.setAttribute("value", paramvalue);
+                        break;
+                    }
                 }
             }
-            //m_clipList.append(clip);
+            if (effecttag == "ladspa") {
+                //QString ladspaEffectFile = EffectsList::parameter(effect, "src", "property");
+
+                if (!QFile::exists(ladspaEffectFile)) {
+                    // If the ladspa effect file is missing, recreate it
+                    initEffects::ladspaEffectFile(ladspaEffectFile, currenteffect.attribute("ladspaid").toInt(), m_trackview->getLadspaParams(currenteffect));
+                }
+                currenteffect.setAttribute("src", ladspaEffectFile);
+            }
+            if (disableeffect) currenteffect.setAttribute("disable", "1");
+            if (clip) clip->addEffect(currenteffect, false);
+            else {
+                kDebug() << "<< TRACK: " << trackIndex << ", adding effect";;
+                m_doc->addTrackEffect(trackIndex, currenteffect);
+            }
         }
     }
-    //m_trackDuration = position;
-
-
-    //documentTracks.insert(ix, track);
-    kDebug() << "*************  ADD DOC TRACK " << ix << ", DURATION: " << position;
-    return position;
-    //track->show();
 }
 
+
 DocClipBase *TrackView::getMissingProducer(const QString id) const
 {
     QDomElement missingXml;
@@ -905,8 +934,10 @@ void TrackView::slotVerticalZoomDown()
     if (m_verticalZoom == 0) return;
     m_verticalZoom--;
     m_doc->setZoom(m_doc->zoom().x(), m_verticalZoom);
-    if (m_verticalZoom == 0) m_trackview->setScale(m_scene->scale().x(), 0.5);
-    else m_trackview->setScale(m_scene->scale().x(), 1);
+    if (m_verticalZoom == 0)
+        m_trackview->setScale(m_scene->scale().x(), 0.5);
+    else
+        m_trackview->setScale(m_scene->scale().x(), 1);
     adjustTrackHeaders();
     m_trackview->verticalScrollBar()->setValue(headers_area->verticalScrollBar()->value());
 }
@@ -916,8 +947,10 @@ void TrackView::slotVerticalZoomUp()
     if (m_verticalZoom == 2) return;
     m_verticalZoom++;
     m_doc->setZoom(m_doc->zoom().x(), m_verticalZoom);
-    if (m_verticalZoom == 2) m_trackview->setScale(m_scene->scale().x(), 2);
-    else m_trackview->setScale(m_scene->scale().x(), 1);
+    if (m_verticalZoom == 2)
+        m_trackview->setScale(m_scene->scale().x(), 2);
+    else
+        m_trackview->setScale(m_scene->scale().x(), 1);
     adjustTrackHeaders();
     m_trackview->verticalScrollBar()->setValue(headers_area->verticalScrollBar()->value());
 }
@@ -928,19 +961,42 @@ void TrackView::updateProjectFps()
     m_trackview->updateProjectFps();
 }
 
-void TrackView::slotRenameTrack(int ix)
+void TrackView::slotRenameTrack(int ix, QString name)
 {
     int tracknumber = m_doc->tracksCount() - ix;
-    TrackInfo info = m_doc->trackInfoAt(tracknumber - 1);
-    bool ok;
-    QString newName = QInputDialog::getText(this, i18n("New Track Name"), i18n("Enter new name"), QLineEdit::Normal, info.trackName, &ok);
-    if (ok) {
-        info.trackName = newName;
-        m_doc->setTrackType(tracknumber - 1, info);
-        QTimer::singleShot(300, this, SLOT(slotReloadTracks()));
-        m_doc->setModified(true);
-    }
+    QList <TrackInfo> tracks = m_doc->tracksList();
+    tracks[tracknumber - 1].trackName = name;
+    ConfigTracksCommand *configTracks = new ConfigTracksCommand(m_trackview, m_doc->tracksList(), tracks);
+    m_doc->commandStack()->push(configTracks);
+    m_doc->setModified(true);
 }
 
+void TrackView::slotUpdateVerticalScroll(int /*min*/, int max)
+{
+    int height = 0;
+    if (max > 0) height = m_trackview->horizontalScrollBar()->height() - 1;
+    headers_container->layout()->setContentsMargins(0, m_trackview->frameWidth(), 0, height);
+}
+
+void TrackView::updateRuler()
+{
+    m_ruler->update();
+}
+
+void TrackView::slotShowTrackEffects(int ix)
+{
+    m_trackview->clearSelection();
+    emit showTrackEffects(m_doc->tracksCount() - ix, m_doc->trackInfoAt(m_doc->tracksCount() - ix - 1));
+}
+
+void TrackView::slotUpdateTrackEffectState(int ix)
+{
+    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
+    if (ix >= widgets.count()) {
+        kDebug() << "ERROR, Trying to access a non existant track: " << ix;
+        return;
+    }
+    widgets.at(m_doc->tracksCount() - ix - 1)->updateEffectLabel(m_doc->trackInfoAt(ix).effectsList.effectNames());
+}
 
 #include "trackview.moc"
