@@ -26,15 +26,14 @@
 
 #include <KDebug>
 
-TransitionSettings::TransitionSettings(QWidget* parent) :
+TransitionSettings::TransitionSettings(Monitor *monitor, QWidget* parent) :
         QWidget(parent),
         m_usedTransition(NULL),
-        m_tracksCount(0),
         m_autoTrackTransition(0)
 {
     setupUi(this);
     QVBoxLayout *vbox1 = new QVBoxLayout(frame);
-    m_effectEdit = new EffectStackEdit(frame);
+    m_effectEdit = new EffectStackEdit(monitor, frame);
     vbox1->setContentsMargins(0, 0, 0, 0);
     vbox1->setSpacing(0);
     vbox1->addWidget(m_effectEdit);
@@ -63,26 +62,42 @@ TransitionSettings::TransitionSettings(QWidget* parent) :
 
     connect(transitionList, SIGNAL(activated(int)), this, SLOT(slotTransitionChanged()));
     connect(transitionTrack, SIGNAL(activated(int)), this, SLOT(slotTransitionTrackChanged()));
-
-    connect(this, SIGNAL(transferParamDesc(const QDomElement&, int , int)), m_effectEdit , SLOT(transferParamDesc(const QDomElement&, int , int)));
     connect(m_effectEdit, SIGNAL(parameterChanged(const QDomElement&, const QDomElement&)), this , SLOT(slotUpdateEffectParams(const QDomElement&, const QDomElement&)));
+    connect(monitor, SIGNAL(renderPosition(int)), this, SLOT(slotRenderPos(int)));
 }
 
 void TransitionSettings::updateProjectFormat(MltVideoProfile profile, Timecode t, const QList <TrackInfo> info)
 {
-    m_tracksCount = info.count();
     m_effectEdit->updateProjectFormat(profile, t);
-    QStringList tracksList;
+    m_tracks = info;
+    updateTrackList();
+}
+
+void TransitionSettings::updateTimecodeFormat()
+{
+    m_effectEdit->updateTimecodeFormat();
+}
+
+void TransitionSettings::updateTrackList()
+{
     transitionTrack->blockSignals(true);
+    int current = transitionTrack->itemData(transitionTrack->currentIndex()).toInt();
     transitionTrack->clear();
     transitionTrack->addItem(i18n("Auto"), -1);
-    for (int i = 0; i < m_tracksCount; i++) {
-        int ix = m_tracksCount - i - 1;
-        if (!info.at(ix).trackName.isEmpty())
-            transitionTrack->addItem(info.at(ix).trackName + '(' + QString::number(i) + ')');
-        else transitionTrack->addItem(QString::number(i));
+    int limit = 1;
+    if (m_usedTransition)
+        limit = m_usedTransition->track() + 1;
+    kDebug() << "/ / TRANS TRK: " << limit;
+    KIcon videoIcon("kdenlive-show-video");
+    KIcon audioIcon("kdenlive-show-audio");
+    for (int i = limit; i < m_tracks.count(); i++) {
+        int ix = m_tracks.count() - i - 1;
+        transitionTrack->addItem(m_tracks.at(ix).type == VIDEOTRACK ? videoIcon : audioIcon,
+                                 m_tracks.at(ix).trackName.isEmpty() ? QString::number(i) : m_tracks.at(ix).trackName + " (" + QString::number(i) + ")",
+                                 m_tracks.count() - i);
     }
-    transitionTrack->addItem(i18n("Black"), m_tracksCount);
+    transitionTrack->addItem(i18n("Black"), 0);
+    transitionTrack->setCurrentIndex(transitionTrack->findData(current));
     transitionTrack->blockSignals(false);
 }
 
@@ -90,19 +105,21 @@ void TransitionSettings::updateProjectFormat(MltVideoProfile profile, Timecode t
 void TransitionSettings::slotTransitionChanged(bool reinit, bool updateCurrent)
 {
     QDomElement e = m_usedTransition->toXML().cloneNode().toElement();
+    int start = m_usedTransition->startPos().frames(KdenliveSettings::project_fps());
+    int end = m_usedTransition->endPos().frames(KdenliveSettings::project_fps());
     if (reinit) {
         // Reset the transition parameters to the default one
         QDomElement newTransition = MainWindow::transitions.getEffectByName(transitionList->currentText()).cloneNode().toElement();
         slotUpdateEffectParams(e, newTransition);
-        emit transferParamDesc(newTransition, m_usedTransition->startPos().frames(KdenliveSettings::project_fps()), m_usedTransition->endPos().frames(KdenliveSettings::project_fps()));
+        m_effectEdit->transferParamDesc(newTransition, start, start, end, false);
     } else if (!updateCurrent) {
         // Transition changed, update parameters dialog
         //slotUpdateEffectParams(e, e);
-        m_effectEdit->transferParamDesc(e, m_usedTransition->startPos().frames(KdenliveSettings::project_fps()), m_usedTransition->endPos().frames(KdenliveSettings::project_fps()));
+        m_effectEdit->transferParamDesc(e, start, start, end, false);
     } else {
         // Same transition, we just want to update the parameters value
         slotUpdateEffectParams(e, e);
-        if (m_usedTransition->hasGeometry()) emit transferParamDesc(m_usedTransition->toXML(), m_usedTransition->startPos().frames(KdenliveSettings::project_fps()), m_usedTransition->endPos().frames(KdenliveSettings::project_fps()));
+        if (m_usedTransition->hasGeometry()) m_effectEdit->transferParamDesc(m_usedTransition->toXML(), start, start, end, false);
     }
 }
 
@@ -112,16 +129,15 @@ void TransitionSettings::slotTransitionTrackChanged()
     int ix = 0;
     QDomElement oldxml = m_usedTransition->toXML().cloneNode().toElement();
     if (transitionTrack->currentIndex() > 0) {
-        ix = transitionTrack->count() - transitionTrack->currentIndex() - 1;
+        ix = transitionTrack->itemData(transitionTrack->currentIndex()).toInt();
         m_usedTransition->setForcedTrack(true, ix);
         m_effectEdit->updateParameter("force_track", "1");
-        emit transitionUpdated(m_usedTransition, oldxml);
     } else {
         ix = m_autoTrackTransition;
         m_usedTransition->setForcedTrack(false, ix);
         m_effectEdit->updateParameter("force_track", "0");
-        emit transitionUpdated(m_usedTransition, oldxml);
     }
+    emit transitionUpdated(m_usedTransition, oldxml);
     m_effectEdit->updateParameter("transition_btrack", QString::number(ix));
 }
 
@@ -134,7 +150,8 @@ void TransitionSettings::slotTransitionItemSelected(Transition* t, int nextTrack
         if (t == NULL) return;
         if (update) {
             transitionTrack->blockSignals(true);
-            if (t->forcedTrack()) transitionTrack->setCurrentIndex(m_tracksCount + 1 - t->transitionEndTrack());
+            updateTrackList();
+            if (t->forcedTrack()) transitionTrack->setCurrentIndex(transitionTrack->findData(t->transitionEndTrack()));
             else transitionTrack->setCurrentIndex(0);
             transitionTrack->blockSignals(false);
         }
@@ -149,11 +166,14 @@ void TransitionSettings::slotTransitionItemSelected(Transition* t, int nextTrack
         m_transitionDuration = t->cropDuration();
         m_transitionStart = t->startPos();
         transitionTrack->blockSignals(true);
-        if (!t->forcedTrack()) transitionTrack->setCurrentIndex(0);
-        else transitionTrack->setCurrentIndex(m_tracksCount + 1 - t->transitionEndTrack());
+        m_usedTransition = t;
+        updateTrackList();
+        if (!t->forcedTrack())
+            transitionTrack->setCurrentIndex(0);
+        else
+            transitionTrack->setCurrentIndex(transitionTrack->findData(t->transitionEndTrack()));
         transitionTrack->blockSignals(false);
         int ix = transitionList->findData(t->transitionInfo(), Qt::UserRole, Qt::MatchExactly);
-        m_usedTransition = t;
         if (ix != -1) {
             transitionList->blockSignals(true);
             transitionList->setCurrentIndex(ix);
@@ -163,7 +183,7 @@ void TransitionSettings::slotTransitionItemSelected(Transition* t, int nextTrack
     } else {
         // null transition selected
         m_usedTransition = NULL;
-        m_effectEdit->transferParamDesc(QDomElement(), 0, 0);
+        m_effectEdit->transferParamDesc(QDomElement(), 0, 0, 0, false);
     }
 
 }
@@ -175,9 +195,8 @@ void TransitionSettings::slotUpdateEffectParams(const QDomElement &oldparam, con
         m_usedTransition->update();
     }
     //oldparam must be also first given to Transition and then return the toXML()
-    if (oldparam != param) {
+    if (oldparam != param)
         emit transitionUpdated(m_usedTransition, oldparam);
-    }
 }
 
 void TransitionSettings::raiseWindow(QWidget* dock)
@@ -187,3 +206,10 @@ void TransitionSettings::raiseWindow(QWidget* dock)
 
 }
 
+void TransitionSettings::slotRenderPos(int pos)
+{
+    if (m_usedTransition)
+        m_effectEdit->slotSyncEffectsPos(pos - m_usedTransition->startPos().frames(KdenliveSettings::project_fps()));
+}
+
+#include "transitionsettings.moc"
